@ECHO OFF
setlocal EnableDelayedExpansion
SET TWGETWINSTART=%time%
SET BCMGetVER=060724
@ECHO Capture_Script_Version_%BCMGetVER%
REM -
REM - 06/07/24 - Added detection of multiple NICs.
REM -
REM - 04/18/24 - Added Win11 detection.
REM -
REM - 04/09/24 - Added 228 niccli util for testing. Still using bnxtnvm.
REM -
REM - 02/28/24 - Update to MR8.8, MR7.28 utils.
REM -
REM - 08/22/23 - Fix ondemand snapdump capture for Aero. Consolodated reg keys into one folder.
REM -
REM - 07/19/23 - Add niccli_x64 support
REM -
REM - 05/31/23 - Update to MR8.5, MR7.25 utils.
REM -
REM - 03/29/23 - Add g4xutil for Atlas. Update to MR8.4 MR7.24 utils. Added Cobra SAS3xXX limited support.
REM -
REM - 12/2/22 - Add Perf-IT detection and collect personality info. Update to MR8.3 utils.
REM -
REM - 09/29/22 - Add temperature and reg key gathering to bnxtnvm commands
REM -
REM - 09/15/22 - Update utilities for Storcli2 (MR8.2) and Storcli (Phase 24) bnxtnvm (222)
REM -
REM - 09/15/22 - Fix typo and update Windows version detection
REM -
REM - 07/20/22 - Track timing and various cleanup
REM -
REM - 07/14/22 - Updated Storcli2 commands for Avenger
REM -
REM - 06/29/22 - Updated Scrutiny Cli Version = v8.1.1.0 (Bld-45.52.11.56.14.0)
REM -
REM - 06/29/22 - Updated Storcli2 CLI Version = 008.0001.0000.0018 Apr 12, 2022
REM -
REM - 06/06/22 - Added bnxtnvm support for P225p
REM -
REM - 05/14/21 - Added ScrutinyCli support for 96xx
REM -
REM - 05/18/21 - Move all HBAs to new Scrutiny version 0.53.0.0
REM -
REM - 6/11/21 - Added Storcli2 CLI Version = 008.0000.0000.0105 for Avenger data gathering
REM -
REM - 6/30/21 - Added Margay and Cub data gathering with Scrutiny
REM -
REM - 10/6/21 - Added detection for " IT" 9400/9500
REM -
REM - 01/20/22 - Updated utilities (Scrutiny ventura Ph21 v33, Storlib Ph21, Scrutiny & Storcli2 from MR8.1
REM
REM  Data collection script for Windows platforms
REM    This script will collect some system files such as "event" logs useful 
REM    for debugging purposes. 
REM 
REM  How to run it:
REM    1. Extract the BCMGet_xxxxxx.7z/zip file to a file system with available space. 
REM         A. In general, the size of the data collected is at least as big as the total size of all logs files.
REM    3. Run it: BCMGet -H <enter> for help screen
REM
REM 
REM  What to do when the script ends:
REM    1. Send the .7z file to Technical Support or the FAE that you are in contact with.
REM 
REM  What to do when receiving the .7z file:
REM    1. Verify files are not empty & Controller_Cx.txt files are present.
REM    2. Analyze the collected data 
REM
REM
REM
REM ###########################################################################################################################
REM # Windows Batch file scripting debug tips
REM ###########################################################################################################################
REM
REM 1. You can not use a "GOTO Label" within a conditional statement, i.e. (GOTO Label) unless there is an executable 
REM    statement, i.e. "@ECHO ###" after the label. 
REM 
REM 2. You can not use a "IF %ERRORLEVEL%==0 or @ECHO %ERRORLEVEL% within a conditional statement, i.e. (IF %ERRORLEVEL%==0).
REM    The return will always be 0, use "IF NOT ERRORLEVEL 1" for a TRUE statement.
REM
REM 3. The replaceable parameter %Num_Mraid_Adapters% doesn't work in the following statement if its in a conditional statement, i.e.
REM    IF [%TWGETBATCHMODE%]==[NO] (
REM    FOR /L %%i IN (0,1,15) DO ( IF %%i LSS %Num_Mraid_Adapters% @ECHO %%i >> adp_nums.txt )
REM
REM 4. To use else it must connect each statement on the same line, i.e. ) ELSE (
REM
REM 5. grep 2.24 "^value" only at beginng of line, "value$" only at end of line, -v = invert match, i.e. all non matching lines.

REM ###########################################################################################################################
REM # Check for ARM64 architecture
REM ###########################################################################################################################

IF %PROCESSOR_ARCHITECTURE% == ARM64 ECHO "This is an ARM64 platform. BCMGet must be run in a 64 bit PowerShell window on ARM platforms."
IF %PROCESSOR_ARCHITECTURE% == ARM64 GOTO SKIP_TO_END

IF %PROCESSOR_ARCHITECTURE% == x86 ECHO "This is 32bit platform. BMCGet does not run in a 32bit Windows platform."
IF %PROCESSOR_ARCHITECTURE% == x86 GOTO SKIP_TO_END

REM ###########################################################################################################################
REM # Check for administrator access
REM ###########################################################################################################################
    echo Administrative permissions required. Detecting permissions...

    net session >nul 2>&1
    if %errorLevel% == 0 (
        echo Success: Administrative permissions confirmed.
		GOTO PASS_CHK
    ) else (
        echo Failure: Current permissions inadequate. Need to run as Administrator. Hit ENTER to exit script.
    )

    pause >nul
	GOTO SKIP_TO_END
:PASS_CHK

REM ###########################################################################################################################
REM # Initialize time/date variables
REM ###########################################################################################################################
SET tw_date=%date%
SET tw_date=%tw_date:~-10%
SET tw_date=%tw_date:/=%
SET tw_date=%tw_date: =%
SET tw_date=%tw_date::=%
SET tw_date=%tw_date:.=%
SET tw_year=%tw_date:~-2%
SET tw_daymonth=%tw_date:~0,-4%
SET tw_date=%tw_daymonth%%tw_year%

SET tw_time=%time%
SET tw_time=%tw_time: =%
SET tw_time=%tw_time::=%
SET tw_time=%tw_time:.=%
SET tw_time=%tw_time:,=%
SET tw_time=%tw_time:~0,-2%

REM ###########################################################################################################################
REM # Save old log and clean up
REM ###########################################################################################################################
IF EXIST misc_output.txt copy misc_output.txt %tw_date%.%tw_time%_misc_output.txt > nul 2>&1
IF EXIST misc_output.txt del misc_output.txt > nul 2>&1
IF EXIST misc_output.txt del misc_output.txt > nul 2>&1
IF EXIST misc_output.txt @ECHO misc_output.txt still exists... 
IF EXIST misc_output.txt del misc_output.txt > nul 2>&1
IF EXIST misc_output.txt del misc_output.txt > nul 2>&1
IF EXIST misc_output.txt @ECHO misc_output.txt still exists... 

IF EXIST Utils rmdir /S /Q Utils >> misc_output.txt 2>&1
IF EXIST Utils @ECHO Utils still exists... >> misc_output.txt 2>&1
IF EXIST Utils @ECHO Utils still exists... 
IF EXIST Utils rmdir /S /Q Utils >> misc_output.txt 2>&1
IF EXIST Utils @ECHO Utils still exists... >> misc_output.txt 2>&1
IF EXIST Utils @ECHO Utils still exists...

@ECHO dir of subdir after Utils deletion >> misc_output.txt 2>&1
dir >> misc_output.txt 2>&1

REM ###########################################################################################################################
REM # Set all_cli variable
REM ###########################################################################################################################

SET all_cli=
IF EXIST all_cli SET all_cli=all_cli

IF EXIST timer.txt del timer.txt >> misc_output.txt 2>&1
IF EXIST timer.txt del timer.txt >> misc_output.txt 2>&1
IF EXIST timer.txt @ECHO timer.txt still exists... >> misc_output.txt 2>&1
IF EXIST timer.txt @ECHO timer.txt still exists... 
IF EXIST timer.txt del timer.txt >> misc_output.txt 2>&1
IF EXIST timer.txt del timer.txt >> misc_output.txt 2>&1
IF EXIST timer.txt @ECHO timer.txt still exists... >> misc_output.txt 2>&1
IF EXIST timer.txt @ECHO timer.txt still exists... 

REM Need Early

IF NOT EXIST Utils mkdir Utils >> misc_output.txt 2>&1
copy 64_7z.exe 7z.exe >> misc_output.txt 2>&1
copy 64_7z.dll 7z.dll >> misc_output.txt 2>&1
.\7z e -y %all_cli% cygwin64.7z >> misc_output.txt 2>&1
.\7z x -y cygwin64.7z >> misc_output.txt 2>&1
move /Y cygwin64 Utils\cygwin >> misc_output.txt 2>&1

SET gawk=Utils\cygwin\gawk >> misc_output.txt 2>&1
SET grep=Utils\cygwin\grep >> misc_output.txt 2>&1
SET sed=Utils\cygwin\sed >> misc_output.txt 2>&1
SET sleep=Utils\cygwin\sleep >> misc_output.txt 2>&1
SET tr=Utils\cygwin\tr >> misc_output.txt 2>&1

@ECHO dir Utils after creation of subdir and move of cygwin utils >> misc_output.txt 2>&1
dir Utils >> misc_output.txt 2>&1

IF EXIST cygwin64 rmdir /S /Q cygwin64 >> misc_output.txt 2>&1

IF EXIST timer.exe del timer.exe >> misc_output.txt 2>&1
IF EXIST xdir.exe del xdir.exe >> misc_output.txt 2>&1

.\7z e -y %all_cli% timer.exe >> misc_output.txt 2>&1
.\7z e -y %all_cli% xdir.exe >> misc_output.txt 2>&1

SET NOWOW64=NO
@ECHO WOW64 test with xdir >> misc_output.txt 2>&1
.\xdir >> misc_output.txt 2>&1
IF ERRORLEVEL 1	(
		SET NOWOW64=YES
		@ECHO %time%
		del timer.exe >> misc_output.txt 2>&1
		del xdir.exe >> misc_output.txt 2>&1
		@ECHO deleted timer.exe and xdir.exe - doing a dir >> misc_output.txt 2>&1 
		dir >> misc_output.txt 2>&1  	
		)
@ECHO Script start time
IF NOT [%NOWOW64%]==[YES] (.\timer /q /nologo)
IF NOT [%NOWOW64%]==[YES] (.\xdir /Form=*t timer.txt)

REM Populate the cleanup list
REM Third Party utils
@ECHO dumpel.exe > cleanup_all.txt 
@ECHO pciutils-3.2.1_64.7z >> cleanup_all.txt 
@ECHO sg3_utils-1.42_64.7z >> cleanup_all.txt 
@ECHO cygwin64.7z >> cleanup_all.txt
@ECHO scsi_* >> cleanup_all.txt
@ECHO copying >> cleanup_all.txt
@ECHO gpl*.txt >> cleanup_all.txt
@ECHO *.html >> cleanup_all.txt
@ECHO cyg*.dll >> cleanup_all.txt
@ECHO cut.exe >> cleanup_all.txt
@ECHO gawk.exe >> cleanup_all.txt
@ECHO grep.exe >> cleanup_all.txt
@ECHO sed.exe >> cleanup_all.txt
@ECHO sleep.exe >> cleanup_all.txt
@ECHO tr.exe >> cleanup_all.txt
REM Script files
@ECHO aens_mr.txt >> cleanup_all.txt 
@ECHO create.bat >> cleanup_all.txt 
@ECHO precreate.bat >> cleanup_all.txt 
@ECHO MegaRAID_Terminology.txt >> cleanup_all.txt 
@ECHO MegaRAID_Driver_Event_Codes.txt >> cleanup_all.txt 
REM Cli/Utils
@ECHO storcli64.exe >> cleanup_all.txt 
@ECHO storcli2.exe >> cleanup_all.txt 
@ECHO storcli.log >> cleanup_all.txt 
@ECHO storcli2.log* >> cleanup_all.txt 
@ECHO storsas.log >> cleanup_all.txt 
@ECHO storcliconf.ini >> cleanup_all.txt 
@ECHO storelibdebugit.txt >> cleanup_all.txt 
@ECHO license.txt >> cleanup_all.txt 
@ECHO scl2.exe >> cleanup_all.txt 
@ECHO scrtnycli_x64.exe >> cleanup_all.txt 
@ECHO g4Xdiagnostics_x64.exe >> cleanup_all.txt 
@ECHO coredump* >> cleanup_all.txt 
@ECHO snapdump* >> cleanup_all.txt 
@ECHO Rttdump* >> cleanup_all.txt 
@ECHO mpi3drv.sys_* >> cleanup_all.txt
@ECHO scrutiny-logs-* >> cleanup_all.txt 
@ECHO eventlog.txt >> cleanup_all.txt 
REM MegaRAID working files
@ECHO adpcount_1.txt >> cleanup_all.txt 
@ECHO num_mraid_adapters.txt >> cleanup_all.txt 
@ECHO adp_nums.txt >> cleanup_all.txt 
@ECHO CtDbg.log >> cleanup_all.txt 
@ECHO MegaSAS.log >> cleanup_all.txt 
@ECHO CmdTool.log >> cleanup_all.txt 
@ECHO mr_ctrl_nums.txt >> cleanup_all.txt 
@ECHO mr2_ctrl_nums.txt >> cleanup_all.txt 
@ECHO mr_ctrl_nums_pmstat.txt >> cleanup_all.txt
@ECHO mr_ctrl_nums_aec.txt >> cleanup_all.txt
@ECHO *_show_pmstat_enbld_mr.txt >> cleanup_all.txt
@ECHO *_show_pmstat_mr.txt >> cleanup_all.txt
@ECHO *_show_pmstat_eidslt_mr.txt >> cleanup_all.txt
@ECHO *_show_pmstat_eidslt1_mr.txt >> cleanup_all.txt
@ECHO *_show_aec_mr.txt >> cleanup_all.txt
@ECHO *_show_capture_mr.txt >> cleanup_all.txt
@ECHO pre_mr_ctrl_nums.txt >> cleanup_all.txt
@ECHO pre_mr2_ctrl_nums.txt >> cleanup_all.txt
REM HBA working files
@ECHO Valid_hba_test.txt >> cleanup_all.txt
@ECHO Valid_wd_test.txt >> cleanup_all.txt
REM bnxtnvm working files
@ECHO bnxtnvm* >> cleanup_all.txt
@ECHO *.core >> cleanup_all.txt
@ECHO *.pkg >> cleanup_all.txt
@ECHO SliffDriver.sys >> cleanup_all.txt
@ECHO Sliff.sys >> cleanup_all.txt
@ECHO niccli_x64.exe >> cleanup_all.txt
REM Util logs
@ECHO CmdTool.log >> cleanup_all.txt 
@ECHO CtDbg.log >> cleanup_all.txt 
@ECHO MegaSAS.log >> cleanup_all.txt 
REM Misc
@ECHO scrutiny.7z >> cleanup_all.txt 
@ECHO Docs.7z >> cleanup_all.txt 

REM   .......................................||.......................................
@ECHO ........................Initial Cleanup at Script Start......................... >> misc_output.txt 2>&1
@ECHO dir >> misc_output.txt 2>&1
dir >> misc_output.txt 2>&1
@ECHO Running Cleanup >> misc_output.txt 2>&1
@ECHO List of files to delete >> misc_output.txt 2>&1
type cleanup_all.txt >> misc_output.txt 2>&1
@ECHO File list done >> misc_output.txt 2>&1
FOR /F "usebackq" %%i IN (cleanup_all.txt) DO	( 
						IF EXIST %%i (del %%i >> misc_output.txt 2>&1)
						)

@ECHO dir AFTER Running Cleanup >> misc_output.txt 2>&1
dir >> misc_output.txt 2>&1

REM ###########################################################################################################################
REM # Verify all capture script files exist or exit.
REM ###########################################################################################################################

IF NOT EXIST 7z.exe @ECHO "7z.exe missing GOTO NOT_A_VALID_CAPTURE_SCRIPT" >> misc_output.txt 2>&1
IF NOT EXIST 7z.dll @ECHO "7z.dll missing GOTO NOT_A_VALID_CAPTURE_SCRIPT" >> misc_output.txt 2>&1
IF NOT EXIST %all_cli% @ECHO "%all_cli% missing GOTO NOT_A_VALID_CAPTURE_SCRIPT" >> misc_output.txt 2>&1

IF NOT EXIST 7z.exe (@ECHO 7z.exe missing GOTO NOT_A_VALID_CAPTURE_SCRIPT)
IF NOT EXIST 7z.dll (@ECHO 7z.dll missing GOTO NOT_A_VALID_CAPTURE_SCRIPT)
IF NOT EXIST %all_cli% (@ECHO %all_cli% missing GOTO NOT_A_VALID_CAPTURE_SCRIPT)

GOTO VALID_CAPTURE_SCRIPT

:NOT_A_VALID_CAPTURE_SCRIPT
REM   .......................................||.......................................
@ECHO .
@ECHO "BCMGet -H" provides a help screen.
@ECHO .
@ECHO This is not a valid BCMGet installation. This script is available at;
@ECHO https://www.broadcom.com/docs/1232743167
@ECHO .
@ECHO For legacy lsiget;
@ECHO https://www.broadcom.com/support/knowledgebase/1211161499563/lsiget-data-capture-script
@ECHO .
@ECHO All files included in the original BCMGet_xxxxxx.7z file MUST be kept
@ECHO in the same subdir as BCMGet.bat.
@ECHO .
@ECHO .

REM   .......................................||.......................................
@ECHO ..........................:NOT_A_VALID_CAPTURE_SCRIPT........................... >> misc_output.txt 2>&1
@ECHO "dir >> misc_output.txt 2>&1" >> misc_output.txt 2>&1
dir >> misc_output.txt 2>&1

GOTO END

:VALID_CAPTURE_SCRIPT
REM ###########################################################################################################################
REM # Initialize Variables
REM ###########################################################################################################################
SET EXTRACTUTILS=NO
SET TWGETSKIPRECORDCAPTURE=YES
SET TWGETSKIPCOMPRESSION=NO
SET TWGETSKIPRECORDSORT=YES
SET TWGETSKIPWINDOWSREPORTING=NO
SET TWPRINTFILENAME=
SET TWGETDIRECTORYKEEP=NO
SET TWGETBATCHMODE=
SET TWGETPARTIALMODE=STANDARD
SET TW_Help_Screen=
SET TWcomment=
SET TWver_name=
SET TW-FN=
SET TW-WS=
SET Continue_without_CLI=
SET TWGETSKIPCDA=NO

REM MRaid
SET NO_MR_Adps=YES
SET NO_MR2_Adps=YES

REM HBA
SET NO_scl_IOC=YES
SET NO_LSI_HBAs=
SET NO_GEN3_HBAs=YES
SET NO_GEN4_HBAs=YES
SET NO_GEN2-3_HBAs=YES
SET ENABLE_ALL_IOC_DEBUG=NO

REM Exps
SET NO_xu_GEN1_EXPs=YES
SET NO_xu_GEN2_EXPs=YES
SET NO_g3xu_GEN3_EXPs=YES
SET NO_g4xu_GEN4_EXPs=YES
SET NO_scl_EXP=YES

SET NO_scl_EXP-IOC=YES
SET NO_bnxtnvm=YES
SET NO_niccli=YES
SET TWGETSKIPEXPANDER=NO

REM ###########################################################################################################################
REM # Command Line Options
REM # Looking for comments that are not command line options.
REM # Only 1 comment allowed, lowest variable # wins.
REM ###########################################################################################################################
FOR /L %%i IN (1,1,20) DO (IF EXIST TWGETVARIABLE%%i del TWGETVARIABLE%%i)

@ECHO %1 > TWGETVARIABLE1
@ECHO %2 > TWGETVARIABLE2
@ECHO %3 > TWGETVARIABLE3
@ECHO %4 > TWGETVARIABLE4
@ECHO %5 > TWGETVARIABLE5
@ECHO %6 > TWGETVARIABLE6
@ECHO %7 > TWGETVARIABLE7
@ECHO %8 > TWGETVARIABLE8
@ECHO %9 > TWGETVARIABLE9
@ECHO %10 > TWGETVARIABLE10
@ECHO %11 > TWGETVARIABLE11
@ECHO %12 > TWGETVARIABLE12
@ECHO %13 > TWGETVARIABLE13
@ECHO %14 > TWGETVARIABLE14
@ECHO %15 > TWGETVARIABLE15
@ECHO %16 > TWGETVARIABLE16
@ECHO %17 > TWGETVARIABLE17
@ECHO %18 > TWGETVARIABLE18
@ECHO %19 > TWGETVARIABLE19
@ECHO %20 > TWGETVARIABLE20


%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE20 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%20
%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE19 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%19
%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE18 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%18
%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE17 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%17
%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE16 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%16
%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE15 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%15
%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE14 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%14
%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE13 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%13
%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE12 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%12
%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE11 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%11
%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE10 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%10
%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE9 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%9
%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE8 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%8
%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE7 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%7
%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE6 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%6
%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE5 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%5
%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE4 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%4
%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE3 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%3
%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE2 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%2
%grep% -i -e "-EXT" -e "-P" -e "-D" -e "-B" -e "-Q" -e "-F1" -e "-F2" -e "-F3" -e "-F4" -e "-CS" -e "-SRC" -e "-SRS" -e "-SWR" -e "-SCDA" -e "-SMR" -e "-SHBA" -e "-SEXP" -e "-SC" -e "-E_AEC" -e "-E_DPM" -e "-E_AEC_DPM" -e "-G_AEC" -e "-G_DPM" -e "-G_AEC_DPM" -e "-H" TWGETVARIABLE1 >> misc_output.txt 2>&1
IF ERRORLEVEL 1 SET TWcomment=%1

FOR /L %%i IN (1,1,20) DO	(
				IF EXIST TWGETVARIABLE%%i	(
								@ECHO ######################TWGETVARIABLE%%i###################### >> misc_output.txt 2>&1
								type TWGETVARIABLE%%i >> misc_output.txt 2>&1
								del TWGETVARIABLE%%i >> misc_output.txt 2>&1	
								)
				)

REM Checking command line variables for options.
REM Competing options are not allowed.

for %%i in (%*) do	(
			IF /I [%%i]==[-P] SET TWPRINTFILENAME=YES
			IF /I [%%i]==[-D] SET TWGETDIRECTORYKEEP=YES
			IF /I [%%i]==[-Q] SET TWGETBATCHMODE=QUIET
			IF /I [%%i]==[-B] SET TWGETBATCHMODE=BATCH
			IF /I [%%i]==[-E_AEC] SET TWGETPARTIALMODE=E_AEC
			IF /I [%%i]==[-E_DPM] SET TWGETPARTIALMODE=E_DPM
			IF /I [%%i]==[-E_AEC_DPM] SET TWGETPARTIALMODE=E_AEC_DPM
			IF /I [%%i]==[-G_AEC] SET TWGETPARTIALMODE=G_AEC
			IF /I [%%i]==[-G_DPM] SET TWGETPARTIALMODE=G_DPM
			IF /I [%%i]==[-G_AEC_DPM] SET TWGETPARTIALMODE=G_AEC_DPM
			IF /I [%%i]==[-H] SET TW_Help_Screen=YES
			IF /I [%%i]==[-EXT] SET EXTRACTUTILS=YES
			IF /I [%%i]==[-SRC] SET TWGETSKIPRECORDCAPTURE=YES
			IF /I [%%i]==[-SRC] SET TWGETSKIPRECORDSORT=YES
			IF /I [%%i]==[-SRS] SET TWGETSKIPRECORDSORT=YES
			IF /I [%%i]==[-SWR] SET TWGETSKIPWINDOWSREPORTING=YES
			IF /I [%%i]==[-SCDA] SET TWGETSKIPCDA=YES
			IF /I [%%i]==[-SMR] SET TWGETSKIPMEGARAID=YES
			IF /I [%%i]==[-SHBA] SET TWGETSKIPHBA=YES
			IF /I [%%i]==[-SEXP] SET TWGETSKIPEXPANDER=YES
			IF /I [%%i]==[-SC] SET TWGETSKIPCOMPRESSION=YES

			IF /I [%%i]==[-F1] SET TWGETSKIPRECORDCAPTURE=YES
			IF /I [%%i]==[-F1] SET TWGETSKIPRECORDSORT=YES
			IF /I [%%i]==[-F1] SET TWGETSKIPWINDOWSREPORTING=YES

			IF /I [%%i]==[-F2] SET TWGETSKIPRECORDCAPTURE=YES
			IF /I [%%i]==[-F2] SET TWGETSKIPRECORDSORT=YES
			IF /I [%%i]==[-F2] SET TWGETSKIPCDA=YES

			IF /I [%%i]==[-F3] SET TWGETSKIPRECORDCAPTURE=YES
			IF /I [%%i]==[-F3] SET TWGETSKIPRECORDSORT=YES
			IF /I [%%i]==[-F3] SET TWGETSKIPWINDOWSREPORTING=YES
			IF /I [%%i]==[-F3] SET TWGETSKIPCDA=YES

			IF /I [%%i]==[-F4] SET TWGETSKIPRECORDCAPTURE=YES
			IF /I [%%i]==[-F4] SET TWGETSKIPRECORDSORT=YES
			IF /I [%%i]==[-F4] SET TWGETSKIPWINDOWSREPORTING=YES
			IF /I [%%i]==[-F4] SET TWGETSKIPCDA=YES
			IF /I [%%i]==[-F4] SET TWGETSKIPCOMPRESSION=YES
			)

REM ###########################################################################################################################
REM # Option Override
REM ###########################################################################################################################

IF [%EXTRACTUTILS%]==[YES] SET TWPRINTFILENAME=NO
IF [%EXTRACTUTILS%]==[YES] SET TWGETDIRECTORYKEEP=NO
IF [%EXTRACTUTILS%]==[YES] SET TWGETBATCHMODE=BATCH
IF [%EXTRACTUTILS%]==[YES] SET TW_Help_Screen=NO

IF NOT [%TWGETDIRECTORYKEEP%]==[YES]	(
					IF [%TWGETSKIPCOMPRESSION%]==[YES]	(
										@ECHO .
										@ECHO You can't skip compression without keeping the directory...						
 										@ECHO The -D parameter has been enabled...
										SET TWGETDIRECTORYKEEP=YES
										)
					)						

REM   .......................................||.......................................
@ECHO .............................Initial Variables SET.............................. >> misc_output.txt 2>&1
@ECHO "SET >> misc_output.txt 2>&1" >> misc_output.txt 2>&1
SET >> misc_output.txt 2>&1

REM ###########################################################################################################################
REM # Help Screen
REM ###########################################################################################################################

IF [%TW_Help_Screen%]==[YES] (GOTO Help_Screen) ELSE GOTO No_Help_Screen

:Help_Screen 
REM   .......................................||.......................................
@ECHO .
@ECHO Broadcom HBA/MegaRAID/Expander/NetExtreme Data Collection Script for Windows.
@ECHO This script will collect system logs and info as well as controller, disk and 
@ECHO enclosure info for debugging purposes. All files included in the original 
@ECHO BCMGet_xxxxxx.7z/zip file MUST be kept in the same subdir as BCMGet.bat.
@ECHO This script MUST be run from its own subdir, NOT pathed.
@ECHO .
@ECHO You MUST be an Administrator/have Admin rights to run this script. The latest
@ECHO version of this script can be obtained from your FAE;
@ECHO .
@ECHO Command Line Options:
@ECHO BCMGet [Comment] [Option(s)]		
@ECHO Comment: Enclose noncontiguous strings in double quotes "My Comments" 
@ECHO Option: 
@ECHO -EXT		= EXTRACT - Extracts all available utilities for use.
@ECHO -P		= PRINT filename in .\LSICAPTUREFILES.TXT for scripting.
@ECHO -D		= Working DIRECTORY is not deleted.
@ECHO -Q		= QUIET Mode - No keystrokes required unless error.
@ECHO -B		= BATCH Mode - No keystrokes required.
@ECHO -E_AEC		= Clear and ENABLE AEC.
@ECHO -E_DPM		= Clear and ENABLE DPMSTAT.
@ECHO -E_AEC_DPM	= Clear and ENABLE AEC and DPMSTAT.
@ECHO -G_AEC		= Disable and GET AEC Logs.
@ECHO -G_DPM		= Disable and GET DPMSTAT Logs.
@ECHO -G_AEC_DPM	= Disable and GET AEC and DPMSTAT Logs.
@ECHO -H		= This Help Screen.
@ECHO .
@ECHO The following command line options are NOT standard and may be detrimental 
@ECHO to a root cause analysis of your issue. Used for repetitive data collection
@ECHO and script debugging, these are fluid and may change.
REM   .......................................||.......................................
@ECHO .
@ECHO -SRS		= Skip MegaRAID AEN Record Sort, NOT standard.
@ECHO -SRC		= Skip MegaRAID AEN Record Capture and Sort, NOT standard.
@ECHO -SWR		= Skip Windows Reporting (MSINFO32), NOT standard.
@ECHO -SCDA		= Skip Controller Disk Association, NOT standard.
@ECHO -SMR		= Skip MegaRAID DATA Capture, NOT standard.
@ECHO -SHBA		= Skip HBA DATA Capture, NOT standard.
@ECHO -SEXP		= Skip Expander DATA Capture, NOT standard.
@ECHO -SC		= Skip Compression of output subdirectory, NOT standard.
@ECHO -F1		= FAST-1, combines -SRC/-SWR, NOT standard.
@ECHO -F2		= FAST-2, combines -SRC/-SCDA, NOT standard.
@ECHO -F3		= FAST-3, combines -SRC/-SWR/-SCDA, NOT standard.
@ECHO -F4		= FAST-4, combines -SRC/-SWR/-SCDA/-SC, NOT standard.
@ECHO .
@ECHO Example; BCMGet -B -D -Q "This is my comment"
@ECHO Runs the standard script leaving the working directory, without prompts 
@ECHO and leaves a comment.
@ECHO .
@ECHO Notes: 
@ECHO Send "JUST" the created .7z file to your support rep. 
@ECHO .
@ECHO EXT = EXTRACT - All of the embedded utilities that are in the pertinent 
@ECHO capture script are extracted without the actual capture script running.
@ECHO The Broadcom utilities such as storcli/scrutinycli/etc. are
@ECHO all copied to the root of the capture script subdir.
@ECHO All third party utilities are copied to that root\Utils, i.e. grep/sg_scan/etc.
@ECHO After each script run, Broadcom utilities without a device are copied to the 
@ECHO Utils subdir. On EACH run the Utils subdir is deleted.
@ECHO .
@ECHO AEC = Advanced Event Capture - This is an unreleased INTERNAL option. 
@ECHO Do NOT use AEC without being directed to by Technical Support or an FAE.
@ECHO .
@ECHO DPMSTAT = Disk Performance Monitoring Statistics - Captures performance
@ECHO related information on a controller/disk basis. Detailed information can 
@ECHO found in the MegaRAID Users Guides available at;
@ECHO .
@ECHO http://www.broadcom.com
@ECHO .
REM   .......................................||.......................................
@ECHO All of the -G_* "GET" Options are done automatically if AEC or DPMSTAT was
@ECHO enabled previously with the -E_* "ENABLE" options by default. The -G_* 
@ECHO options are meant for quick repetitive results without getting other system
@ECHO information. Normally you should run the standard BCMGet.bat file without
@ECHO a -G_* option to provide as much info as possible.
@ECHO .
@ECHO If there are competing comments the lowest variable number wins.
@ECHO If there are contradictory options the lowest variable number with the
@ECHO option order listed in the help wins. Valid combinations would be;
@ECHO -D or -D with -B or -Q any -E_* or -G_* option by itself or in conjunction
@ECHO with a -D and -B/-Q option. -E_* is allowed with -D but has no effect as 
@ECHO there is no working directory created.
@ECHO .
REM   .......................................||.......................................
@ECHO MegaRAID -
@ECHO This script should run with any controller 94xx, 95xx, 96xx family of controllers. 
@ECHO .
@ECHO HBA -
@ECHO This script should run with any controller 94xx, 95xx, 96xx family of controllers.
@ECHO .
@ECHO NetExtreme NIC -
@ECHO This script should run with any controller NetExtreme family of controllers.
@ECHO .
@ECHO Trouble Shooting - 
@ECHO .
@ECHO 1Q. Script appears to hang
@ECHO 1A. Dont enable Quick Edit mode. Also command windows have been seen to go to 
@ECHO sleep after a while (20-30 Minutes), hit return in the window to wake up.
@ECHO .
@ECHO Capture Script Version: %BCMGetVER%
@ECHO .

GOTO END_No_Pause

:No_Help_Screen


IF [%TWGETBATCHMODE%]==[BATCH] GOTO comment
IF [%TWGETBATCHMODE%]==[QUIET] GOTO comment
@ECHO .
@ECHO Its recommended to disable "QuickEdit Mode" on command prompt window
@ECHO that this script is run in under Properties/Options. Otherwise if you click in
@ECHO the Window you can get stuck in "Select" mode and the script will stop. If
@ECHO this happens you can hit return in the Window.
IF [%TWcomment%]==[] (GOTO no_comment) ELSE GOTO comment

REM ###########################################################################################################################
REM # Script not paused regardless of comment
REM ###########################################################################################################################
:no_comment
IF [%TWGETPARTIALMODE%]==[E_AEC] GOTO E_FROM_COMMENT
IF [%TWGETPARTIALMODE%]==[E_DPM] GOTO E_FROM_COMMENT
IF [%TWGETPARTIALMODE%]==[E_AEC_DPM] GOTO E_FROM_COMMENT
IF [%EXTRACTUTILS%]==[YES] GOTO E_FROM_COMMENT
REM   .......................................||.......................................
@ECHO .
@ECHO "BCMGet -H" provides a help screen.
@ECHO .
@ECHO To associate a user comment with this data capture session pass the
@ECHO comment as a variable. 
@ECHO .						  
@ECHO Example;
@ECHO BCMGet "Case 123456-123456789 - performance problems after upgrade"   
@ECHO .
@ECHO NOTE: Noncontiguous strings must be in double quotes "My Comments". 	  
@ECHO .
@ECHO .
@ECHO Hit CTRL-C to abort and use a comment or DO NOTHING TO CONTINUE...
:comment

REM ###########################################################################################################################
REM # reg test
REM ###########################################################################################################################

@ECHO Test if reg is present >> misc_output.txt 2>&1
reg /? >> misc_output.txt 2>&1
IF %ERRORLEVEL% == 0 (SET HAVE_REG=YES) ELSE SET HAVE_REG=NO

REM ###########################################################################################################################
REM # Windows Version Check
REM ###########################################################################################################################

SET TWver_name=OS_Unknown

Ver >> misc_output.txt 2>&1

Ver | %grep% "Version 10.0.22631" >> misc_output.txt 2>&1
IF %ERRORLEVEL% == 0    (
            SET TWver_name=Win11_23H2
            GOTO HAVE_VER
            )

Ver | %grep% "Version 10.0.22621" >> misc_output.txt 2>&1
IF %ERRORLEVEL% == 0    (
            SET TWver_name=Win11_22H2
            GOTO HAVE_VER
            )

Ver | %grep% "Version 10.0.22000" >> misc_output.txt 2>&1
IF %ERRORLEVEL% == 0    (
            SET TWver_name=Win11_21H2
            GOTO HAVE_VER
            )

Ver | %grep% "Version 10.0.19045" >> misc_output.txt 2>&1
IF %ERRORLEVEL% == 0    (
            SET TWver_name=Win10_22H2
            GOTO HAVE_VER
            )

Ver | %grep% "Version 10.0.19044" >> misc_output.txt 2>&1
IF %ERRORLEVEL% == 0    (
            SET TWver_name=Win10_21H2
            GOTO HAVE_VER
            )

Ver | %grep% "Version 10.0.19043" >> misc_output.txt 2>&1
IF %ERRORLEVEL% == 0    (
            SET TWver_name=Win10_21H1
            GOTO HAVE_VER
            )

Ver | %grep% "Version 10.0.19042" >> misc_output.txt 2>&1
IF %ERRORLEVEL% == 0    (
            SET TWver_name=Win10_20H2
            GOTO HAVE_VER
            )

Ver | %grep% "Version 10.0.19041" >> misc_output.txt 2>&1
IF %ERRORLEVEL% == 0    (
            SET TWver_name=Win10_20H1
            GOTO HAVE_VER
            )

Ver | %grep% "Version 10.0.18363" >> misc_output.txt 2>&1
IF %ERRORLEVEL% == 0    (
            SET TWver_name=Win10_19H2
            GOTO HAVE_VER
            )

Ver | %grep% "Version 10.0.18362" >> misc_output.txt 2>&1
IF %ERRORLEVEL% == 0    (
            SET TWver_name=Win10_19H1
            GOTO HAVE_VER
            )

Ver | %grep% "Version 10.0.17763" >> misc_output.txt 2>&1
IF %ERRORLEVEL% == 0    (
            SET TWver_name=Win10_1809
            GOTO HAVE_VER
            )

Ver | %grep% "Version 10.0.17134" >> misc_output.txt 2>&1
IF %ERRORLEVEL% == 0    (
            SET TWver_name=Win10_1803
            GOTO HAVE_VER
            )

ver | %grep% "Version 10.0.16229" >> misc_output.txt 2>&1
IF %ERRORLEVEL% == 0	(
			SET TWver_name=Win10_1709
			GOTO HAVE_VER
			)

ver | %grep% "Version 10.0.15063" >> misc_output.txt 2>&1
IF %ERRORLEVEL% == 0	(
			SET TWver_name=Win10_1703
			GOTO HAVE_VER
			)

Ver | %grep% "Version 10.0.14393" >> misc_output.txt 2>&1
IF %ERRORLEVEL% == 0    (
            SET TWver_name=Win10_1607
            GOTO HAVE_VER
            )

ver | %grep% "Version 10.0.10586" >> misc_output.txt 2>&1
IF %ERRORLEVEL% == 0	(
			SET TWver_name=Win10_1511
			GOTO HAVE_VER
			)

ver | %grep% "Version 10.0.10240" >> misc_output.txt 2>&1
IF %ERRORLEVEL% == 0	(
			SET TWver_name=Win10
			GOTO HAVE_VER
			)

:HAVE_VER

@ECHO At the HAVE_VER point >> misc_output.txt 2>&1
@ECHO %TWver_name% >> misc_output.txt 2>&1
@ECHO ver >> misc_output.txt 2>&1

:E_FROM_COMMENT

REM ###########################################################################################################################
REM # Extract Files
REM ###########################################################################################################################
@ECHO dir Prior to main file extraction >> misc_output.txt 2>&1
dir >> misc_output.txt 2>&1
@ECHO dir Utils Prior to main file extraction >> misc_output.txt 2>&1
dir Utils >> misc_output.txt 2>&1

7z e -y %all_cli% >> misc_output.txt 2>&1
IF [%NOWOW64%]==[YES] del timer.exe >> misc_output.txt 2>&1
IF [%NOWOW64%]==[YES] del xdir.exe >> misc_output.txt 2>&1
move /Y Sense-Key_ASC-ASCQ_Opcodes_ATA-Command_Codes-Set_Features_Code.txt Utils >> misc_output.txt 2>&1

7z x -y pciutils-3.2.1_64.7z >> misc_output.txt 2>&1
move /Y pciutils-3.2.1_64 Utils >> misc_output.txt 2>&1
copy Utils\pciutils-3.2.1_64\lspci.exe Utils >> misc_output.txt 2>&1
copy Utils\pciutils-3.2.1_64\pci.ids Utils >> misc_output.txt 2>&1
copy Utils\pciutils-3.2.1_64\*.dll Utils >> misc_output.txt 2>&1
SET lspci=Utils\lspci
7z x -y sg3_utils-1.42_64.7z >> misc_output.txt 2>&1
move /Y sg3_utils-1.42_64 Utils >> misc_output.txt 2>&1
copy Utils\sg3_utils-1.42_64\sg_scan.exe Utils >> misc_output.txt 2>&1
copy Utils\sg3_utils-1.42_64\sg_vpd.exe Utils >> misc_output.txt 2>&1
SET sg_scan=Utils\sg_scan
SET sg_vpd=Utils\sg_vpd
IF EXIST pciutils-3.2.1_64 rmdir /S /Q pciutils-3.2.1_64 >> misc_output.txt 2>&1
IF EXIST sg3_utils-1.42_64 rmdir /S /Q sg3_utils-1.42_64 >> misc_output.txt 2>&1

REM ###########################################################################################################################
REM # Test Scrutiny
REM ###########################################################################################################################

copy scrtnycli_x64.exe scl2.exe >> misc_output.txt 2>&1
.\scl2 --list >> misc_output.txt 2>&1
IF NOT ERRORLEVEL 1 SET NO_scl_EXP-IOC=NO

REM ###########################################################################################################################
REM # Test bnxtnvm
REM ###########################################################################################################################

.\bnxtnvm listdev >> misc_output.txt 2>&1
IF NOT ERRORLEVEL 1 SET NO_bnxtnvm=NO

REM ###########################################################################################################################
REM # Test niccli_x64
REM ###########################################################################################################################

.\niccli_x64 --listdev >> misc_output.txt 2>&1
IF NOT ERRORLEVEL 1 SET NO_niccli=NO


REM ###########################################################################################################################
REM # Test Storcli TODO need to add native file names of embedded utilities
REM ###########################################################################################################################

SET MR_Cli=storcli64.exe >> misc_output.txt 2>&1
SET MR_Cli2=storcli2.exe >> misc_output.txt 2>&1


@ECHO dir AFTER the main file extraction >> misc_output.txt 2>&1
dir >> misc_output.txt 2>&1
@ECHO dir Utils AFTER the main file extraction >> misc_output.txt 2>&1
dir Utils >> misc_output.txt 2>&1
@ECHO SET AFTER the main file extraction >> misc_output.txt 2>&1
SET >> misc_output.txt 2>&1

@ECHO "%MR_Cli% /call show | %grep% "Controller = " > pre_mr_ctrl_nums.txt 2>&1" >> misc_output.txt 2>&1
%MR_Cli% /call show | %grep% "Controller = " > pre_mr_ctrl_nums.txt 2>&1
@ECHO "type pre_mr_ctrl_nums.txt >> misc_output.txt 2>&1" >> misc_output.txt 2>&1
type pre_mr_ctrl_nums.txt >> misc_output.txt 2>&1
FOR /F "tokens=2 delims== " %%i in (pre_mr_ctrl_nums.txt) DO (@ECHO %%i >> mr_ctrl_nums.txt)

@ECHO "%MR_Cli2% /call show | %grep% "Controller = " > pre_mr2_ctrl_nums.txt 2>&1" >> misc_output.txt 2>&1
%MR_Cli2% /call show | %grep% "Controller = " > pre_mr2_ctrl_nums.txt 2>&1
@ECHO "type pre_mr2_ctrl_nums.txt >> misc_output.txt 2>&1" >> misc_output.txt 2>&1
type pre_mr2_ctrl_nums.txt >> misc_output.txt 2>&1
FOR /F "tokens=2 delims== " %%i in (pre_mr2_ctrl_nums.txt) DO (@ECHO %%i >> mr2_ctrl_nums.txt)

IF NOT EXIST mr_ctrl_nums.txt (SET NO_MR_Adps=YES) ELSE SET NO_MR_Adps=NO
IF NOT EXIST mr2_ctrl_nums.txt (SET NO_MR2_Adps=YES) ELSE SET NO_MR2_Adps=NO


REM ###########################################################################################################################
REM # temp files
REM ###########################################################################################################################

IF [%EXTRACTUTILS%]==[YES] (GOTO END_No_Pause)

IF NOT [%NO_LSI_HBAs%]==[YES] GOTO Continue_with_CLI

IF [%NO_MR_Adps%]==[YES] (GOTO NO_CLI_DRV_ETC )

GOTO Continue_with_CLI
REM ###########################################################################################################################
REM # TW_CLI not valid, no driver, controllers, etc.
REM ###########################################################################################################################

:NO_CLI_DRV_ETC
IF [%TWGETBATCHMODE%]==[BATCH] GOTO Continue_without_CLI
REM   .......................................||.......................................
@ECHO ...............................:NO_CLI_DRV_ETC.................................. >> misc_output.txt 2>&1
@ECHO "dir >> misc_output.txt 2>&1" >> misc_output.txt 2>&1
dir >> misc_output.txt 2>&1
IF EXIST cleanup_all.txt	(
				FOR /F "usebackq" %%i IN (cleanup_all.txt) DO	( 
										@ECHO "IF EXIST %%i del %%i >> misc_output.txt 2>&1" >> misc_output.txt 2>&1
										IF EXIST %%i del %%i >> misc_output.txt 2>&1
										@ECHO "dir >> misc_output.txt 2>&1" >> misc_output.txt 2>&1
										dir >> misc_output.txt 2>&1	
										)
				)

REM   .......................................||.......................................
@ECHO ................................................................................
@ECHO ####### No MegaRAID Raid Controllers or Broadcom HBAs are installed ########
@ECHO .
@ECHO "BCMGet -H" provides a help screen.
@ECHO .
IF [%TWGETBATCHMODE%]==[BATCH] GOTO Continue_without_CLI
@ECHO Hit CTRL-C to abort or ENTER to continue data collection without CLI support.
@ECHO .
PAUSE

:Continue_without_CLI
:Continue_with_CLI

REM ###########################################################################################################################
REM # Extract Files again may have been deleted
REM ###########################################################################################################################
7z e -y %all_cli% >> misc_output.txt 2>&1
move /Y Sense-Key_ASC-ASCQ_Opcodes_ATA-Command_Codes-Set_Features_Code.txt Utils >> misc_output.txt 2>&1

REM ###########################################################################################################################

			IF [%NO_MR_Adps%]==[YES]	(
						IF [%TWGETPARTIALMODE%]==[E_AEC] GOTO IF_NO_MR-No_AEC_or_DPMSTAT
						IF [%TWGETPARTIALMODE%]==[E_DPM] GOTO IF_NO_MR-No_AEC_or_DPMSTAT
						IF [%TWGETPARTIALMODE%]==[E_AEC_DPM] GOTO IF_NO_MR-No_AEC_or_DPMSTAT
						IF [%TWGETPARTIALMODE%]==[G_AEC] GOTO IF_NO_MR-No_AEC_or_DPMSTAT
						IF [%TWGETPARTIALMODE%]==[G_DPM] GOTO IF_NO_MR-No_AEC_or_DPMSTAT
						IF [%TWGETPARTIALMODE%]==[G_AEC_DPM] GOTO IF_NO_MR-No_AEC_or_DPMSTAT
						
						GOTO YES_MR_Controller
						:IF_NO_MR-No_AEC_or_DPMSTAT
						@ECHO ......................:IF_NO_MR-No_AEC_or_DPMSTAT...................... >> misc_output.txt 2>&1
						@ECHO "dir >> misc_output.txt 2>&1" >> misc_output.txt 2>&1
						dir >> misc_output.txt 2>&1
						REM   .......................................||.......................................
						@ECHO .
						@ECHO The command line switches;
						@ECHO -E_AEC
						@ECHO -E_DPM
						@ECHO -E_AEC_DPM
						@ECHO -G_AEC
						@ECHO -G_DPM
						@ECHO -G_AEC_DPM
						@ECHO .
						@ECHO can ONLY be used if a MegaRAID controller is installed...
						@ECHO Ignoring G_* options, exiting if E_* options...
						@ECHO %TWGETPARTIALMODE%
						@ECHO . 
						IF [%TWGETPARTIALMODE%]==[E_AEC] GOTO END_No_Pause
						IF [%TWGETPARTIALMODE%]==[E_DPM] GOTO END_No_Pause
						IF [%TWGETPARTIALMODE%]==[E_AEC_DPM] GOTO END_No_Pause
						SET TWGETPARTIALMODE=STANDARD
						@ECHO . >> misc_output.txt 2>&1
						@ECHO The command line switches; >> misc_output.txt 2>&1
						@ECHO -E_AEC >> misc_output.txt 2>&1
						@ECHO -E_DPM >> misc_output.txt 2>&1
						@ECHO -E_AEC_DPM >> misc_output.txt 2>&1
						@ECHO -G_AEC >> misc_output.txt 2>&1
						@ECHO -G_DPM >> misc_output.txt 2>&1
						@ECHO -G_AEC_DPM >> misc_output.txt 2>&1
						@ECHO . >> misc_output.txt 2>&1
						@ECHO can ONLY be used if a MegaRAID controller is installed... >> misc_output.txt 2>&1
						@ECHO Ignoring G_* options, exiting if E_* options... >> misc_output.txt 2>&1
						@ECHO %TWGETPARTIALMODE% >> misc_output.txt 2>&1
						@ECHO . >> misc_output.txt 2>&1
						@ECHO SET TWGETPARTIALMODE= >> misc_output.txt 2>&1
						@ECHO . >> misc_output.txt 2>&1 
						@ECHO IF [%TWGETPARTIALMODE%]==[E_AEC] GOTO END_No_Pause >> misc_output.txt 2>&1
						@ECHO IF [%TWGETPARTIALMODE%]==[E_DPM] GOTO END_No_Pause >> misc_output.txt 2>&1
						@ECHO IF [%TWGETPARTIALMODE%]==[E_AEC_DPM] GOTO END_No_Pause >> misc_output.txt 2>&1
						@ECHO SET TWGETPARTIALMODE=STANDARD >> misc_output.txt 2>&1
						)

	
:YES_MR_Controller

REM ###########################################################################################################################
REM # Subdirectory Name / File Name Creation
REM ###########################################################################################################################

IF [%TWGETPARTIALMODE%]==[STANDARD] SET TW-FN=BCM.%TWver_name%.%COMPUTERNAME%.%tw_date%.%tw_time%
IF [%TWGETPARTIALMODE%]==[G_AEC] SET TW-FN=AEC.%TWver_name%.%COMPUTERNAME%.%tw_date%.%tw_time%
IF [%TWGETPARTIALMODE%]==[G_DPM] SET TW-FN=DPMSTAT.%TWver_name%.%COMPUTERNAME%.%tw_date%.%tw_time%
IF [%TWGETPARTIALMODE%]==[G_AEC_DPM] SET TW-FN=AEC_DPMSTAT.%TWver_name%.%COMPUTERNAME%.%tw_date%.%tw_time%

IF [%TWGETPARTIALMODE%]==[STANDARD] GOTO PRINTFILENAME
IF [%TWGETPARTIALMODE%]==[G_AEC] GOTO PRINTFILENAME
IF [%TWGETPARTIALMODE%]==[G_DPM] GOTO PRINTFILENAME
IF [%TWGETPARTIALMODE%]==[G_AEC_DPM] GOTO PRINTFILENAME
GOTO DONTPRINTFILENAME
:PRINTFILENAME
IF [%TWPRINTFILENAME%]==[YES] ECHO %TW-FN%.7z >> LSICAPTUREFILES.TXT
:DONTPRINTFILENAME

IF [%TWGETPARTIALMODE%]==[E_AEC] SET TW-WS=.\
IF [%TWGETPARTIALMODE%]==[E_DPM] SET TW-WS=.\
IF [%TWGETPARTIALMODE%]==[E_AEC_DPM] SET TW-WS=.\
IF [%TWGETPARTIALMODE%]==[STANDARD] SET TW-WS=%TW-FN%\script_workspace\
IF [%TWGETPARTIALMODE%]==[G_AEC] SET TW-WS=%TW-FN%\script_workspace\
IF [%TWGETPARTIALMODE%]==[G_DPM] SET TW-WS=%TW-FN%\script_workspace\
IF [%TWGETPARTIALMODE%]==[G_AEC_DPM] SET TW-WS=%TW-FN%\script_workspace\

IF [%TWGETPARTIALMODE%]==[E_AEC] GOTO E_AEC1
IF [%TWGETPARTIALMODE%]==[E_DPM] GOTO E_DPM1
IF [%TWGETPARTIALMODE%]==[E_AEC_DPM] GOTO E_AEC_DPM1

REM ###########################################################################################################################
REM # The following is for TWGETPARTIALMODE = G_*, STANDARD or MONITOR
REM ###########################################################################################################################

IF NOT [%NOWOW64%]==[YES] (MKDIR Utils\timer_comp >> misc_output.txt 2>&1)
MKDIR %TW-FN% >> misc_output.txt 2>&1
MKDIR %TW-FN%\script_workspace >> misc_output.txt 2>&1
IF NOT [%NOWOW64%]==[YES]	(
				MKDIR %TW-FN%\script_workspace\timers >> misc_output.txt 2>&1
				MKDIR %TW-FN%\script_workspace\timers\timer1 >> misc_output.txt 2>&1
				MKDIR %TW-FN%\script_workspace\timers\timer2 >> misc_output.txt 2>&1
				MKDIR %TW-FN%\script_workspace\timers\timer3 >> misc_output.txt 2>&1
				MKDIR %TW-FN%\script_workspace\timers\timer4 >> misc_output.txt 2>&1
				MKDIR %TW-FN%\script_workspace\timers\timer5 >> misc_output.txt 2>&1
				MKDIR %TW-FN%\script_workspace\timers\timer6 >> misc_output.txt 2>&1
				MKDIR %TW-FN%\script_workspace\timers\timer7 >> misc_output.txt 2>&1
				MKDIR %TW-FN%\script_workspace\timers\timer8 >> misc_output.txt 2>&1
				MKDIR %TW-FN%\script_workspace\timers\timer9 >> misc_output.txt 2>&1
				MKDIR %TW-FN%\script_workspace\timers\timer10 >> misc_output.txt 2>&1
				MKDIR %TW-FN%\script_workspace\timers\timer100 >> misc_output.txt 2>&1
				
				copy timer.exe %TW-WS%timers\timer1\timer1.exe >> misc_output.txt 2>&1
				copy timer.exe %TW-WS%timers\timer2\timer2.exe >> misc_output.txt 2>&1
				copy timer.exe %TW-WS%timers\timer3\timer3.exe >> misc_output.txt 2>&1
				copy timer.exe %TW-WS%timers\timer4\timer4.exe >> misc_output.txt 2>&1
				copy timer.exe %TW-WS%timers\timer5\timer5.exe >> misc_output.txt 2>&1
				copy timer.exe %TW-WS%timers\timer6\timer6.exe >> misc_output.txt 2>&1
				copy timer.exe %TW-WS%timers\timer7\timer7.exe >> misc_output.txt 2>&1
				copy timer.exe %TW-WS%timers\timer8\timer8.exe >> misc_output.txt 2>&1
				copy timer.exe %TW-WS%timers\timer9\timer9.exe >> misc_output.txt 2>&1
				copy timer.exe %TW-WS%timers\timer10\timer10.exe >> misc_output.txt 2>&1
				copy timer.exe %TW-WS%timers\timer100\timer100.exe >> misc_output.txt 2>&1
				copy timer.exe Utils\timer_comp\timer_comp.exe >> misc_output.txt 2>&1
				)

IF EXIST adpcount.txt copy adpcount.txt %TW-WS% >> misc_output.txt 2>&1
IF EXIST adpcount_1.txt copy adpcount_1.txt %TW-WS% >> misc_output.txt 2>&1
IF EXIST num_mraid_adapters.txt copy num_mraid_adapters.txt %TW-WS% >> misc_output.txt 2>&1
IF EXIST adp_nums.txt copy adp_nums.txt %TW-WS% >> misc_output.txt 2>&1
IF EXIST pre_mr_ctrl_nums.txt copy pre_mr_ctrl_nums.txt %TW-WS% >> misc_output.txt 2>&1
IF EXIST mr_ctrl_nums.txt copy mr_ctrl_nums.txt %TW-WS% >> misc_output.txt 2>&1
IF EXIST pre_mr2_ctrl_nums.txt copy pre_mr2_ctrl_nums.txt %TW-WS% >> misc_output.txt 2>&1
IF EXIST mr2_ctrl_nums.txt copy mr2_ctrl_nums.txt %TW-WS% >> misc_output.txt 2>&1


copy BCMGet.bat %TW-WS% >> misc_output.txt 2>&1
copy aens_mr.txt %TW-WS% >> misc_output.txt 2>&1
copy MegaRAID_Driver_Event_Codes.txt %TW-WS% >> misc_output.txt 2>&1



REM Used in AEN Sort
@ECHO Info > %TW-WS%mr_aen_types.txt
@ECHO Warning >> %TW-WS%mr_aen_types.txt
@ECHO Critical >> %TW-WS%mr_aen_types.txt
@ECHO Fatal >> %TW-WS%mr_aen_types.txt
@ECHO Progress >> %TW-WS%mr_aen_types.txt
@ECHO Obsolete >> %TW-WS%mr_aen_types.txt

@ECHO %BCMGetVER% > %TW-WS%BCMGet_version.txt

REM Creating comment
IF NOT [%TWcomment%]==[] @ECHO %TWcomment% > %TW-FN%\comment.txt

REM ###########################################################################################################################
REM # -E_* functions without a subdir
REM ###########################################################################################################################

:E_AEC1
:E_DPM1
:E_AEC_DPM1


REM ###########################################################################################################################
REM Starting Controller_Cx.txt files
REM ###########################################################################################################################

IF [%TWGETPARTIALMODE%]==[E_AEC] GOTO START_MR_STORCLI
IF [%TWGETPARTIALMODE%]==[E_DPM] GOTO START_MR_STORCLI
IF [%TWGETPARTIALMODE%]==[E_AEC_DPM] GOTO START_MR_STORCLI
IF [%TWGETPARTIALMODE%]==[G_AEC] GOTO START_MR_STORCLI
IF [%TWGETPARTIALMODE%]==[G_DPM] GOTO START_MR_STORCLI
IF [%TWGETPARTIALMODE%]==[G_AEC_DPM] GOTO START_MR_STORCLI

REM ###########################################################################################################################
REM Starting scl2 96xx RAID Data Collection
REM ###########################################################################################################################
SET SCL296XXRAID=%time%
IF NOT [%TWGETSKIPHBA%]==[YES]	(
				IF NOT [%NO_scl_EXP-IOC%]==[YES]	(
									.\scl2 --list | find "RAID" >> %TW-WS%sc2_gen4_MR_hbas_raw.txt 2>&1 
									IF EXIST %TW-WS%sc2_gen4_MR_hbas_raw.txt dir %TW-WS%sc2_gen4_MR_hbas_raw.txt | %grep% " 0 sc2_gen4_MR_hbas_raw.txt" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1 move %TW-WS%sc2_gen4_MR_hbas_raw.txt %TW-WS%0Byte_sc2_gen4_MR_hbas_raw.txt >> misc_output.txt 2>&1
									IF EXIST %TW-WS%sc2_gen4_MR_hbas_raw.txt	(
													 	SET NO_scl_IOC=NO
														@ECHO IN__scl2_MR4_Branch_1 >> misc_output.txt 2>&1
														IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products
														IF NOT EXIST %TW-FN%\Broadcom_Products\MegaRAID mkdir %TW-FN%\Broadcom_Products\MegaRAID
														IF NOT EXIST %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID mkdir %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID
														.\scl2 --list | find "RAID" > %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\sc2_MR4_hbas.txt
														FOR /F delims^=^)^ tokens^=1 %%i in (%TW-WS%sc2_gen4_MR_hbas_raw.txt) DO (@ECHO %%i >> %TW-WS%sc2_gen4_MR_hbas_raw1.txt)
														FOR /F "tokens=1 delims= " %%i in (%TW-WS%sc2_gen4_MR_hbas_raw1.txt) DO (@ECHO %%i >> %TW-WS%sc2_gen3_MR_hba_nums.txt)
														@ECHO IN__scl2_MR4_Branch_2 >> misc_output.txt 2>&1
														FOR /F "tokens=1" %%i in (%TW-WS%sc2_gen3_MR_hba_nums.txt) DO	(
																						@ECHO IN__scl2_MR4_Branch_3 >> misc_output.txt 2>&1
																						.\scl2 -i %%i ctrl -wwid | find "IOC WWID" > %TW-WS%sc2_MR_hba_%%i_sasaddr.txt
																						FOR /F "tokens=3 delims=: " %%j in (%TW-WS%sc2_MR_hba_%%i_sasaddr.txt) DO (@ECHO %%j > %TW-WS%sc2_MR_hba_%%i_sasaddr1.txt)																				
																						FOR /F "tokens=1" %%j in (%TW-WS%sc2_MR_hba_%%i_sasaddr1.txt) DO	(
																														@ECHO IN__scl2_MR4_Branch_4_HBA%%i >> misc_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO .
																														@ECHO Starting the log collection for 96xx_RAID hba%%i SAS Address %%j
																														@ECHO ................................events collection.............................. >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_uploads_hba%%i.txt 2>&1
																														IF EXIST eventlog.txt del eventlog.txt >> misc_output.txt 2>&1
																														.\scl2 -i %%i events -o eventlog.txt >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_uploads_hba%%i.txt 2>&1
																														IF EXIST eventlog.txt copy eventlog.txt %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_eventlog_hba%%i.txt >> misc_output.txt >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_uploads_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop show cfg all.................................... >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_iop_show_cfg_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show cfg all >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_iop_show_cfg_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................show -all.................................... >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i show -all >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop show ver.................................... >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show ver >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop show flashmap.................................... >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show flashmap >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop show temperature.................................... >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show temperature >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop show rtconfig................................... >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show rtconfig >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop personality................................... >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop personality >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................show -fwheader............................... >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i show -fwheader >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cfg -nondefault.............................. >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cfg -nondefault >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ....................................phy -da.................................... >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -da >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ...................................phy -port................................... >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -port >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ....................................phy -rates.................................... >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -rates >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ...................................phy -err.................................... >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -err >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................ioc -displaysas................................ >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i ioc -displaysas >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................ioc -displaypcie................................ >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i ioc -displaypcie >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................cli pl pci lnkcfg................................ >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl pci lnkcfg >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................cli pl show acm....................................... >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl show acm >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................cli pl show status.................................... >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl show status >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................cli pl show vSES.................................... >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl show vses >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................cli pl show ubm.................................... >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl show ubm >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................scan......................................... >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i scan >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................scan -l...................................... >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i scan -l >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cfg -dumpall................................. >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cfg -dumpall >> %TW-FN%\Broadcom_Products\MegaRAID\96xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														)
																						)	
														)
													)
									)
								
REM ###########################################################################################################################
REM Starting scl2 96xx Perf-IT Data Collection # This code does not run in MR8.1 since all are eHBA or RAID
REM ###########################################################################################################################
SET SCL296XXPERFIT=%time%
IF NOT [%TWGETSKIPHBA%]==[YES]	(
				IF NOT [%NO_scl_EXP-IOC%]==[YES]	(
									.\scl2 --list | find "Perf-IT" >> %TW-WS%sc2_gen4_PerfIT_hbas_raw.txt 2>&1 
									IF EXIST %TW-WS%sc2_gen4_PerfIT_hbas_raw.txt dir %TW-WS%sc2_gen4_PerfIT_hbas_raw.txt | %grep% " 0 sc2_gen4_PerfIT_hbas_raw.txt" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1 move %TW-WS%sc2_gen4_PerfIT_hbas_raw.txt %TW-WS%0Byte_sc2_gen4_PerfIT_hbas_raw.txt >> misc_output.txt 2>&1
									IF EXIST %TW-WS%sc2_gen4_PerfIT_hbas_raw.txt	(
													 	SET NO_scl_IOC=NO
														@ECHO IN__scl2_IOC4_Branch_1 >> misc_output.txt 2>&1
														IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products
														IF NOT EXIST %TW-FN%\Broadcom_Products\HBA mkdir %TW-FN%\Broadcom_Products\HBA
														IF NOT EXIST %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT mkdir %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT
														.\scl2 --list | find "Perf-IT" > %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\PerfIT_hbas_list.txt
														FOR /F delims^=^)^ tokens^=1 %%i in (%TW-WS%sc2_gen4_PerfIT_hbas_raw.txt) DO (@ECHO %%i >> %TW-WS%sc2_gen4_PerfIT_hbas_raw1.txt)
														FOR /F "tokens=1 delims= " %%i in (%TW-WS%sc2_gen4_PerfIT_hbas_raw1.txt) DO (@ECHO %%i >> %TW-WS%sc2_gen4_PerfIT_nums.txt)
														@ECHO IN__scl2_IOC4_Branch_2 >> misc_output.txt 2>&1
														FOR /F "tokens=1" %%i in (%TW-WS%sc2_gen4_PerfIT_nums.txt) DO	(
																						@ECHO IN__scl2_IOC4_Branch_3 >> misc_output.txt 2>&1
																						.\scl2 -i %%i ctrl -wwid | find "IOC WWID" > %TW-WS%sc2_hba_%%i_sasaddr.txt
																						FOR /F "tokens=3 delims=: " %%j in (%TW-WS%sc2_hba_%%i_sasaddr.txt) DO (@ECHO %%j > %TW-WS%sc2_hba_%%i_sasaddr1.txt)																				
																						FOR /F "tokens=1" %%j in (%TW-WS%sc2_hba_%%i_sasaddr1.txt) DO	(
																														@ECHO IN__scl2_IOC4_Branch_4_HBA%%i >> misc_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO .
																														@ECHO Starting the log collection for 96xx_Perf-IT hba%%i SAS Address %%j
																														@ECHO ..................................cli iop show cfg all.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_iop_show_cfg_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show cfg all >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_iop_show_cfg_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................show -all.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i show -all >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop show ver.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show ver >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop show flashmap.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show flashmap >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop show temperature.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show temperature >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop show rtconfig................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show rtconfig >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop personality................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop personality >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................show -fwheader............................... >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i show -fwheader >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cfg -nondefault.............................. >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cfg -nondefault >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ....................................phy -da.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -da >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ...................................phy -port................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -port >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ....................................phy -rates.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -rates >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ...................................phy -err.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -err >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................ioc -displaysas................................ >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i ioc -displaysas >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................ioc -displaypcie................................ >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i ioc -displaypcie >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................cli pl pci lnkcfg................................ >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl pci lnkcfg >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................cli pl show acm....................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl show acm >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................cli pl show status.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl show status >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................cli pl show vSES.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl show vses >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................cli pl show ubm.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl show ubm >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................scan......................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i scan >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................scan -l...................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i scan -l >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cfg -dumpall................................. >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cfg -dumpall >> %TW-FN%\Broadcom_Products\HBA\96xx_PerfIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														)
																						)	
														)
													)
									)
REM ###########################################################################################################################
REM Starting scl2 96xx FeatureIT Data Collection # This code does not run in MR8.1 since all are eHBA or RAID
REM ###########################################################################################################################
SET SCL296XXFeatureIT=%time%
IF NOT [%TWGETSKIPHBA%]==[YES]	(
				IF NOT [%NO_scl_EXP-IOC%]==[YES]	(
									.\scl2 --list | find "FeatureIT" >> %TW-WS%sc2_gen4_FeatureIT_hbas_raw.txt 2>&1 
									IF EXIST %TW-WS%sc2_gen4_FeatureIT_hbas_raw.txt dir %TW-WS%sc2_gen4_FeatureIT_hbas_raw.txt | %grep% " 0 sc2_gen4_FeatureIT_hbas_raw.txt" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1 move %TW-WS%sc2_gen4_FeatureIT_hbas_raw.txt %TW-WS%0Byte_sc2_gen4_FeatureIT_hbas_raw.txt >> misc_output.txt 2>&1
									IF EXIST %TW-WS%sc2_gen4_FeatureIT_hbas_raw.txt	(
													 	SET NO_scl_IOC=NO
														@ECHO IN__scl2_IOC4_Branch_1 >> misc_output.txt 2>&1
														IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products
														IF NOT EXIST %TW-FN%\Broadcom_Products\HBA mkdir %TW-FN%\Broadcom_Products\HBA
														IF NOT EXIST %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT mkdir %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT
														.\scl2 --list | find "FeatureIT" > %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\FeatureIT_hbas_list.txt
														FOR /F delims^=^)^ tokens^=1 %%i in (%TW-WS%sc2_gen4_FeatureIT_hbas_raw.txt) DO (@ECHO %%i >> %TW-WS%sc2_gen4_FeatureIT_hbas_raw1.txt)
														FOR /F "tokens=1 delims= " %%i in (%TW-WS%sc2_gen4_FeatureIT_hbas_raw1.txt) DO (@ECHO %%i >> %TW-WS%sc2_gen4_FeatureIT_nums.txt)
														@ECHO IN__scl2_IOC4_Branch_2 >> misc_output.txt 2>&1
														FOR /F "tokens=1" %%i in (%TW-WS%sc2_gen4_FeatureIT_nums.txt) DO	(
																						@ECHO IN__scl2_IOC4_Branch_3 >> misc_output.txt 2>&1
																						.\scl2 -i %%i ctrl -wwid | find "IOC WWID" > %TW-WS%sc2_hba_%%i_sasaddr.txt
																						FOR /F "tokens=3 delims=: " %%j in (%TW-WS%sc2_hba_%%i_sasaddr.txt) DO (@ECHO %%j > %TW-WS%sc2_hba_%%i_sasaddr1.txt)																				
																						FOR /F "tokens=1" %%j in (%TW-WS%sc2_hba_%%i_sasaddr1.txt) DO	(
																														@ECHO IN__scl2_IOC4_Branch_4_HBA%%i >> misc_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO .
																														@ECHO Starting the log collection for 96xx_FeatureIT hba%%i SAS Address %%j
																														@ECHO ..................................cli iop show cfg all.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_iop_show_cfg_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show cfg all >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_iop_show_cfg_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................show -all.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_iop_show_cfg_hba%%i.txt 2>&1
																														.\scl2 -i %%i show -all >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop show ver.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show ver >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop show flashmap.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show flashmap >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop show temperature.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show temperature >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop show rtconfig................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show rtconfig >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop personality................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop personality >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................show -fwheader............................... >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i show -fwheader >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cfg -nondefault.............................. >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cfg -nondefault >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ....................................phy -da.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -da >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ...................................phy -port................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -port >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ....................................phy -rates.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -rates >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ...................................phy -err.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -err >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................ioc -displaysas................................ >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i ioc -displaysas >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................ioc -displaypcie................................ >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i ioc -displaypcie >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................cli pl pci lnkcfg................................ >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl pci lnkcfg >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................cli pl show acm....................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl show acm >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................cli pl show status.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl show status >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................cli pl show vSES.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl show vses >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................cli pl show ubm.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl show ubm >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................scan......................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i scan >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................scan -l...................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i scan -l >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cfg -dumpall................................. >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cfg -dumpall >> %TW-FN%\Broadcom_Products\HBA\96xx_FeatureIT\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														)
																						)	
														)
													)
									)
REM ###########################################################################################################################
REM Starting scl2 96xx eHBA Data Collection
REM ###########################################################################################################################
SET SCL296XXEHBA=%time%
IF NOT [%TWGETSKIPHBA%]==[YES]	(
				IF NOT [%NO_scl_EXP-IOC%]==[YES]	(
									.\scl2 --list | find "eHBA" >> %TW-WS%sc2_gen4_eHBA_hbas_raw.txt 2>&1 
									IF EXIST %TW-WS%sc2_gen4_eHBA_hbas_raw.txt dir %TW-WS%sc2_gen4_eHBA_hbas_raw.txt | %grep% " 0 sc2_gen4_eHBA_hbas_raw.txt" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1 move %TW-WS%sc2_gen4_eHBA_hbas_raw.txt %TW-WS%0Byte_sc2_gen4_eHBA_hbas_raw.txt >> misc_output.txt 2>&1
									IF EXIST %TW-WS%sc2_gen4_eHBA_hbas_raw.txt	(
													 	SET NO_scl_IOC=NO
														@ECHO IN__scl2_IOC4_Branch_1 >> misc_output.txt 2>&1
														IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products
														IF NOT EXIST %TW-FN%\Broadcom_Products\HBA mkdir %TW-FN%\Broadcom_Products\HBA
														IF NOT EXIST %TW-FN%\Broadcom_Products\HBA\96xx_eHBA mkdir %TW-FN%\Broadcom_Products\HBA\96xx_eHBA
														.\scl2 --list | find "eHBA" > %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\eHBA_hbas_list.txt
														FOR /F delims^=^)^ tokens^=1 %%i in (%TW-WS%sc2_gen4_eHBA_hbas_raw.txt) DO (@ECHO %%i >> %TW-WS%sc2_gen4_eHBA_hbas_raw1.txt)
														FOR /F "tokens=1 delims= " %%i in (%TW-WS%sc2_gen4_eHBA_hbas_raw1.txt) DO (@ECHO %%i >> %TW-WS%sc2_gen4_eHBA_nums.txt)
														@ECHO IN__scl2_IOC4_Branch_2 >> misc_output.txt 2>&1
														FOR /F "tokens=1" %%i in (%TW-WS%sc2_gen4_eHBA_nums.txt) DO	(
																						@ECHO IN__scl2_IOC4_Branch_3 >> misc_output.txt 2>&1
																						.\scl2 -i %%i ctrl -wwid | find "IOC WWID" > %TW-WS%sc2_hba_%%i_sasaddr.txt
																						FOR /F "tokens=3 delims=: " %%j in (%TW-WS%sc2_hba_%%i_sasaddr.txt) DO (@ECHO %%j > %TW-WS%sc2_hba_%%i_sasaddr1.txt)																				
																						FOR /F "tokens=1" %%j in (%TW-WS%sc2_hba_%%i_sasaddr1.txt) DO	(
																														@ECHO IN__scl2_IOC4_Branch_4_HBA%%i >> misc_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO .
																														@ECHO Starting the log collection for 96xx_eHBA hba%%i SAS Address %%j
																														@ECHO ..................................cli iop show cfg all.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_iop_show_cfg_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show cfg all >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_iop_show_cfg_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................show -all.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i show -all >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop show ver.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show ver >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop show flashmap.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show flashmap >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop show temperature.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show temperature >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop show rtconfig................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop show rtconfig >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cli iop personality................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli iop personality >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................show -fwheader............................... >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i show -fwheader >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cfg -nondefault.............................. >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cfg -nondefault >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ....................................phy -da.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -da >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ...................................phy -port................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -port >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ....................................phy -rates.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -rates >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ...................................phy -err.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -err >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................ioc -displaysas................................ >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i ioc -displaysas >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................ioc -displaypcie................................ >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i ioc -displaypcie >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................cli pl pci lnkcfg................................ >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl pci lnkcfg >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................cli pl show acm....................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl show acm >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................cli pl show status.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl show status >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................cli pl show vSES.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl show vses >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................cli pl show ubm.................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl show ubm >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................scan......................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i scan >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................scan -l...................................... >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i scan -l >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................cfg -dumpall................................. >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cfg -dumpall >> %TW-FN%\Broadcom_Products\HBA\96xx_eHBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														)
																						)	
														)
													)
									)
REM ###########################################################################################################################
REM Starting scl2 95xx RAID Data Collection
REM ###########################################################################################################################
SET SCL295XXRAID=%time%
IF NOT [%TWGETSKIPHBA%]==[YES]	(
				IF NOT [%NO_scl_EXP-IOC%]==[YES]	(
									.\scl2 --list | find "MR" >> %TW-WS%sc2_gen3.5_MR_hbas_raw.txt 2>&1 
									IF EXIST %TW-WS%sc2_gen3.5_MR_hbas_raw.txt dir %TW-WS%sc2_gen3.5_MR_hbas_raw.txt | %grep% " 0 sc2_gen3.5_MR_hbas_raw.txt" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1 move %TW-WS%sc2_gen3.5_MR_hbas_raw.txt %TW-WS%0Byte_sc2_gen3.5_MR_hbas_raw.txt >> misc_output.txt 2>&1
									IF EXIST %TW-WS%sc2_gen3.5_MR_hbas_raw.txt	(
													 	SET NO_scl_IOC=NO
														@ECHO IN__scl2_MR3.5_MR_Branch_1 >> misc_output.txt 2>&1
														IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products
														IF NOT EXIST %TW-FN%\Broadcom_Products\MegaRAID mkdir %TW-FN%\Broadcom_Products\MegaRAID
														IF NOT EXIST %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID mkdir %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID
														.\scl2 --list | find "MR" > %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\sc2_MR3.5_hbas.txt
														FOR /F delims^=^)^ tokens^=1 %%i in (%TW-WS%sc2_gen3.5_MR_hbas_raw.txt) DO (@ECHO %%i >> %TW-WS%sc2_gen3.5_MR_hbas_raw1.txt)
														FOR /F "tokens=1 delims= " %%i in (%TW-WS%sc2_gen3.5_MR_hbas_raw1.txt) DO (@ECHO %%i >> %TW-WS%sc2_gen3.5_MR_hba_nums.txt)
														@ECHO IN__scl2_MR3.5_MR_Branch_2 >> misc_output.txt 2>&1
														FOR /F "tokens=1" %%i in (%TW-WS%sc2_gen3.5_MR_hba_nums.txt) DO	(
																						@ECHO IN__scl2_MR3.5_MR_Branch_3 >> misc_output.txt 2>&1
																						.\scl2 -i %%i roc -wwid | find "SAS Address" > %TW-WS%sc2_MR_hba_%%i_sasaddr.txt
																						FOR /F "tokens=3,4 delims=: " %%j in (%TW-WS%sc2_MR_hba_%%i_sasaddr.txt) DO (@ECHO %%j%%k > %TW-WS%sc2_MR_hba_%%i_sasaddr1.txt)																				
																						FOR /F "tokens=1" %%j in (%TW-WS%sc2_MR_hba_%%i_sasaddr1.txt) DO	(
																														@ECHO IN__scl2_MR3.5_MR_Branch_4_HBA%%i >> misc_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO .
																														@ECHO Starting the log collection for 95xx_RAID hba%%i SAS Address %%j
																														@ECHO ................................vpd collection.............................. >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_uploads_hba%%i.txt 2>&1
																														IF EXIST vpd.bin del vpd.bin >> misc_output.txt 2>&1
																														.\scl2 -i %%i vpd -get -b vpd.bin >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_uploads_hba%%i.txt 2>&1
																														move vpd.bin %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_vpd_hba%%i.bin >> misc_output.txt >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_uploads_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................mfc collection.............................. >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_uploads_hba%%i.txt 2>&1
																														IF EXIST mfc.ini del mfc.ini >> misc_output.txt 2>&1
																														.\scl2 -i %%i mfc -get mfc.ini >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_uploads_hba%%i.txt 2>&1
																														move mfc.ini %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_mfc_hba%%i.ini >> misc_output.txt >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_uploads_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................events collection.............................. >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_uploads_hba%%i.txt 2>&1
																														IF EXIST eventlog.txt del eventlog.txt >> misc_output.txt 2>&1
																														.\scl2 -i %%i events -o eventlog.txt >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_uploads_hba%%i.txt 2>&1
																														move eventlog.txt %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_eventlog_hba%%i.txt >> misc_output.txt >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_uploads_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................fwtermlog collection.............................. >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_uploads_hba%%i.txt 2>&1
																														IF EXIST fwtermlog.txt del fwtermlog.txt >> misc_output.txt 2>&1
																														.\scl2 -i %%i termlogs -o fwtermlog.txt >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_uploads_hba%%i.txt 2>&1
																														move fwtermlog.txt %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_fwtermlog_hba%%i.txt >> misc_output.txt >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_uploads_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................show -all............................... >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i show -all >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................show -clkmode............................... >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i show -clkmode >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................show -oob............................... >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i show -oob >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................scan......................................... >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i scan >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................scan -l.............................. >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i scan -l >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ....................................energypack.................................... >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i energypack >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ...................................roc -suboem................................... >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i roc -suboem >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ....................................roc -profile.................................... >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i roc -profile >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ...................................roc -ocr.................................... >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i roc -ocr >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................events -info................................ >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i events -info >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................phy -da................................ >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -da >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................phy -err....................................... >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -err >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................phy -speed.................................... >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -speed >> %TW-FN%\Broadcom_Products\MegaRAID\95xx_RAID\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														)
																						)	
														)
													)
									)	
									
REM ###########################################################################################################################
REM Starting scl2 94xx, 95xx HBA Data Collection
REM ###########################################################################################################################
SET SCL295XXHBA=%time%
IF NOT [%TWGETSKIPHBA%]==[YES]	(
				IF NOT [%NO_scl_EXP-IOC%]==[YES]	(
									.\scl2 --list | find " HBA" >> %TW-WS%sc2_gen3.5_HBA_hbas_raw.txt 2>&1 
									IF EXIST %TW-WS%sc2_gen3.5_HBA_hbas_raw.txt dir %TW-WS%sc2_gen3.5_HBA_hbas_raw.txt | %grep% " 0 sc2_gen3.5_HBA_hbas_raw.txt" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1 move %TW-WS%sc2_gen3.5_HBA_hbas_raw.txt %TW-WS%0Byte_sc2_gen3.5_HBA_hbas_raw.txt >> misc_output.txt 2>&1
									IF EXIST %TW-WS%sc2_gen3.5_HBA_hbas_raw.txt	(
													 	SET NO_scl_IOC=NO
														@ECHO IN__scl2_HBA3.5_IOC_Branch_1 >> misc_output.txt 2>&1
														IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products
														IF NOT EXIST %TW-FN%\Broadcom_Products\HBA mkdir %TW-FN%\Broadcom_Products\HBA
														IF NOT EXIST %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA mkdir %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA
														.\scl2 --list | find " HBA" > %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\sc2_HBA3.5_hbas.txt
														FOR /F delims^=^)^ tokens^=1 %%i in (%TW-WS%sc2_gen3.5_HBA_hbas_raw.txt) DO (@ECHO %%i >> %TW-WS%sc2_gen3.5_HBA_hbas_raw1.txt)
														FOR /F "tokens=1 delims= " %%i in (%TW-WS%sc2_gen3.5_HBA_hbas_raw1.txt) DO (@ECHO %%i >> %TW-WS%sc2_gen3.5_HBA_hba_nums.txt)
														@ECHO IN__scl2_HBA3.5_IOC_Branch_2 >> misc_output.txt 2>&1
														FOR /F "tokens=1" %%i in (%TW-WS%sc2_gen3.5_HBA_hba_nums.txt) DO	(
																						@ECHO IN__scl2_HBA3.5_IOC_Branch_3 >> misc_output.txt 2>&1
																						.\scl2 -i %%i show | find "WWID" > %TW-WS%sc2_HBA_hba_%%i_sasaddr.txt
																						FOR /F "tokens=2,3 delims=: " %%j in (%TW-WS%sc2_HBA_hba_%%i_sasaddr.txt) DO (@ECHO %%j%%k > %TW-WS%sc2_HBA_hba_%%i_sasaddr1.txt)																				
																						FOR /F "tokens=1" %%j in (%TW-WS%sc2_HBA_hba_%%i_sasaddr1.txt) DO	(
																														@ECHO IN__scl2_HBA3.5_IOC_Branch_4_HBA%%i >> misc_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO .
																														@ECHO Starting the log collection for 9500/9400_HBA hba%%i SAS Address %%j
																														@ECHO ................................coredump collection.............................. >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_uploads_hba%%i.txt 2>&1
																														IF EXIST %%jcoredump.bin del %%jcoredump.bin >> misc_output.txt 2>&1
																														.\scl2 -i %%i coredump -ul -f %%jcoredump.bin >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_uploads_hba%%i.txt 2>&1
																														move %%jcoredump.bin %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA >> misc_output.txt >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_uploads_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................show -all............................... >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i show -all >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................show -sys............................... >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i show -sys >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................show -fwheader............................... >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i show -fwheader >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................scan......................................... >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i scan >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..................................scan -l.............................. >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i scan -l >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ....................................device -c.................................... >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i device -c >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ...................................device -tmt -show................................... >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i device -tmt -show >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................events -sas................................ >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i events -sas >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................events -pci................................ >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i events -pci >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ................................phy -da................................ >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -da >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................phy -port.................................... >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -port >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................phy -err....................................... >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -err >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................phy -evnt.................................... >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i phy -evnt >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................cli pl acm.................................... >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl acm >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO ..............................cli pl show acm.................................... >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														.\scl2 -i %%i cli pl show acm >> %TW-FN%\Broadcom_Products\HBA\9500_9400_HBA\%%j_scli_hba%%i.txt 2>&1
																														REM   ......................................::.......................................
																														)
																						)	
														)
													)
									)	
									
REM ###########################################################################################################################
REM Starting scl2 Margay SAS4xXX Data Collection
REM ###########################################################################################################################
SET SCL2MARGAY=%time%
IF NOT [%TWGETSKIPEXPANDER%]==[YES]	(
		IF NOT [%NO_scl_EXP-IOC%]==[YES]	(
					.\scl2 --list | find "SAS4x" >> %TW-WS%sc_gen4_exps_raw.txt 2>&1 
					IF EXIST %TW-WS%sc_gen4_exps_raw.txt dir %TW-WS%sc_gen4_exps_raw.txt | %grep% " 0 sc_gen4_exps_raw.txt" >> misc_output.txt 2>&1
					IF NOT ERRORLEVEL 1 move %TW-WS%sc_gen4_exps_raw.txt %TW-WS%0Byte_sc_gen4_exps_raw.txt >> misc_output.txt 2>&1
					IF EXIST %TW-WS%sc_gen4_exps_raw.txt	(
									 	SET NO_scl_EXP=NO
										@ECHO IN__scl_EXP4_Branch_1 >> misc_output.txt 2>&1
										IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products
										IF NOT EXIST %TW-FN%\Broadcom_Products\Expander mkdir %TW-FN%\Broadcom_Products\Expander
										IF NOT EXIST %TW-FN%\Broadcom_Products\Expander\SAS4xXX mkdir %TW-FN%\Broadcom_Products\Expander\SAS4xXX
										IF NOT EXIST %TW-FN%\Broadcom_Products\Expander\SAS4xXX\Details mkdir %TW-FN%\Broadcom_Products\Expander\SAS4xXX\Details
										.\scl2 --list | find "SAS4x" > %TW-FN%\Broadcom_Products\Expander\SAS4xXX\Details\Margay_expanders.txt
										FOR /F delims^=^)^ tokens^=1 %%i in (%TW-WS%sc_gen4_exps_raw.txt) DO (@ECHO %%i >> %TW-WS%sc_gen4_exps_raw1.txt)
										FOR /F "tokens=1 delims= " %%i in (%TW-WS%sc_gen4_exps_raw1.txt) DO (@ECHO %%i >> %TW-WS%sc_gen4_exp_nums.txt)
										@ECHO IN__scl_EXP4_Branch_2 >> misc_output.txt 2>&1
										FOR /F "tokens=1" %%i in (%TW-WS%sc_gen4_exp_nums.txt) DO	(
																		@ECHO IN__scl_EXP4_Branch_3_EXP%%i >> misc_output.txt 2>&1
																		.\scl2 -i %%i show | find "SAS Address" > %TW-WS%sc_exp_%%i_sasaddr.txt
																		FOR /F "tokens=2,3 delims=:" %%j in (%TW-WS%sc_exp_%%i_sasaddr.txt) DO (@ECHO %%j%%k > %TW-WS%sc_exp_%%i_sasaddr1.txt)																				
																		FOR /F "tokens=1,2,3,4 delims=: " %%j in (%TW-WS%sc_exp_%%i_sasaddr1.txt) DO (@ECHO %%j%%k%%l%%m > %TW-WS%sc_exp_%%i_sasaddr2.txt)
																		FOR /F "tokens=1" %%j in (%TW-WS%sc_exp_%%i_sasaddr2.txt) DO	(
																										@ECHO IN__scl_EXP4_Branch_4_EXP%%i >> misc_output.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO .
																										@ECHO Starting the log collection for SAS4xXX expander%%i SAS Address %%j
																										@ECHO ................................scli Expanders................................. >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 --list | find "SAS4xXX" >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ................................coredump collection.............................. >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_coredump_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli coredump >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_coredump_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ................................debuginfo collection.............................. >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_debuginfo_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli debuginfo >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_debuginfo_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................show -all.................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i show -all >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli date.................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli date >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli rev.................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli rev >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli showmfg.................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli showmfg >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli thread................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli thread >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................show -ftbl................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i show -ftbl >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli flashtblinfo................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli flashtblinfo >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli spiinfo................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli spiinfo >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................route.................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i route >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli rtr.................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli rtr >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ....................................phy -da.................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i phy -da >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ...................................phy -edfb................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i phy -edfb >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ...................................cli edfbinfo................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli edfbinfo >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ...................................phy -err.................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i phy -err >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................phy -speed................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i phy -speed >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli ubminfo................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli ubminfo >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli phyinfo ubm................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli phyinfo ubm >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli printkeys................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli printkeys >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli isrstat................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli isrstat >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli sgpioinfo................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli sgpioinfo >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli memstat................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli memstat >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli scedebug................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli scedebug >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli eyescope FFFF FFFFFFFF................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli eyescope FFFF FFFFFFFF >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cfg -dumpall......................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cfg -dumpall >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO .....................................fwtrace..................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i_fwtrace.txt 2>&1
																										.\scl2 -i %%i fwtrace >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i_fwtrace.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO .....................................fwlogs..................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i_fwlogs.txt 2>&1
																										.\scl2 -i %%i fwlogs >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i_fwlogs.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO .....................................fwlogs -raw..................................... >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i_fwlogs.txt 2>&1
																										.\scl2 -i %%i fwlogs -raw >> %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i_fwlogs.txt 2>&1
																										REM   ......................................::.......................................
																										.\scl2 -i %%i ul -r 0 -s -o %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i_up_fw_region0.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 1 -s -o %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i_up_fw_region1.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 2 -s -o %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i_up_fw_region2.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 3 -s -o %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i_up_fw_region3.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 4 -s -o %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i_up_fw_region4.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 5 -s -o %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i_up_fw_region5.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 6 -s -o %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i_up_fw_region6.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 7 -s -o %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i_up_fw_region7.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 8 -s -o %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i_up_fw_region8.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 9 -s -o %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i_up_fw_region9.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 10 -s -o %TW-FN%\Broadcom_Products\Expander\SAS4xXX\%%j_scli_exp%%i_up_fw_region10.bin >> misc_output.txt 2>&1
																										)
																		)	
										)
					)
		)
REM ###########################################################################################################################
REM # Starting scl2 Cub SAS35xXX Data Collection
REM ###########################################################################################################################
SET SCL2CUB=%time%
IF NOT [%TWGETSKIPEXPANDER%]==[YES]	(
		IF NOT [%NO_scl_EXP-IOC%]==[YES]	(
					.\scl2 --list | find "SAS35x" >> %TW-WS%sc_gen35_exps_raw.txt 2>&1 
					IF EXIST %TW-WS%sc_gen35_exps_raw.txt dir %TW-WS%sc_gen35_exps_raw.txt | %grep% " 0 sc_gen35_exps_raw.txt" >> misc_output.txt 2>&1
					IF NOT ERRORLEVEL 1 move %TW-WS%sc_gen35_exps_raw.txt %TW-WS%0Byte_sc_gen35_exps_raw.txt >> misc_output.txt 2>&1
					IF EXIST %TW-WS%sc_gen35_exps_raw.txt	(
									 	SET NO_scl_EXP=NO
										@ECHO IN__scl_EXP3.5_Branch_1 >> misc_output.txt 2>&1
										IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products
										IF NOT EXIST %TW-FN%\Broadcom_Products\Expander mkdir %TW-FN%\Broadcom_Products\Expander
										IF NOT EXIST %TW-FN%\Broadcom_Products\Expander\SAS35xXX mkdir %TW-FN%\Broadcom_Products\Expander\SAS35xXX
										IF NOT EXIST %TW-FN%\Broadcom_Products\Expander\SAS35xXX\Details mkdir %TW-FN%\Broadcom_Products\Expander\SAS35xXX\Details
										.\scl2 --list | find "SAS35x" > %TW-FN%\Broadcom_Products\Expander\SAS35xXX\Details\Cub_expanders.txt
										FOR /F delims^=^)^ tokens^=1 %%i in (%TW-WS%sc_gen35_exps_raw.txt) DO (@ECHO %%i >> %TW-WS%sc_gen35_exps_raw1.txt)
										FOR /F "tokens=1 delims= " %%i in (%TW-WS%sc_gen35_exps_raw1.txt) DO (@ECHO %%i >> %TW-WS%sc_gen35_exp_nums.txt)
										@ECHO IN__scl_EXP3.5_Branch_2 >> misc_output.txt 2>&1
										FOR /F "tokens=1" %%i in (%TW-WS%sc_gen35_exp_nums.txt) DO	(
																		@ECHO IN__scl_EXP3.5_Branch_3_EXP%%i >> misc_output.txt 2>&1
																		.\scl2 -i %%i show | find "SAS Address" > %TW-WS%sc_exp_%%i_sasaddr.txt
																		FOR /F "tokens=2,3 delims=:" %%j in (%TW-WS%sc_exp_%%i_sasaddr.txt) DO (@ECHO %%j%%k > %TW-WS%sc_exp_%%i_sasaddr1.txt)																				
																		FOR /F "tokens=1,2,3,4 delims=: " %%j in (%TW-WS%sc_exp_%%i_sasaddr1.txt) DO (@ECHO %%j%%k%%l%%m > %TW-WS%sc_exp_%%i_sasaddr2.txt)
																		FOR /F "tokens=1" %%j in (%TW-WS%sc_exp_%%i_sasaddr2.txt) DO	(
																										@ECHO IN__scl_EXP3.5_Branch_4_EXP%%i >> misc_output.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO .
																										@ECHO Starting the log collection for SAS35xXX expander%%i SAS Address %%j
																										@ECHO ................................scli Expanders................................. >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 --list | find "SAS35x" >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ................................coredump collection.............................. >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_coredump_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli coredump >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_coredump_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ................................debuginfo collection.............................. >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_debuginfo_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli debuginfo >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_debuginfo_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................show -all.................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i show -all >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli date.................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli date >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli rev.................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli rev >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli showmfg.................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli showmfg >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli thread................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli thread >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................show -ftbl................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i show -ftbl >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli flashtblinfo................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli flashtblinfo >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli spiinfo................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli spiinfo >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................route.................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i route >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli rtr.................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli rtr >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ....................................phy -da.................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i phy -da >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ...................................phy -edfb................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i phy -edfb >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ...................................cli edfbinfo................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli edfbinfo >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ...................................phy -err.................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i phy -err >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................phy -speed................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i phy -speed >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli ubminfo................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli ubminfo >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli phyinfo ubm................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli phyinfo ubm >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli printkeys................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli printkeys >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli isrstat................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli isrstat >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli sgpioinfo................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli sgpioinfo >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli memstat................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli memstat >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli scedebug................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli scedebug >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cli eyescope FFFF FFFFFFFF................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cli eyescope FFFF FFFFFFFF >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cfg -dumpall......................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cfg -dumpall >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO .....................................fwtrace..................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i_fwtrace.txt 2>&1
																										.\scl2 -i %%i fwtrace >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i_fwtrace.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO .....................................fwlogs..................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i_fwlogs.txt 2>&1
																										.\scl2 -i %%i fwlogs >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i_fwlogs.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO .....................................fwlogs -raw..................................... >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i_fwlogs.txt 2>&1
																										.\scl2 -i %%i fwlogs -raw >> %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i_fwlogs.txt 2>&1
																										REM   ......................................::.......................................
																										.\scl2 -i %%i ul -r 0 -s -o %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i_up_fw_region0.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 1 -s -o %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i_up_fw_region1.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 2 -s -o %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i_up_fw_region2.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 3 -s -o %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i_up_fw_region3.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 4 -s -o %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i_up_fw_region4.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 5 -s -o %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i_up_fw_region5.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 6 -s -o %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i_up_fw_region6.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 7 -s -o %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i_up_fw_region7.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 8 -s -o %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i_up_fw_region8.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 9 -s -o %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i_up_fw_region9.bin >> misc_output.txt 2>&1
																										.\scl2 -i %%i ul -r 10 -s -o %TW-FN%\Broadcom_Products\Expander\SAS35xXX\%%j_scli_exp%%i_up_fw_region10.bin >> misc_output.txt 2>&1
																										)
																		)	
										)
					)
		)

REM ###########################################################################################################################
REM # Starting scl2 Cobra SAS3xXX Data Collection (Limited info available)
REM ###########################################################################################################################
SET SCL2COBRA=%time%
IF NOT [%TWGETSKIPEXPANDER%]==[YES]	(
		IF NOT [%NO_scl_EXP-IOC%]==[YES]	(
					.\scl2 --list | find "SAS3x" >> %TW-WS%sc_gen3_exps_raw.txt 2>&1 
					IF EXIST %TW-WS%sc_gen3_exps_raw.txt dir %TW-WS%sc_gen3_exps_raw.txt | %grep% " 0 sc_gen3_exps_raw.txt" >> misc_output.txt 2>&1
					IF NOT ERRORLEVEL 1 move %TW-WS%sc_gen3_exps_raw.txt %TW-WS%0Byte_sc_gen3_exps_raw.txt >> misc_output.txt 2>&1
					IF EXIST %TW-WS%sc_gen3_exps_raw.txt	(
									 	SET NO_scl_EXP=NO
										@ECHO IN__scl_EXP3_Branch_1 >> misc_output.txt 2>&1
										IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products
										IF NOT EXIST %TW-FN%\Broadcom_Products\Expander mkdir %TW-FN%\Broadcom_Products\Expander
										IF NOT EXIST %TW-FN%\Broadcom_Products\Expander\SAS3xXX mkdir %TW-FN%\Broadcom_Products\Expander\SAS3xXX
										IF NOT EXIST %TW-FN%\Broadcom_Products\Expander\SAS3xXX\Details mkdir %TW-FN%\Broadcom_Products\Expander\SAS3xXX\Details
										.\scl2 --list | find "SAS3x" > %TW-FN%\Broadcom_Products\Expander\SAS3xXX\Details\Cobra_expanders.txt
										FOR /F delims^=^)^ tokens^=1 %%i in (%TW-WS%sc_gen3_exps_raw.txt) DO (@ECHO %%i >> %TW-WS%sc_gen3_exps_raw1.txt)
										FOR /F "tokens=1 delims= " %%i in (%TW-WS%sc_gen3_exps_raw1.txt) DO (@ECHO %%i >> %TW-WS%sc_gen3_exp_nums.txt)
										@ECHO IN__scl_EXP3.5_Branch_2 >> misc_output.txt 2>&1
										FOR /F "tokens=1" %%i in (%TW-WS%sc_gen3_exp_nums.txt) DO	(
																		@ECHO IN__scl_EXP3_Branch_3_EXP%%i >> misc_output.txt 2>&1
																		.\scl2 -i %%i show | find "SAS Address" > %TW-WS%sc_exp_%%i_sasaddr.txt
																		FOR /F "tokens=2,3 delims=:" %%j in (%TW-WS%sc_exp_%%i_sasaddr.txt) DO (@ECHO %%j%%k > %TW-WS%sc_exp_%%i_sasaddr1.txt)																				
																		FOR /F "tokens=1,2,3,4 delims=: " %%j in (%TW-WS%sc_exp_%%i_sasaddr1.txt) DO (@ECHO %%j%%k%%l%%m > %TW-WS%sc_exp_%%i_sasaddr2.txt)
																		FOR /F "tokens=1" %%j in (%TW-WS%sc_exp_%%i_sasaddr2.txt) DO	(
																										@ECHO IN__scl_EXP3_Branch_4_EXP%%i >> misc_output.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO .
																										@ECHO Starting the log collection for SAS3xXX expander%%i SAS Address %%j
																										@ECHO ................................scli Expanders................................. >> %TW-FN%\Broadcom_Products\Expander\SAS3xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 --list | find "SAS35x" >> %TW-FN%\Broadcom_Products\Expander\SAS3xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................show -all.................................... >> %TW-FN%\Broadcom_Products\Expander\SAS3xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i show -all >> %TW-FN%\Broadcom_Products\Expander\SAS3xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ....................................phy -da.................................... >> %TW-FN%\Broadcom_Products\Expander\SAS3xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i phy -da >> %TW-FN%\Broadcom_Products\Expander\SAS3xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ...................................phy -edfb................................... >> %TW-FN%\Broadcom_Products\Expander\SAS3xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i phy -edfb >> %TW-FN%\Broadcom_Products\Expander\SAS3xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ...................................phy -err.................................... >> %TW-FN%\Broadcom_Products\Expander\SAS3xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i phy -err >> %TW-FN%\Broadcom_Products\Expander\SAS3xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................phy -speed................................... >> %TW-FN%\Broadcom_Products\Expander\SAS3xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i phy -speed >> %TW-FN%\Broadcom_Products\Expander\SAS3xXX\%%j_scli_exp%%i.txt 2>&1
																										REM   ......................................::.......................................
																										@ECHO ..................................cfg -dumpall......................................... >> %TW-FN%\Broadcom_Products\Expander\SAS3xXX\%%j_scli_exp%%i.txt 2>&1
																										.\scl2 -i %%i cfg -dumpall >> %TW-FN%\Broadcom_Products\Expander\SAS3xXX\%%j_scli_exp%%i.txt 2>&1
																										)
																		)	
										)
					)
		)
REM ###########################################################################################################################
REM # Starting bnxtnvm Data Collection
REM ###########################################################################################################################
SET BNXTNVMRUN=%time%
IF NOT [%NO_bnxtnvm%]==[YES]	(
									.\bnxtnvm listdev | find "MACAddress" >> %TW-WS%bnxtnvm_hbas_raw.txt 2>&1 
									IF EXIST %TW-WS%bnxtnvm_hbas_raw.txt dir %TW-WS%bnxtnvm_hbas_raw.txt | %grep% " 0 bnxtnvm_hbas_raw.txt" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1 move %TW-WS%bnxtnvm_hbas_raw.txt %TW-WS%0Byte_bnxtnvm_hbas_raw.txt >> misc_output.txt 2>&1
									IF EXIST %TW-WS%bnxtnvm_hbas_raw.txt	(
													 	@ECHO IN__bnxtnvm_Branch_1 >> misc_output.txt 2>&1
														IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products
														IF NOT EXIST %TW-FN%\Broadcom_Products\NetXtreme-E mkdir %TW-FN%\Broadcom_Products\NetXtreme-E
														IF NOT EXIST %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM mkdir %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM
														FOR /F "delims=: tokens=2" %%i in (%TW-WS%bnxtnvm_hbas_raw.txt) DO (@ECHO %%i >> %TW-WS%bnxtnvm_hbas_raw1.txt)
														FOR /F "tokens=1*" %%a in (%TW-WS%bnxtnvm_hbas_raw1.txt) DO (@ECHO %%a >> %TW-WS%bnxtnvm_hba_nums.txt)
														@ECHO IN__bnxtnvm_Branch_2 >> misc_output.txt 2>&1
														FOR /F "tokens=1" %%j in (%TW-WS%bnxtnvm_hba_nums.txt) DO	(
																						@ECHO IN__bnxtnvm_Branch_3 >> misc_output.txt 2>&1
																						IF NOT EXIST %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j mkdir %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j
																														@ECHO IN__bnxtnvm_Branch_4_NIC%%j >> misc_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO .
																														@ECHO Starting the bnxtnvm log collection for NetXtreme-E hba %%j
																														@ECHO ................................NetXtreme-E................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														@ECHO listdev output................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														.\bnxtnvm listdev >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO device_info output................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														.\bnxtnvm device_info >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO list output................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														.\bnxtnvm list >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO view output................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														.\bnxtnvm view >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO -dev device_info output................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														.\bnxtnvm -dev=%%j device_info >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO -dev list output................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														.\bnxtnvm -dev=%%j list >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO -dev pkgver output................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														.\bnxtnvm -dev=%%j pkgver >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO -dev device_temperature output................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														.\bnxtnvm -dev=%%j device_temperature >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO -dev verify output................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														.\bnxtnvm -dev=%%j verify >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO generating coredump................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														.\bnxtnvm -dev=%%j coredump >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO generating backup................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														.\bnxtnvm -dev=%%j backup >> %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\%%j_bnxtnvm_output.txt 2>&1
																														REM   ......................................::.......................................
																														IF EXIST *.core copy *.core %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\ >> misc_output.txt 2>&1
																														IF EXIST *.pkg copy *.pkg %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\ >> misc_output.txt 2>&1
																														IF EXIST bnxtnvm.log copy bnxtnvm.log %TW-FN%\Broadcom_Products\NetXtreme-E\BNXTNVM\%%j\ >> misc_output.txt 2>&1
																														IF EXIST *.core del *.core >nul 2>&1
																														IF EXIST *.pkg del *.pkg >nul 2>&1
																														IF EXIST bnxtnvm.log del bnxtnvm.log >nul 2>&1
																												)		
																		)
							)
GOTO SKIP_NICCLI
REM ###########################################################################################################################
REM # Starting niccli_x64 Data Collection
REM ###########################################################################################################################
SET NICCLIRUN=%time%
IF NOT [%NO_niccli%]==[YES]	(
									.\niccli_x64 --listdev | find "MAC Address" >> %TW-WS%niccli_hbas_raw.txt 2>&1					
									IF EXIST %TW-WS%niccli_hbas_raw.txt dir %TW-WS%niccli_hbas_raw.txt | %grep% " 0 niccli_hbas_raw.txt" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1 move %TW-WS%niccli_hbas_raw.txt %TW-WS%0Byte_niccli_hbas_raw.txt >> misc_output.txt 2>&1
									IF EXIST %TW-WS%niccli_hbas_raw.txt	(
													 	@ECHO IN__niccli_Branch_1 >> misc_output.txt 2>&1
														IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products
														IF NOT EXIST %TW-FN%\Broadcom_Products\NetXtreme-E mkdir %TW-FN%\Broadcom_Products\NetXtreme-E
														IF NOT EXIST %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI mkdir %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI
														FOR /F "tokens=2,3,4,5,6,7 delims=:" %%i in (%TW-WS%niccli_hbas_raw.txt) DO (@ECHO %%i %%j %%k %%l %%m %%n >> %TW-WS%niccli_hbas_raw1.txt)
														FOR /F "tokens=1-6" %%a in (%TW-WS%niccli_hbas_raw1.txt) DO (@ECHO %%a%%b%%c%%d%%e%%f >> %TW-WS%niccli_hba_nums.txt)
														@ECHO IN__niccli_Branch_2 >> misc_output.txt 2>&1
														FOR /F "tokens=1" %%i in (%TW-WS%niccli_hba_nums.txt) DO	(
																						@ECHO IN__niccli_Branch_3 >> misc_output.txt 2>&1
																						.\niccli_x64 --list | find "BCM5" > %TW-WS%niccli_hba_%%i_macaddr.txt
																						FOR /F delims^=^)^ tokens^=1 %%j in (%TW-WS%niccli_hba_%%i_macaddr.txt) DO (@ECHO %%j > %TW-WS%niccli_hba_%%i_macaddr1.txt)																				
																						FOR /F "tokens=1" %%j in (%TW-WS%niccli_hba_%%i_macaddr1.txt) DO	(
																														@ECHO IN__niccli_Branch_4_NIC%%i >> misc_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO .
																														@ECHO Starting the niccli log collection for NetXtreme-E hba %%i
																														@ECHO ................................NetXtreme-E................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\%%i_niccli_output.txt 2>&1
																														@ECHO devid output................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\%%i_niccli_output.txt 2>&1
																														.\niccli_x64 devid >> %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\%%i_niccli_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO device_info output................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\%%i_niccli_output.txt 2>&1
																														.\niccli_x64 -i %%j listdev >> %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\%%i_niccli_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO -dev device_info output................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\%%i_niccli_output.txt 2>&1
																														.\niccli_x64 -i %%j device_info >> %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\%%i_niccli_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO -dev list output................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\%%i_niccli_output.txt 2>&1
																														.\niccli_x64 -i %%j list >> %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\%%i_niccli_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO -dev pkgver output................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\%%i_niccli_output.txt 2>&1
																														.\niccli_x64 -i %%j pkgver >> %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\%%i_niccli_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO -dev device_temperature output................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\%%i_niccli_output.txt 2>&1
																														.\niccli_x64 -i %%j device_temperature >> %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\%%i_niccli_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO -dev verify output................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\%%i_niccli_output.txt 2>&1
																														.\niccli_x64 -i %%j verify >> %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\%%i_niccli_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO generating coredump................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\%%i_niccli_output.txt 2>&1
																														.\niccli_x64 -i %%j coredump >> %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\%%i_niccli_output.txt 2>&1
																														REM   ......................................::.......................................
																														@ECHO generating backup................................. >> %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\%%i_niccli_output.txt 2>&1
																														.\niccli_x64 -i %%j backup >> %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\%%i_niccli_output.txt 2>&1
																														REM   ......................................::.......................................
																														IF EXIST *.core copy *.core %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\ >> misc_output.txt 2>&1
																														IF EXIST *.pkg copy *.pkg %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\ >> misc_output.txt 2>&1
																														IF EXIST niccli.log copy niccli.log %TW-FN%\Broadcom_Products\NetXtreme-E\NICCLI\ >> misc_output.txt 2>&1
																																						)
																												)		
																		)
							)
:SKIP_NICCLI							
REM ###########################################################################################################################
REM Storcli2 - Adapter Info
REM ###########################################################################################################################
SET STORCLI2=%time%
REM IF NOT [%NOWOW64%]==[YES] (%TW-WS%timers\timer3\timer3 /q /nologo)
IF NOT ["%NO_MR2_Adps%"]==["YES"]	(
FOR /F "usebackq" %%i IN (%TW-WS%mr2_ctrl_nums.txt) DO	(
							REM IF NOT [%NOWOW64%]==[YES] (%TW-WS%timers\timer100\timer100 /q /nologo)
							IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli2 mkdir %TW-FN%\Broadcom_Products\Storcli2
							IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli2\Avenger mkdir %TW-FN%\Broadcom_Products\Storcli2\Avenger
							@ECHO .
							@ECHO Starting Storcli2 gathering on Avenger %%i...
							@ECHO Starting Storcli2 gathering on Avenger %%i... >> misc_output.txt 2>&1
							@ECHO Start_on_Avenger_%%i...1 >> misc_output.txt 2>&1
							@ECHO Start on Avenger Controller %%i... > %TW-WS%Start_Avenger_Controller_%%i.txt
							IF NOT [%NOWOW64%]==[YES] (.\xdir /Form=*t %TW-WS%Start_Avenger_Controller_%%i.txt >> misc_output.txt 2>&1)
 
							REM   ......................................::.......................................
							@ECHO %TW-FN% > %TW-FN%\Broadcom_Products\Storcli2\Avenger\Show_all_C%%i.txt												
							@ECHO .............................storcli2 /c%%i show all.............................. >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Show_all_C%%i.txt	
							%MR_Cli2% /c%%i show all >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Show_all_C%%i.txt 2>&1

							@ECHO Start_on_Avenger_%%i...2 >> misc_output.txt 2>&1

							@ECHO %TW-FN% > %TW-FN%\Broadcom_Products\Storcli2\Avenger\Cx_Eall_show_all-plus_C%%i.txt
							REM   ......................................::.......................................
							@ECHO .........................storcli2 /c%%i/eall show all........................ >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Cx_Eall_show_all-plus_C%%i.txt
							%MR_Cli2% /c%%i/eall show all >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Cx_Eall_show_all-plus_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .....................storcli2 /c%%i/eall show status......................... >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Cx_Eall_show_all-plus_C%%i.txt
							%MR_Cli2% /c%%i/eall show status >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Cx_Eall_show_all-plus_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .................storcli2 /c%%i/eall show phyerrorcounters................... >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Cx_Eall_show_all-plus_C%%i.txt
							%MR_Cli2% /c%%i/eall show phyerrorcounters >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Cx_Eall_show_all-plus_C%%i.txt 2>&1

							@ECHO Start_on_Avenger_%%i...3 >> misc_output.txt 2>&1

							@ECHO %TW-FN% > %TW-FN%\Broadcom_Products\Storcli2\Avenger\Cx_Eall_Sall_show_all-plus_C%%i.txt
							REM   ......................................::.......................................
							@ECHO .........................storcli2 /c%%i/eall/sall show all...................... >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Cx_Eall_Sall_show_all-plus_C%%i.txt
							%MR_Cli2% /c%%i/eall/sall show all >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Cx_Eall_Sall_show_all-plus_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .....................storcli2 /c%%i/eall/sall show smart........................ >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Cx_Eall_Sall_show_all-plus_C%%i.txt
							%MR_Cli2% /c%%i/eall/sall show smart >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Cx_Eall_Sall_show_all-plus_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .................storcli2 /c%%i/eall/sall show phyerrorcounters................. >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Cx_Eall_Sall_show_all-plus_C%%i.txt
							%MR_Cli2% /c%%i/eall/sall show phyerrorcounters >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Cx_Eall_Sall_show_all-plus_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .................storcli2 /c%%i show unusabledriveinfo.......................... >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Cx_Eall_Sall_show_all-plus_C%%i.txt
							%MR_Cli2% /c%%i show unusabledriveinfo >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Cx_Eall_Sall_show_all-plus_C%%i.txt 2>&1

							@ECHO Start_on_Avenger_%%i...4 >> misc_output.txt 2>&1
							
							@ECHO %TW-FN% > %TW-FN%\Broadcom_Products\Storcli2\Avenger\Alilog_C%%i.txt												
							REM   ......................................::.......................................
							@ECHO ..........................storcli2 /c%%i show alilog............................ >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Alilog_C%%i.txt
							%MR_Cli2% /c%%i show alilog >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Alilog_C%%i.txt 2>&1

							@ECHO Start_on_Avenger_%%i...5 >> misc_output.txt 2>&1
							
							@ECHO %TW-FN% > %TW-FN%\Broadcom_Products\Storcli2\Avenger\Events_C%%i.txt												
							REM   ......................................::.......................................
							@ECHO ..........................storcli2 /c%%i show eventseqinfo.................... >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Events_C%%i.txt
							%MR_Cli2% /c%%i show eventseqinfo >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Events_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO ..........................storcli2 /c%%i show events.......................... >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Events_C%%i.txt
							%MR_Cli2% /c%%i show events >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Events_C%%i.txt 2>&1

							@ECHO Start_on_Avenger_%%i...6 >> misc_output.txt 2>&1
							
							@ECHO %TW-FN% > %TW-FN%\Broadcom_Products\Storcli2\Avenger\Controller_C%%i.txt												
							REM   ......................................::.......................................
							@ECHO ................................storcli2 show all............................. >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Controller_C%%i.txt
							%MR_Cli2% show all >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Controller_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO ...............................storcli2 /c%%i show............................ >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Controller_C%%i.txt
							%MR_Cli2% /c%%i show >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Controller_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .........................storcli2 /c%%i show all.............................. >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Controller_C%%i.txt
							%MR_Cli2% /c%%i show all >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Controller_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .........................storcli2 /c%%i compare factory defaults.............. >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Controller_C%%i.txt
							%MR_Cli2% /c%%i compare factory defaults >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Controller_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .........................storcli2 /c%%i show ocr.............................. >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Controller_C%%i.txt
							%MR_Cli2% /c%%i show ocr >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Controller_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .........................storcli2 /c%%i show security keyid................... >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Controller_C%%i.txt
							%MR_Cli2% /c%%i show security keyid >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Controller_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .........................storcli2 /c%%i show spinupdelay...................... >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Controller_C%%i.txt
							%MR_Cli2% /c%%i show spinupdelay >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Controller_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .................storcli2 /c%%i/pall show all................................. >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Controller_C%%i.txt
							%MR_Cli2% /c%%i/pall show all >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Controller_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .................storcli2 /c%%i/vall show all................................. >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Controller_C%%i.txt
							%MR_Cli2% /c%%i/vall show all >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Controller_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .........................storcli2 /c%%i show snapdump......................... >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Snapdumpinfo_C%%i.txt
							%MR_Cli2% /c%%i show snapdump >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Snapdumpinfo_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .........................storcli2 /c%%i get snapdump all......................... >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Snapdumpinfo_C%%i.txt
							%MR_Cli2% /c%%i get snapdump all >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Snapdumpinfo_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .........................storcli2 /c%%i get snapdump ondemand force......................... >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Snapdumpinfo_C%%i.txt
							%MR_Cli2% /c%%i get snapdump ondemand force >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Snapdumpinfo_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .........................storcli2 /c%%i delete snapdump force......................... >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Snapdumpinfo_C%%i.txt
							%MR_Cli2% /c%%i delete snapdump force >> %TW-FN%\Broadcom_Products\Storcli2\Avenger\Snapdumpinfo_C%%i.txt 2>&1
							REM   ......................................::.......................................

							IF NOT EXIST %TW-FN%\Broadcom_Products\Snapdump\Storcli2\Avenger mkdir %TW-FN%\Broadcom_Products\Snapdump\Storcli2\Avenger
                            IF EXIST snapdump* copy snapdump* %TW-FN%\Broadcom_Products\Snapdump\Storcli2\Avenger >> misc_output.txt 2>&1
                            IF EXIST mpi3drv.sys_* copy mpi3drv.sys_* %TW-FN%\Broadcom_Products\Snapdump\Storcli2\Avenger >> misc_output.txt 2>&1
							del snapdump* > nul 2>&1
							del mpi3drv.sys_* > nul 2>&1
							
							REM   ......................................::.......................................
							 
							@ECHO Start_on_Avenger_%%i...7 >> misc_output.txt 2>&1
							@ECHO End on Controller %%i... >> misc_output.txt 2>&1
							@ECHO End on Storcli2 Controller %%i... > %TW-WS%End_Storcli2_Controller_%%i.txt
							REM IF NOT [%NOWOW64%]==[YES] (.\xdir /Form=*t %TW-WS%End_Storcli2_Controller_%%i.txt >> misc_output.txt 2>&1)
							REM IF NOT [%NOWOW64%]==[YES] (%TW-WS%timers\timer100\timer100 /s /nologo)
							)

@ECHO End of the Controller Data Collection with storcli2... >> misc_output.txt 2>&1
@ECHO End of the Controller Data Collection with storcli2... > %TW-WS%End_Storcli2.txt
IF NOT [%NOWOW64%]==[YES] (.\xdir /Form=*t %TW-WS%End_Storcli2.txt >> misc_output.txt 2>&1)
%grep% -c -e 0 -e 1 -e 2 -e 3 %TW-WS%mr2_ctrl_nums.txt | %grep% 1 >> misc_output.txt 2>&1
REM IF ERRORLEVEL 1	(
REM 		IF NOT [%NOWOW64%]==[YES] (@ECHO Cumulative - storcli2 Syntax:)
REM 		IF NOT [%NOWOW64%]==[YES] (%TW-WS%timers\timer3\timer3 /s /nologo)
REM 							)
		)

REM legacy starts here
REM ###########################################################################################################################
REM storcli - MegaRAID Adapter Info
REM ###########################################################################################################################
SET STORCLI1_A=%time%
:START_MR_STORCLI
IF [%TWGETSKIPMEGARAID%]==[YES]	GOTO NO_MR_Adapters
IF ["%NO_MR_Adps%"]==["YES"]	(GOTO NO_MR_Adapters)

IF [%TWGETPARTIALMODE%]==[E_AEC] GOTO MR_E_AEC
IF [%TWGETPARTIALMODE%]==[E_DPM] GOTO MR_E_DPM
IF [%TWGETPARTIALMODE%]==[E_AEC_DPM] GOTO MR_E_AEC


GOTO MR_NOT_E_AEC
:MR_E_AEC
FOR /F "usebackq" %%i IN (%TW-WS%mr_ctrl_nums.txt) DO	(
							%MR_Cli% adpaec disable a%%i nolog > %TW-WS%c%%i_show_capture_mr.txt 
							IF NOT ERRORLEVEL 1 @ECHO %%i >> %TW-WS%mr_ctrl_nums_aec.txt
							)



IF EXIST %TW-WS%mr_ctrl_nums_aec.txt	(
					@ECHO .
					@ECHO Clearing and Enabling Advanced Event Capture "AEC" for MegaRAID... 
					FOR /F "usebackq" %%i IN (%TW-WS%mr_ctrl_nums_aec.txt) DO	(
													%MR_Cli% adpaec disable a%%i nolog >> misc_output.txt 2>&1
													%MR_Cli% adpaec start numevents 150000 a%%i nolog >> misc_output.txt 2>&1
													)
					)
:MR_NOT_E_AEC
IF [%TWGETPARTIALMODE%]==[E_AEC] GOTO END_No_Pause
IF [%TWGETPARTIALMODE%]==[E_DPM] GOTO MR_E_DPM
IF [%TWGETPARTIALMODE%]==[E_AEC_DPM] GOTO MR_E_DPM
GOTO MR_NOT_E_DPM
:MR_E_DPM

REM ###########################################################################################################################
REM # Determine # of ports & which controllers support dpmstat.
REM # Clearing and Enabling DPMSTAT
REM ###########################################################################################################################
FOR /F "usebackq" %%i IN (%TW-WS%mr_ctrl_nums.txt) DO	(
							%MR_Cli% adpgetprop dpmenable a%%i nolog > %TW-WS%c%%i_show_pmstat_mr.txt 2>&1
							%grep% "DPM is " %TW-WS%c%%i_show_pmstat_mr.txt  > %TW-WS%c%%i_show_pmstat_enbld_mr.txt
							IF NOT ERRORLEVEL 1 @ECHO %%i >> %TW-WS%mr_ctrl_nums_pmstat.txt
							)

IF EXIST %TW-WS%mr_ctrl_nums_pmstat.txt	(
					@ECHO .
					@ECHO Clearing and Enabling Disk Performance Monitoring Statistics "DPMSTAT" for MegaRAID...
					FOR /F "usebackq" %%i IN (%TW-WS%mr_ctrl_nums_pmstat.txt) DO	(
													%MR_Cli% dpmstat clear lct a%%i nolog >> misc_output.txt 2>&1
													%MR_Cli% dpmstat clear hist a%%i nolog >> misc_output.txt 2>&1
													%MR_Cli% dpmstat clear ra a%%i nolog >> misc_output.txt 2>&1
													%MR_Cli% dpmstat clear ext a%%i nolog >> misc_output.txt 2>&1
													%MR_Cli% adpsetprop dpmenable 1 a%%i nolog >> misc_output.txt 2>&1
													)
													
					)

					
:MR_NOT_E_DPM
IF [%TWGETPARTIALMODE%]==[G_AEC] GOTO MR_G_AEC
IF [%TWGETPARTIALMODE%]==[G_DPM] GOTO MR_G_DPM
IF [%TWGETPARTIALMODE%]==[G_AEC_DPM] GOTO MR_G_AEC
IF [%TWGETPARTIALMODE%]==[STANDARD] GOTO MR_G_AEC
IF [%TWGETPARTIALMODE%]==[MONITOR] GOTO MR_G_AEC
REM GOTO END is for E_*
GOTO END_No_Pause
:MR_G_AEC

REM ###########################################################################################################################
REM # Disabling AEC and capturing logs - Must be first or IOCTLs pollute capture.
REM # TWGETPARTIALMODE = G_* gets AEC/DPMSTAT regardless of state.
REM # TWGETPARTIALMODE = STANDARD/MONITOR gets AEC/DPMSTAT only if Enabled. 
REM ###########################################################################################################################
FOR /F "usebackq" %%i IN (%TW-WS%mr_ctrl_nums.txt) DO	(
							IF [%TWGETPARTIALMODE%]==[STANDARD] %MR_Cli% adpaec show a%%i nolog > %TW-WS%c%%i_show_capture_mr.txt 2>&1
							IF [%TWGETPARTIALMODE%]==[STANDARD]	(
												%grep% "AEC enabled : Yes" %TW-WS%c%%i_show_capture_mr.txt  > %TW-WS%c%%i_show_capture_enabled_mr.txt 2>&1
												IF NOT ERRORLEVEL 1 @ECHO %%i >> %TW-WS%mr_ctrl_nums_aec.txt							
												)
							IF NOT [%TWGETPARTIALMODE%]==[STANDARD] (
												%MR_Cli% adpaec stop a%%i nolog >> misc_output.txt 2>&1
												IF NOT ERRORLEVEL 1 @ECHO %%i >> %TW-WS%mr_ctrl_nums_aec.txt
												)
							)

IF EXIST %TW-WS%mr_ctrl_nums_aec.txt GOTO MR_AEC_EXISTS
GOTO MR_AEC_DOES_NOT_EXIST
:MR_AEC_EXISTS
@ECHO .
@ECHO Disabling and Getting Advanced Event Capture "AEC" for MegaRAID...

FOR /F "usebackq" %%i IN (%TW-WS%mr_ctrl_nums_aec.txt) DO (%MR_Cli% adpaec stop a%%i nolog >> misc_output.txt 2>&1)

FOR /L %%i IN (0,1,11) DO (IF EXIST evtcapture_c%%i.dat SET MR_OLD_EVT_CAP_EXIST=YES)

IF [%MR_OLD_EVT_CAP_EXIST%] == [YES]	(
					IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products
					IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli mkdir %TW-FN%\Broadcom_Products\Storcli
					IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli\OldAEC mkdir %TW-FN%\Broadcom_Products\Storcli\OldAEC
					FOR /L %%i IN (0,1,11) DO	(
									IF EXIST evtcapture_c%%i.dat copy evtcapture_c%%i.dat %TW-FN%\Broadcom_Products\Storcli\OldAEC >> misc_output.txt 2>&1
									IF EXIST evtcapture_c%%i.dat del evtcapture_c%%i.dat >> misc_output.txt 2>&1
									)
					)

FOR /F "usebackq" %%i IN (%TW-WS%mr_ctrl_nums_aec.txt) DO	(
								%MR_Cli% adpaec get -f evtcapture_c%%i.dat a%%i nolog >> misc_output.txt 2>&1
								%MR_Cli% adpaec disable a%%i nolog >> misc_output.txt 2>&1
								)

FOR /F "usebackq" %%i IN (%TW-WS%mr_ctrl_nums_aec.txt) DO (IF EXIST evtcapture_c%%i.dat SET MR_NEW_EVT_CAP_EXIST=YES)

IF [%MR_NEW_EVT_CAP_EXIST%] == [YES]	(
					IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products
					IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli mkdir %TW-FN%\Broadcom_Products\Storcli
					IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli\AEC mkdir %TW-FN%\Broadcom_Products\Storcli\AEC
					FOR /F "usebackq" %%i IN (%TW-WS%mr_ctrl_nums_aec.txt) DO	(
													IF EXIST evtcapture_c%%i.dat copy evtcapture_c%%i.dat %TW-FN%\Broadcom_Products\Storcli\AEC >> misc_output.txt 2>&1
													IF EXIST evtcapture_c%%i.dat del evtcapture_c%%i.dat >> misc_output.txt 2>&1
	
													)
					)
:MR_AEC_DOES_NOT_EXIST

:MR_G_DPM

REM ###########################################################################################################################
REM # Determine # of controllers that support pmstat
REM # TWGETPARTIALMODE = G_* gets AEC/DPMSTAT regardless of state.
REM # TWGETPARTIALMODE = STANDARD gets AEC/DPMSTAT only if Enabled.
REM ###########################################################################################################################
FOR /F "usebackq" %%i IN (%TW-WS%mr_ctrl_nums.txt) DO	(
							IF [%TWGETPARTIALMODE%]==[STANDARD] %MR_Cli% adpgetprop dpmenable a%%i nolog > %TW-WS%c%%i_show_pmstat_mr.txt 2>&1
							IF [%TWGETPARTIALMODE%]==[STANDARD]	(
												%grep% "DPM is Enabled on Adapter" %TW-WS%c%%i_show_pmstat_mr.txt  > %TW-WS%c%%i_show_pmstat_enbld_mr.txt
												IF NOT ERRORLEVEL 1 @ECHO %%i >> %TW-WS%mr_ctrl_nums_pmstat.txt
												)
							IF NOT [%TWGETPARTIALMODE%]==[STANDARD] %MR_Cli% adpgetprop dpmenable a%%i nolog > %TW-WS%c%%i_show_pmstat_mr.txt 2>&1
							IF NOT [%TWGETPARTIALMODE%]==[STANDARD]	(%grep% "DPM is " %TW-WS%c%%i_show_pmstat_mr.txt  > %TW-WS%c%%i_show_pmstat_enbld_mr.txt
												IF NOT ERRORLEVEL 1 @ECHO %%i >> %TW-WS%mr_ctrl_nums_pmstat.txt
												)
							)


IF EXIST %TW-WS%mr_ctrl_nums_pmstat.txt	(
					FOR /F "usebackq" %%i IN (%TW-WS%mr_ctrl_nums_pmstat.txt) DO	(
													%MR_Cli% /c%%i show j | %grep% "EID:Slt" > %TW-WS%c%%i_show_pmstat_eidslt1_mr.txt 2>&1
													FOR /F delims^=^"^ tokens^=4 %%j IN (%TW-WS%c%%i_show_pmstat_eidslt1_mr.txt) DO @ECHO %%j >> %TW-WS%c%%i_show_pmstat_eidslt_mr.txt 2>&1	
													)
					)

IF [%TWGETPARTIALMODE%]==[G_AEC] GOTO MR_NOT_G_DPM

IF EXIST %TW-WS%mr_ctrl_nums_pmstat.txt	(
					@ECHO .
					@ECHO Disabling and Getting Disk Performance Monitoring Statistics "DPMSTAT" for MegaRAID...
					IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products
					IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli mkdir %TW-FN%\Broadcom_Products\Storcli
					IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli\PMSTAT mkdir %TW-FN%\Broadcom_Products\Storcli\PMSTAT

					FOR /F "usebackq" %%i IN (%TW-WS%mr_ctrl_nums_pmstat.txt) DO	(
													%MR_Cli% adpsetprop dpmenable 0 a%%i nolog >> misc_output.txt 2>&1
													IF EXIST %TW-WS%c%%i_show_pmstat_eidslt_mr.txt	(
																			FOR /F "usebackq" %%j IN (%TW-WS%c%%i_show_pmstat_eidslt_mr.txt) DO	(
																												%MR_Cli% adpsetprop dpmenable 0 a%%i nolog >> misc_output.txt 2>&1
																												REM   ......................................::.......................................
																												@ECHO .............storcli dpmstat dsply lct physdrv[%%j] a%%i nolog.................... >> %TW-FN%\Broadcom_Products\Storcli\PMSTAT\PMSTAT_LCT_C%%i.txt 2>&1
																												@ECHO . >> %TW-FN%\Broadcom_Products\Storcli\PMSTAT\PMSTAT_LCT_C%%i.txt 2>&1
																												%MR_Cli% dpmstat dsply lct physdrv[%%j] a%%i nolog >> %TW-FN%\Broadcom_Products\Storcli\PMSTAT\PMSTAT_LCT_C%%i.txt 2>&1
																												
																												REM   ......................................::.......................................
																												@ECHO ..............storcli dpmstat dsply hist physdrv[%%j] a%%i nolog.................. >> %TW-FN%\Broadcom_Products\Storcli\PMSTAT\PMSTAT_HIST_C%%i.txt 2>&1
																												@ECHO . >> %TW-FN%\Broadcom_Products\Storcli\PMSTAT\PMSTAT_HIST_C%%i.txt 2>&1
																												%MR_Cli% dpmstat dsply hist physdrv[%%j] a%%i nolog >> %TW-FN%\Broadcom_Products\Storcli\PMSTAT\PMSTAT_HIST_C%%i.txt 2>&1
																												
																												REM   ......................................::.......................................
																												@ECHO ...............storcli dpmstat dsply ra physdrv[%%j] a%%i nolog................... >> %TW-FN%\Broadcom_Products\Storcli\PMSTAT\PMSTAT_RA_C%%i.txt 2>&1
																												@ECHO . >> %TW-FN%\Broadcom_Products\Storcli\PMSTAT\PMSTAT_RA_C%%i.txt 2>&1
																												%MR_Cli% dpmstat dsply ra physdrv[%%j] a%%i nolog >> %TW-FN%\Broadcom_Products\Storcli\PMSTAT\PMSTAT_RA_C%%i.txt 2>&1
																												
																												REM   ......................................::.......................................
																												@ECHO ...............storcli dpmstat dsply ext physdrv[%%j] a%%i nolog.................. >> %TW-FN%\Broadcom_Products\Storcli\PMSTAT\PMSTAT_EXT_C%%i.txt 2>&1
																												@ECHO . >> %TW-FN%\Broadcom_Products\Storcli\PMSTAT\PMSTAT_EXT_C%%i.txt 2>&1
																												%MR_Cli% dpmstat dsply ext physdrv[%%j] a%%i nolog >> %TW-FN%\Broadcom_Products\Storcli\PMSTAT\PMSTAT_EXT_C%%i.txt 2>&1
																												)
																			)			
													)				
					)	


:MR_NOT_G_DPM
SET STORCLI1_B=%time%
@ECHO .
REM IF NOT [%NOWOW64%]==[YES] (%TW-WS%timers\timer3\timer3 /q /nologo)
@ECHO Starting additional MegaRAID and HBA Controller Log Collection...
IF [%NOWOW64%]==[YES] (@ECHO %time%)
@ECHO Starting additional MegaRAID and HBA Controller Log Collection with storcli... >> misc_output.txt 2>&1
@ECHO Starting additional MegaRAID and HBA Controller Log Collection with storcli... > %TW-WS%Start_MegaRAID_storcli.txt
IF NOT [%NOWOW64%]==[YES] (.\xdir /Form=*t %TW-WS%Start_MegaRAID_storcli.txt >> misc_output.txt 2>&1)

IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products
IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli mkdir %TW-FN%\Broadcom_Products\Storcli

									

REM   ......................................::.......................................
@ECHO %TW-FN% > %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt
@ECHO ......................storcli /call/eall/sall show all......................... >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt	
%MR_Cli% /call/eall/sall show all >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt 2>&1
@ECHO .....................storcli /call/eall/sall show smart........................ >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt	
%MR_Cli% /call/eall/sall show smart >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt 2>&1
REM   ......................................::.......................................
@ECHO .................storcli /call/eall/sall show phyerrorcounters................. >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt	
%MR_Cli% /call/eall/sall show phyerrorcounters >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt 2>&1
IF EXIST %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt	(
									@ECHO %TW-FN% > %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									
									REM   ......................................::.......................................
									
									@ECHO ....................................Drives..................................... >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%MR_Cli% /Call/eall/sall show | %grep% -e "SATA" -e "SAS" >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
	
									REM   ......................................::.......................................
									@ECHO .................................Shield Counter................................ >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Shield Counter =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ................................Media Error Count.............................. >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Media Error Count =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ...............................Other Error Count............................... >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Other Error Count =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ..............................Drive Temperature................................ >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Drive Temperature =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ............................Predictive Failure Count........................... >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Predictive Failure Count =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO .........................S.M.A.R.T alert flagged by drive...................... >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "S.M.A.R.T alert flagged by drive =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ......................................SN....................................... >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "SN =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ......................................WWN...................................... >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "WWN =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ...............................Firmware Revision............................... >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Firmware Revision =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ...................................Raw size.................................... >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Raw size =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO .................................Coerced size.................................. >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Coerced size =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ...............................Non Coerced size................................ >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Non Coerced size =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO .................................Device Speed.................................. >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Device Speed =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ..................................Link Speed................................... >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Link Speed =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ................................Drive write cache.............................. >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Drive write cache =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ..............................Logical Sector Size.............................. >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Logical Sector Size =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO .............................Physical Sector Size.............................. >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Physical Sector Size =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ................................Drive position................................. >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Drive position =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ...............................Enclosure position.............................. >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Enclosure position =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ..............................Connected Port Number............................ >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Connected Port Number =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ................................Sequence Number................................ >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Sequence Number =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ..............................Commissioned Spare............................... >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Commissioned Spare =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ...............................Emergency Spare................................. >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Emergency Spare =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ..................Last Predictive Failure Event Sequence Number................ >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Last Predictive Failure Event Sequence Number =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO .....................Successful diagnostics completion on...................... >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Successful diagnostics completion on =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO .................................SED Capable................................... >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "SED Capable =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO .................................SED Enabled................................... >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "SED Enabled =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ...................................Secured..................................... >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Secured =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ....................................Locked..................................... >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Locked =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO .............................Needs EKM Attention............................... >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Needs EKM Attention =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO .................................PI Eligible................................... >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "PI Eligible =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ..............................Wide Port Capable................................ >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% "Wide Port Capable =" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									REM   ......................................::.......................................
									@ECHO ....................Port # - Status - Linkspeed - SAS Address.................. >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%grep% -e "Gb/s 0x" -e "Gb/s  0x" -e "Gb/s   0x" -e "Gb/s    0x" %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-plus.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
	
									REM   ......................................::.......................................
									@ECHO .................................Inquiry Data.................................. >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									%MR_Cli% /Call/eall/sall show all j | %grep% "Inquiry Data" >> %TW-FN%\Broadcom_Products\Storcli\Call_Eall_Sall_show_all-Compare-All-Parms.txt
									)


FOR /F "usebackq" %%i IN (%TW-WS%mr_ctrl_nums.txt) DO	(
							REM IF NOT [%NOWOW64%]==[YES] (%TW-WS%timers\timer100\timer100 /q /nologo)
							@ECHO Start on Controller %%i...
							@ECHO Start on Controller %%i... >> misc_output.txt 2>&1
							@ECHO Start_on_Controller_%%i...1 >> misc_output.txt 2>&1
							@ECHO Start on MegaRAID Controller %%i... > %TW-WS%Start_MegaRAID_Controller_%%i.txt
							IF NOT [%NOWOW64%]==[YES] (.\xdir /Form=*t %TW-WS%Start_MegaRAID_Controller_%%i.txt >> misc_output.txt 2>&1)

							REM Adding Aero Snapdump Collection
							IF NOT EXIST %TW-FN%\Broadcom_Products\Snapdump mkdir %TW-FN%\Broadcom_Products\Snapdump
							IF NOT EXIST %TW-FN%\Broadcom_Products\Snapdump\Storcli mkdir %TW-FN%\Broadcom_Products\Snapdump\Storcli
							IF NOT EXIST %TW-FN%\Broadcom_Products\Snapdump\Storcli\Aero mkdir %TW-FN%\Broadcom_Products\Snapdump\Storcli\Aero

							@ECHO .........................storcli /c%%i show snapdump......................... >> %TW-FN%\Broadcom_Products\Snapdump\Storcli\Aero\Snapdumpinfo_C%%i.txt
							%MR_Cli% /c%%i show snapdump >> %TW-FN%\Broadcom_Products\Snapdump\Storcli\Aero\Snapdumpinfo_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .........................storcli /c%%i get snapdump id=all......................... >> %TW-FN%\Broadcom_Products\Snapdump\Storcli\Aero\Snapdumpinfo_C%%i.txt
							%MR_Cli% /c%%i get snapdump id=all >> %TW-FN%\Broadcom_Products\Snapdump\Storcli\Aero\Snapdumpinfo_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .........................storcli /c%%i get snapdump ......................... >> %TW-FN%\Broadcom_Products\Snapdump\Storcli\Aero\Snapdumpinfo_C%%i.txt
							%MR_Cli% /c%%i get snapdump >> %TW-FN%\Broadcom_Products\Snapdump\Storcli\Aero\Snapdumpinfo_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .........................storcli /c%%i delete snapdump force......................... >> %TW-FN%\Broadcom_Products\Snapdump\Storcli\Aero\Snapdumpinfo_C%%i.txt
							%MR_Cli% /c%%i delete snapdump force >> %TW-FN%\Broadcom_Products\Snapdump\Storcli\Aero\Snapdumpinfo_C%%i.txt 2>&1
							REM   ......................................::.......................................

							REM IF NOT EXIST %TW-FN%\Broadcom_Products\Snapdump\Storcli\Aero\c%%i mkdir %TW-FN%\Broadcom_Products\Snapdump\Storcli\Aero\c%%i
                            IF EXIST snapdump* copy snapdump* %TW-FN%\Broadcom_Products\Snapdump\Storcli\Aero >> misc_output.txt 2>&1
                            IF EXIST rttdump* copy rttdump* %TW-FN%\Broadcom_Products\Snapdump\Storcli\Aero >> misc_output.txt 2>&1
							del snapdump* > nul 2>&1
							del rttdump* > nul 2>&1



 
							REM   ......................................::.......................................
							@ECHO %TW-FN% > %TW-FN%\Broadcom_Products\Storcli\Cx_show_all_C%%i.txt												
							@ECHO .............................storcli /C%%i show all.............................. >> %TW-FN%\Broadcom_Products\Storcli\Cx_show_all_C%%i.txt	
							%MR_Cli% /c%%i show all >> %TW-FN%\Broadcom_Products\Storcli\Cx_show_all_C%%i.txt 2>&1

							@ECHO Start_on_Controller_%%i...2 >> misc_output.txt 2>&1
							REM   ......................................::.......................................
							@ECHO %TW-FN% > %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt
							@ECHO .........................storcli /C%%i/eall/sall show all........................ >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt
							%MR_Cli% /c%%i/eall/sall show all >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt 2>&1
							@ECHO .....................storcli /call/eall/sall show smart........................ >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt
							%MR_Cli% /call/eall/sall show smart >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .................storcli /call/eall/sall show phyerrorcounters................. >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt
							%MR_Cli% /call/eall/sall show phyerrorcounters >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt 2>&1


							@ECHO Start_on_Controller_%%i...3 >> misc_output.txt 2>&1
							%MR_Cli% /c%%i show all >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt 2>&1
						

							@ECHO %TW-FN% > %TW-FN%\Broadcom_Products\Storcli\alilog_C%%i.txt												
							REM   ......................................::.......................................
							@ECHO ..........................storcli /C%%i show alilog.............................. >> %TW-FN%\Broadcom_Products\Storcli\alilog_C%%i.txt
							%MR_Cli% /c%%i show alilog >> %TW-FN%\Broadcom_Products\Storcli\alilog_C%%i.txt 2>&1



							@ECHO %TW-FN% > %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt												
							REM   ......................................::.......................................
							@ECHO ................................storcli show all............................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
							%MR_Cli% show all >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1

							IF EXIST %TW-FN%\Broadcom_Products\Storcli\Cx_show_all_C%%i.txt	(
															REM   ......................................::.......................................
															@ECHO .....................................Time...................................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
															%grep% "Current Controller Date/Time" %TW-FN%\Broadcom_Products\Storcli\Cx_show_all_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
															%grep% "Current System Date/time" %TW-FN%\Broadcom_Products\Storcli\Cx_show_all_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
															)
							
							@ECHO Start_on_Controller_%%i...4 >> misc_output.txt 2>&1
							REM   ......................................::.......................................
							@ECHO ...............................storcli /C%%i show................................ >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
							%MR_Cli% /C%%i show >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1

							%MR_Cli% /C%%i show termlog | %grep% "PCIE Link Status/Ctrl" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO ...............................PCI-E Link Speed................................ >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show termlog | %grep% "PCIE Link Status/Ctrl" >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)


							REM   ......................................::.......................................
							@ECHO ............................storcli /C%%i show bios.............................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
							%MR_Cli% /C%%i show bios >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
							@ECHO Start_on_Controller_%%i...5 >> misc_output.txt 2>&1
							%MR_Cli% /C%%i/vall show | %grep% "No VDs have been configured" >> misc_output.txt 2>&1
							IF ERRORLEVEL 1	(
									@ECHO Start_on_Controller_%%i...6 >> misc_output.txt 2>&1
									%MR_Cli% /C%%i show preservedcache | %grep% "Status = Success" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1	(
												REM   ......................................::.......................................
												@ECHO .......................storcli /C%%i show preservedcache......................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
												%MR_Cli% /C%%i show preservedcache >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
												)

									%MR_Cli% /C%%i/vall show all | %grep% "Status = Success" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1	(
												REM   ......................................::.......................................
												@ECHO ...........................storcli /C%%i/vall show all........................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
												%MR_Cli% /C%%i/vall show all >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
												)

									%MR_Cli% /c%%i/vall show bbmt | %grep% "Status = Success" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1	(		
												REM   ......................................::.......................................
												@ECHO ..........................storcli /C%%i/Vall show bbmt........................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt	
												%MR_Cli% /c%%i/vall show bbmt >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
												)
									@ECHO Start_on_Controller_%%i...7 >> misc_output.txt 2>&1
									%MR_Cli% /c%%i/vall show autobgi | %grep% "Status = Success" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1	(
												REM   ......................................::.......................................
												@ECHO .........................storcli /C%%i/Vall show autobgi......................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt	
												%MR_Cli% /c%%i/vall show autobgi >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1		
												)						

									%MR_Cli% /C%%i/vall show expansion | %grep% "Status = Success" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1	(
												REM   ......................................::.......................................
												@ECHO .............................VD Expansion Status............................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
												%MR_Cli% /C%%i/vall show expansion >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
												)

									%MR_Cli% /C%%i/vall show bgi | %grep% -e "In progress" -e "Paused" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1	(
												REM   ......................................::.......................................
												@ECHO .....................VD Background Initialization Status....................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
												%MR_Cli% /C%%i/vall show bgi | %grep% -e ------------- -e Estimated -e "In progress" -e Paused >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
												)
									@ECHO Start_on_Controller_%%i...8 >> misc_output.txt 2>&1
									%MR_Cli% /C%%i/vall show cc | %grep% -e "In progress" -e "Paused" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1	(
												REM   ......................................::.......................................
												@ECHO ..........................VD Consistency Check Status.......................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
												%MR_Cli% /C%%i/vall show cc | %grep% -e ------------- -e Estimated -e "In progress" -e Paused >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
												)
		
									%MR_Cli% /C%%i/vall show erase | %grep% -e "In progress" -e "Paused" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1	(
												REM   ......................................::.......................................
												@ECHO ...............................VD Erase Status................................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
												%MR_Cli% /C%%i/vall show erase | %grep% -e ------------- -e Estimated -e "In progress" -e Paused >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
												)
	
									%MR_Cli% /C%%i/vall show init | %grep% -e "In progress" -e "Paused" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1	(
												REM   ......................................::.......................................
												@ECHO ............................VD Initialization Status........................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
												%MR_Cli% /C%%i/vall show init | %grep% -e ------------- -e Estimated -e "In progress" -e Paused >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
												)
		
									%MR_Cli% /C%%i/vall show migrate | %grep% -e "In progress" -e "Paused" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1	(
												REM   ......................................::.......................................
												@ECHO ..............................VD Migration Status.............................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
												%MR_Cli% /C%%i/vall show migrate | %grep% -e ------------- -e Estimated -e "In progress" -e Paused >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
												)
									@ECHO Start_on_Controller_%%i...9 >> misc_output.txt 2>&1
									%MR_Cli% /C%%i/eall/sall show copyback | %grep% -e "In progress" -e "Paused" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1	(
												REM   ......................................::.......................................
												@ECHO ...............................copyback Status................................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
												%MR_Cli% /C%%i/eall/sall show copyback | %grep% -e ------------- -e Estimated -e "In progress" -e Paused >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
												)

									%MR_Cli% /C%%i/eall/sall show rebuild | %grep% -e "In progress" -e "Paused" >> misc_output.txt 2>&1
									IF NOT ERRORLEVEL 1	(
												REM   ......................................::.......................................
												@ECHO ................................Rebuild Status................................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
												%MR_Cli% /C%%i/eall/sall show rebuild | %grep% -e ------------- -e Estimated -e "In progress" -e Paused >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
												)
									@ECHO Start_on_Controller_%%i...10 >> misc_output.txt 2>&1
									)

							%MR_Cli% /C%%i/eall/sall show erase | %grep% -e "In progress" -e "Paused" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO ...............................Drive Erase Status.............................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i/eall/sall show erase | %grep% -e ------------- -e Estimated -e "In progress" -e Paused >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)
							@ECHO Start_on_Controller_%%i...11 >> misc_output.txt 2>&1
							%MR_Cli% /C%%i/eall/sall show initialization | %grep% -e "In progress" -e "Paused" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO ..........................Drive Initialization Status.......................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i/eall/sall show initialization | %grep% -e ------------- -e Estimated -e "In progress" -e Paused >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							%MR_Cli% /C%%i/eall/sall show securitykey keyid | %grep% -e "In progress" -e "Paused" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO .....................storcli /C%%ishow securitykey keyid......................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i/eall/sall show securitykey keyid | %grep% -e ------------- -e Estimated -e "In progress" -e Paused >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)
							@ECHO Start_on_Controller_%%i...12 >> misc_output.txt 2>&1
							%MR_Cli% /C%%i show freespace | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										@ECHO Start_on_Controller_%%i...12A >> misc_output.txt 2>&1
										REM   ......................................::.......................................
										@ECHO .........................storcli /C%%i show freespace............................ >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show freespace >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										@ECHO Start_on_Controller_%%i...12B >> misc_output.txt 2>&1
										)

							@ECHO Start_on_Controller_%%i...12C >> misc_output.txt 2>&1
							%MR_Cli% /C%%i show health all | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(						
										@ECHO Start_on_Controller_%%i...12D >> misc_output.txt 2>&1
										REM   ......................................::.......................................
										@ECHO ........................storcli /C%%i show health all............................ >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show health all >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										@ECHO Start_on_Controller_%%i...12E >> misc_output.txt 2>&1
										)

							@ECHO Start_on_Controller_%%i...12F >> misc_output.txt 2>&1
							%MR_Cli% /C%%i show cc | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(						
										@ECHO Start_on_Controller_%%i...12G >> misc_output.txt 2>&1
										REM   ......................................::.......................................
										@ECHO .............................storcli /C%%i show cc............................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show cc >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										@ECHO Start_on_Controller_%%i...12H >> misc_output.txt 2>&1
										)
							@ECHO Start_on_Controller_%%i...13 >> misc_output.txt 2>&1
							%MR_Cli% /C%%i show pr | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO .............................storcli /C%%i show pr............................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show pr >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)	

							%MR_Cli% /C%%i show copyback | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO ...........................storcli /C%%i show copyback........................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show copyback >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							%MR_Cli% /C%%i show failpdonsmarterror | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO .....................storcli /C%%i show failpdonsmarterror....................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show failpdonsmarterror >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)
							@ECHO Start_on_Controller_%%i...14 >> misc_output.txt 2>&1
							%MR_Cli% /C%%i show eghs | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO .............................storcli /C%%i show eghs............................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show eghs >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							%MR_Cli% /C%%i show cachebypass | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO .........................storcli /C%%i show cachebypass.......................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show cachebypass >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							%MR_Cli% /C%%i show perfmode | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO ...........................storcli /C%%i show perfmode........................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show perfmode >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)
							@ECHO Start_on_Controller_%%i...15 >> misc_output.txt 2>&1
							%MR_Cli% /C%%i show perfmodevalues | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO ........................storcli /C%%i show perfmodevalues........................ >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show perfmodevalues >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							%MR_Cli% /C%%i show immediateio | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO .......................storcli /C%%i show immediateio............................ >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show immediateio >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							%MR_Cli% /C%%i show largeQD | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO .........................storcli /C%%i show largeQD.............................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show largeQD >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)
							@ECHO Start_on_Controller_%%i...16 >> misc_output.txt 2>&1
							%MR_Cli% /C%%i show flushwriteverify | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO ......................storcli /C%%i show flushwriteverify........................ >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show flushwriteverify >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							%MR_Cli% /C%%i show largeiosupport | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO .......................storcli /C%%i show largeiosupport......................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show largeiosupport >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)
							@ECHO Start_on_Controller_%%i...17 >> misc_output.txt 2>&1
							%MR_Cli% /C%%i show personality | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO .......................storcli /C%%i show personality............................ >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show personality >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1

										@ECHO Start_on_Controller_%%i...18 >> misc_output.txt 2>&1
										%MR_Cli% /C%%i/epdall show | %grep% "Status = Success" >> misc_output.txt 2>&1
										IF NOT ERRORLEVEL 1	(
													REM   ......................................::.......................................
													@ECHO ..........................storcli /C%%i/epdall show.............................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
													%MR_Cli% /C%%i/epdall show >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
													
													@ECHO Start_on_Controller_%%i...19 >> misc_output.txt 2>&1
													%MR_Cli% /C%%i/epdall show erase | %grep% -e "In progress" -e "Paused" >> misc_output.txt 2>&1
													IF NOT ERRORLEVEL 1	(
																REM   ......................................::.......................................
																@ECHO ............................EPD Drive Erase Status............................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
																%MR_Cli% /C%%i/vall show erase | %grep% -e ------------- -e Estimated -e "In progress" -e Paused >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
																)
	
													%MR_Cli% /C%%i/epdall show init | %grep% -e "In progress" -e "Paused" >> misc_output.txt 2>&1
													IF NOT ERRORLEVEL 1	(
																REM   ......................................::.......................................
																@ECHO ........................EPD Drive Initialization Status........................ >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
																%MR_Cli% /C%%i/vall show init | %grep% -e ------------- -e Estimated -e "In progress" -e Paused >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
																)
													@ECHO Start_on_Controller_%%i...20 >> misc_output.txt 2>&1
													)
										)		


							@ECHO Start_on_Controller_%%i...21 >> misc_output.txt 2>&1
							%MR_Cli% /C%%i show pdfaileventoptions | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO ....................storcli /C%%i show pdfaileventoptions........................ >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show pdfaileventoptions >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										@ECHO ......................storcli /C%%i show pdfailevents............................ >> %TW-FN%\Broadcom_Products\Storcli\pdfailevents_C%%i.txt
										%MR_Cli% /C%%i show pdfailevents >> %TW-FN%\Broadcom_Products\Storcli\pdfailevents_C%%i.txt 2>&1
										)

							%MR_Cli% /C%%i show jbodwritecache | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO ......................storcli /C%%i show jbodwritecache.......................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show jbodwritecache >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							@ECHO Start_on_Controller_%%i...22 >> misc_output.txt 2>&1
							%MR_Cli% /C%%i show wbsupport | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO .......................storcli /C%%i show wbsupport.............................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show wbsupport >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							%MR_Cli% /C%%i show autopdcache | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO ......................storcli /C%%i show autopdcache............................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show autopdcache >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							%MR_Cli% /C%%i show fshinting | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO ...........................storcli /C%%i show fshinting.......................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show fshinting >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)	

							@ECHO Start_on_Controller_%%i...23 >> misc_output.txt 2>&1
							%MR_Cli% /C%%i show ocr | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO .............................storcli /C%%i show ocr.............................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show ocr >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							%MR_Cli% /C%%i show bootwithpinnedcache | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO .....................storcli /C%%i show bootwithpinnedcache...................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show bootwithpinnedcache >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							%MR_Cli% /C%%i show autorebuild | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO ........................storcli /C%%i show autorebuild........................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show autorebuild >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							@ECHO Start_on_Controller_%%i...24 >> misc_output.txt 2>&1
							%MR_Cli% /C%%i show badblocks | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO .........................storcli /C%%i show badblocks............................ >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show badblocks >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							%MR_Cli% /C%%i show ds | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO ............................storcli /C%%i show ds................................ >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show ds >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							%MR_Cli% /C%%i show aso | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO ............................storcli /C%%i show aso............................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show aso >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							@ECHO Start_on_Controller_%%i...25 >> misc_output.txt 2>&1
							%MR_Cli% /C%%i show bootdrive | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO .........................storcli /C%%i show bootdrive............................ >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show bootdrive >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							%MR_Cli% /C%%i/pall show all | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO .........................storcli /C%%i/pall show all............................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i/pall show all >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							%MR_Cli% /C%%i show backplane | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO .........................storcli /C%%i show backplane............................ >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show backplane >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							@ECHO Start_on_Controller_%%i...26 >> misc_output.txt 2>&1
							%MR_Cli% /C%%i show sesmonitoring | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO ......................storcli /C%%i show sesmonitoring........................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i show sesmonitoring >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							%MR_Cli% /C%%i/eall show all | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO .........................storcli /C%%i/eall show all............................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i/eall show all >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)	

							%MR_Cli% /C%%i/eall show status | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO .......................storcli /C%%i/eall show status............................ >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i/eall show status >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)

							%MR_Cli% /C%%i/eall show phyerrorcounters | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO ..................storcli /C%%i/eall show phyerrorcounters....................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i/eall show phyerrorcounters >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)	

							@ECHO Start_on_Controller_%%i...27 >> misc_output.txt 2>&1
							IF EXIST %TW-FN%\Broadcom_Products\Storcli\Cx_show_all_C%%i.txt	(
															REM   ......................................::.......................................
															@ECHO .................................Temperatures.................................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
															%grep% -e "Temperature Sensor for" %TW-FN%\Broadcom_Products\Storcli\Cx_show_all_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
															%grep% -e "ROC temperature" %TW-FN%\Broadcom_Products\Storcli\Cx_show_all_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
															)
						

							IF EXIST %TW-WS%iBBU_PRESENT_C%%i.txt	(
												REM   ......................................::.......................................
												@ECHO ..............................iBBU Temperature................................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
												%MR_Cli% /C%%i/bbu show all | %grep% -e "Temperature" >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
												)

							IF EXIST %TW-WS%SuperCaP_PRESENT_C%%i.txt	(
													REM   ......................................::.......................................
													@ECHO ................................CV Temperature................................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
													%MR_Cli% /C%%i/cv show all | %grep% -e "Temperature" >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
													)
									

REM MegaCli syntax - Cant grep proper output in Windows from "/ex show status"
REM JSON output makes data available but cant clean up in Windows....
	
							@ECHO Start_on_Controller_%%i...28 >> misc_output.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .............................Enclosure Temperature............................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
							%MR_Cli% encinfo a%%i | %grep% -e "Temp Sensor                  :" -e "Temperature                  :" >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1

							IF EXIST %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt	(
																REM   ......................................::.......................................
																@ECHO ...............................Drive Temperature............................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
																%grep% -e "Drive Temperature =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ...............................Media Error Count............................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
																%grep% -e "Media Error Count =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
																REM   ......................................::.......................................
																@ECHO .............................Predictive Failure Count.......................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
																%grep% -e "Predictive Failure Count =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ..................................Device Speed................................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
																%grep% -e "Device Speed =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ....................Port # - Status - Linkspeed - SAS Address.................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
																%grep% -e "Gb/s 0x" -e "Gb/s  0x" -e "Gb/s   0x" -e "Gb/s    0x" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
																)

							@ECHO Start_on_Controller_%%i...29 >> misc_output.txt 2>&1
							IF EXIST %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt	(
																@ECHO %TW-FN% > %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt	
																REM   ......................................::.......................................
																
																@ECHO ....................................Drives..................................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%MR_Cli% /C%%i/eall/sall show | %grep% -e "SATA" -e "SAS" >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt

																REM   ......................................::.......................................
																@ECHO .................................Shield Counter................................ >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Shield Counter =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ...............................Media Error Count............................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Media Error Count =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ...............................Other Error Count............................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Other Error Count =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ...............................Drive Temperature............................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Drive Temperature =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ............................Predictive Failure Count........................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Predictive Failure Count =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ........................S.M.A.R.T alert flagged by drive....................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "S.M.A.R.T alert flagged by drive =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ......................................SN....................................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "SN =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ......................................WWN...................................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "WWN =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
									
																@ECHO Start_on_Controller_%%i...30 >> misc_output.txt 2>&1
									
																@ECHO ...............................Firmware Revision............................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Firmware Revision =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ...................................Raw size.................................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Raw size =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO .................................Coerced size.................................. >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Coerced size =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ................................Non Coerced size............................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Non Coerced size =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO .................................Device Speed.................................. >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Device Speed =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ..................................Link Speed................................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Link Speed =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ...............................Drive write cache............................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Drive write cache =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ..............................Logical Sector Size.............................. >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Logical Sector Size =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO .............................Physical Sector Size.............................. >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Physical Sector Size =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ................................Drive position................................. >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Drive position =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ..............................Enclosure position............................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Enclosure position =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO .............................Connected Port Number............................. >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Connected Port Number =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ................................Sequence Number................................ >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Sequence Number =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ...............................Commissioned Spare.............................. >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Commissioned Spare =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ................................Emergency Spare................................ >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Emergency Spare =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO .................Last Predictive Failure Event Sequence Number................. >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Last Predictive Failure Event Sequence Number =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................

																@ECHO Start_on_Controller_%%i...31 >> misc_output.txt 2>&1

																@ECHO ......................Successful diagnostics completion on..................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Successful diagnostics completion on =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO .................................SED Capable................................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "SED Capable =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO .................................SED Enabled................................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "SED Enabled =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ....................................Secured.................................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Secured =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ....................................Locked..................................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Locked =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ..............................Needs EKM Attention.............................. >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Needs EKM Attention =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO .................................PI Eligible................................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "PI Eligible =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ...............................Wide Port Capable............................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Wide Port Capable =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																REM   ......................................::.......................................
																@ECHO ...................Port # - Status - Linkspeed - SAS Address................... >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%grep% -e "Gb/s   0x =" %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-plus_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt

																REM   ......................................::.......................................
																@ECHO .................................Inquiry Data.................................. >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																%MR_Cli% /C%%i/eall/sall show all j | %grep% -e "Inquiry Data" >> %TW-FN%\Broadcom_Products\Storcli\Cx_Eall_Sall_show_all-Compare-All-Parms_C%%i.txt
																)

							@ECHO Start_on_Controller_%%i...32 >> misc_output.txt 2>&1

							IF EXIST %TW-WS%iBBU_PRESENT_C%%i.txt	(
												REM   ......................................::.......................................
												@ECHO ..........................storcli /C%%i/bbu show all............................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
												%MR_Cli% /C%%i/bbu show all >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
												)	

							IF EXIST %TW-WS%SuperCaP_PRESENT_C%%i.txt	(
													REM   ......................................::.......................................
													@ECHO ..........................storcli /C%%i/cv show all.............................. >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
													%MR_Cli% /C%%i/cv show all >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
													)				
							%MR_Cli% /C%%i/fall show all | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO ..........................storcli /C%%i/fall show all............................ >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i/fall show all >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)
	
							%MR_Cli% /C%%i/fall import preview | %grep% "Status = Success" >> misc_output.txt 2>&1
							IF NOT ERRORLEVEL 1	(
										REM   ......................................::.......................................
										@ECHO ........................storcli /C%%i/fall import preview........................ >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
										%MR_Cli% /C%%i/fall import preview >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
										)


							@ECHO Start_on_Controller_%%i...33 >> misc_output.txt 2>&1
							REM   ......................................::.......................................
							@ECHO .........................storcli /C%%i show eventloginfo......................... >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
							%MR_Cli% /C%%i show eventloginfo >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1
							REM   ......................................::.......................................


							REM   ......................................::.......................................
							@ECHO ...................storcli /C%%i show termlog type=config........................ >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt

							%MR_Cli% /C%%i show termlog type=config >> %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt 2>&1
							%MR_Cli% /C%%i show termlog type=config >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1


							REM   ......................................::.......................................
							@ECHO ...........................storcli /C%%i show termlog............................ >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt
							%MR_Cli% /C%%i show termlog >> %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt 2>&1
							%MR_Cli% /C%%i show termlog >> %TW-FN%\Broadcom_Products\Storcli\Controller_C%%i.txt 2>&1

							@ECHO Start_on_Controller_%%i...34 >> misc_output.txt 2>&1

							@ECHO End on Controller %%i... >> misc_output.txt 2>&1
							@ECHO End on MegaRAID Controller %%i... > %TW-WS%End_MegaRAID_storcli_Controller_%%i.txt
							IF NOT [%NOWOW64%]==[YES] (.\xdir /Form=*t %TW-WS%End_MegaRAID_storcli_Controller_%%i.txt >> misc_output.txt 2>&1)
							REM IF NOT [%NOWOW64%]==[YES] (%TW-WS%timers\timer100\timer100 /s /nologo)
							)

@ECHO End of the MegaRAID Controller Data Collection with storcli... >> misc_output.txt 2>&1
@ECHO End of the MegaRAID Controller Data Collection with storcli... > %TW-WS%End_MegaRAID_storcli.txt
IF NOT [%NOWOW64%]==[YES] (.\xdir /Form=*t %TW-WS%End_MegaRAID_storcli.txt >> misc_output.txt 2>&1)
%grep% -c -e 0 -e 1 -e 2 -e 3 %TW-WS%mr_ctrl_nums.txt | %grep% 1 >> misc_output.txt 2>&1
REM IF ERRORLEVEL 1	(
REM 		IF NOT [%NOWOW64%]==[YES] (@ECHO Cumulative - storcli Syntax:)
REM 		IF NOT [%NOWOW64%]==[YES] (%TW-WS%timers\timer3\timer3 /s /nologo)
REM 		)


IF NOT [%TWGETSKIPRECORDCAPTURE%]==[YES]	(

						@ECHO .
						REM IF NOT [%NOWOW64%]==[YES] (%TW-WS%timers\timer4\timer4 /q /nologo)
						REM   ......................................::.......................................   
SET STORCLI1_C=%time%						
						@ECHO Start of the MegaRAID Event Record Capture... 
						IF [%NOWOW64%]==[YES] (@ECHO %time%)
						@ECHO This will take approx. 1 minute per 78K/0x130B0 Event Records per Controller...
						@ECHO Start of the MegaRAID Event Record Capture... >> misc_output.txt 2>&1
						@ECHO This will take approx. 1 minute per 78K/0x130B0 Event Records per Controller... >> misc_output.txt 2>&1
						@ECHO Start of the MegaRAID Event Record Capture...  > %TW-WS%Start_MegaRAID_Record_Capture.txt
						@ECHO This will take approx. 1 minute per 78K/0x130B0 Event Records per Controller... >> %TW-WS%Start_MegaRAID_Record_Capture.txt
						.\xdir /Form=*t %TW-WS%Start_MegaRAID_Record_Capture.txt >> misc_output.txt 2>&1
						
						
						FOR /F "usebackq" %%i IN (%TW-WS%mr_ctrl_nums.txt) DO	(
													REM IF NOT [%NOWOW64%]==[YES] (%TW-WS%timers\timer100\timer100 /q /nologo)
													@ECHO Start on Controller %%i...
													@ECHO Start on Controller %%i... > %TW-WS%Start_MegaRAID_Event_Collection%%i.txt
													IF NOT [%NOWOW64%]==[YES] (.\xdir /Form=*t %TW-WS%Start_MegaRAID_Event_Collection%%i.txt >> misc_output.txt 2>&1)
													%MR_Cli% /C%%i show eventloginfo | %grep% -e "Newest" -e "Oldest"
													
						
													REM   ......................................::.......................................
													IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli\Event_Logs mkdir %TW-FN%\Broadcom_Products\Storcli\Event_Logs
													@ECHO %TW-FN% > %TW-FN%\Broadcom_Products\Storcli\Event_Logs\evtlog_ID_C%%i.txt 2>&1							
													@ECHO ..................storcli /C%%i show events type=includedeleted.................. >> %TW-FN%\Broadcom_Products\Storcli\Event_Logs\evtlog_ID_C%%i.txt
													%MR_Cli% /C%%i show events type=includedeleted file=%TW-FN%\Broadcom_Products\Storcli\Event_Logs\evtlog_ID_C%%i.txt >> misc_output.txt 2>&1
						
													@ECHO End on Controller %%i... >> misc_output.txt 2>&1
													@ECHO End on MegaRAID Controller %%i... > %TW-WS%End_MegaRAID_Event_Collection%%i.txt
													IF NOT [%NOWOW64%]==[YES] (.\xdir /Form=*t %TW-WS%End_MegaRAID_Event_Collection%%i.txt >> misc_output.txt 2>&1)
													REM IF NOT [%NOWOW64%]==[YES] (%TW-WS%timers\timer100\timer100 /s /nologo)
													)
						
						
						@ECHO End of the MegaRAID Event Record Capture... >> misc_output.txt 2>&1
						@ECHO End of the MegaRAID Event Record Capture... > %TW-WS%End_MegaRAID_Record_Capture.txt
						IF NOT [%NOWOW64%]==[YES] (.\xdir /Form=*t %TW-WS%End_MegaRAID_Record_Capture.txt >> misc_output.txt 2>&1)
						%grep% -c -e 0 -e 1 -e 2 -e 3 %TW-WS%mr_ctrl_nums.txt | %grep% 1 >> misc_output.txt 2>&1
						REM IF ERRORLEVEL 1	(
						REM 		@ECHO Cumulative - Event Capture:
						REM 		IF NOT [%NOWOW64%]==[YES] (%TW-WS%timers\timer4\timer4 /s /nologo)
						REM 		)
						)

REM ###########################################################################################################################
REM MegaRAID Adapter Event log sorting
REM ###########################################################################################################################
SET STORCLI1_D=%time%
IF NOT [%TWGETSKIPRECORDSORT%]==[YES]	( 
					
					IF NOT EXIST %TW-WS%mr_aen_sort mkdir %TW-WS%mr_aen_sort
					IF EXIST %TW-WS%aens_mr.txt move /Y %TW-WS%aens_mr.txt %TW-WS%mr_aen_sort\ >> misc_output.txt 2>&1

					@ECHO .
					REM IF NOT [%NOWOW64%]==[YES] (%TW-WS%timers\timer5\timer5 /q /nologo)
					REM   ......................................::.......................................
					@ECHO Start of the MegaRAID Event Record Sort...
					IF [%NOWOW64%]==[YES] (@ECHO %time%)
					@ECHO This will take approx. 1 minute per 78,000 Event Records per Controller...
					@ECHO Start of the MegaRAID Event Record Sort... >> misc_output.txt 2>&1
					@ECHO This will take approx. 1 minute per 78,000 Event Records per Controller... >> misc_output.txt 2>&1
					@ECHO Start of the MegaRAID Event Record Sort... > %TW-WS%mr_aen_sort\Start_MegaRAID_Record_Sort.txt
					@ECHO This will take approx. 1 minute per 78,000 Event Records per Controller... >> %TW-WS%mr_aen_sort\Start_MegaRAID_Record_Sort.txt
					IF NOT [%NOWOW64%]==[YES] (.\xdir /Form=*t %TW-WS%mr_aen_sort\Start_MegaRAID_Record_Sort.txt >> misc_output.txt 2>&1)
					
					
					FOR /F "usebackq" %%i IN (%TW-WS%mr_ctrl_nums.txt) DO	(
												REM IF NOT [%NOWOW64%]==[YES] (%TW-WS%timers\timer100\timer100 /q /nologo)
												@ECHO Start on Controller %%i...
												@ECHO Start on Controller %%i... >> misc_output.txt 2>&1
												@ECHO Start on Controller %%i... > %TW-WS%mr_aen_sort\Start_MegaRAID_Record_Sort_Controller_%%i.txt
												IF NOT [%NOWOW64%]==[YES] (.\xdir /Form=*t %TW-WS%mr_aen_sort\Start_MegaRAID_Record_Sort_Controller_%%i.txt >> misc_output.txt 2>&1)
					
									
												%grep% "Code: 0x" %TW-FN%\Broadcom_Products\Storcli\Event_Logs\evtlog_ID_C%%i.txt > %TW-WS%mr_aen_sort\all_aen_iterations_C%%i.txt
												
												
												FOR /F "tokens=1,2" %%j in (%TW-WS%mr_aen_sort\all_aen_iterations_C%%i.txt) DO	(@ECHO %%j %%k > %TW-WS%mr_aen_sort\"%%k_used_aens_C%%i.txt")
												
												
												dir /B %TW-WS%mr_aen_sort\*_used_aens_C%%i.txt > %TW-WS%mr_aen_sort\all_used_aens_C%%i.txt
												
												
												FOR /F "tokens=1 delims=_" %%j in (%TW-WS%mr_aen_sort\all_used_aens_C%%i.txt) DO	(
																							Echo Number of Events : > %TW-WS%mr_aen_sort\"%%j_AEN_C%%i.txt"
																							%grep% "Code: %%j" %TW-FN%\Broadcom_Products\Storcli\Event_Logs\evtlog_ID_C%%i.txt -c >> %TW-WS%mr_aen_sort\"%%j_AEN_C%%i.txt"
																							@ECHO .................................................................................................... >> %TW-WS%mr_aen_sort\"%%j_AEN_C%%i.txt"
																							%grep% -B 3 -A 5 "Code: %%j" %TW-FN%\Broadcom_Products\Storcli\Event_Logs\evtlog_ID_C%%i.txt >> %TW-WS%mr_aen_sort\"%%j_AEN_C%%i.txt"
																							%grep% "Code: %%j" %TW-WS%mr_aen_sort\aens_mr.txt >> %TW-WS%mr_aen_sort\aens_mr_used_C%%i.txt
																							)
												
												
												FOR /F "tokens=1,2,3" %%j in (%TW-WS%mr_aen_sort\aens_mr_used_C%%i.txt) DO (move /Y %TW-WS%mr_aen_sort\"%%k_AEN_C%%i.txt" %TW-FN%\Broadcom_Products\Storcli\Event_Logs\%%k_%%l_C%%i.txt >> misc_output.txt 2>&1)
					
												)
					
					
					
					FOR /F "usebackq" %%i IN (%TW-WS%mr_ctrl_nums.txt) DO	(
												dir %TW-FN%\Broadcom_Products\Storcli\Event_Logs\*_C%%i.txt >> misc_output.txt 2>&1
												IF NOT ERRORLEVEL 1	(
															mkdir %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Controller_C%%i >> misc_output.txt 2>&1
															copy %TW-FN%\Broadcom_Products\Storcli\Event_Logs\*_C%%i.txt %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Controller_C%%i >> misc_output.txt 2>&1
															)
												)
					
					
					FOR /F "usebackq" %%i IN (%TW-WS%mr_aen_types.txt) DO	(
												dir %TW-FN%\Broadcom_Products\Storcli\Event_Logs\*_%%i_* >> misc_output.txt 2>&1
												IF NOT ERRORLEVEL 1	(
															mkdir %TW-FN%\Broadcom_Products\Storcli\Event_Logs\%%i >> misc_output.txt 2>&1
															move /Y %TW-FN%\Broadcom_Products\Storcli\Event_Logs\*_%%i_* %TW-FN%\Broadcom_Products\Storcli\Event_Logs\%%i >> misc_output.txt 2>&1
															)
												)
					
					FOR /F "usebackq" %%i IN (%TW-WS%mr_ctrl_nums.txt) DO	(
												FOR /F "usebackq" %%j IN (%TW-WS%mr_aen_types.txt) DO	(
																			dir %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Controller_C%%i\*_%%j_* >> misc_output.txt 2>&1
																			IF NOT ERRORLEVEL 1	(
																						mkdir %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Controller_C%%i\%%j >> misc_output.txt 2>&1
																						move /Y %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Controller_C%%i\*_%%j_* %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Controller_C%%i\%%j >> misc_output.txt 2>&1
																						)
																			)
												)	
					
					FOR /F "usebackq" %%i IN (%TW-WS%mr_ctrl_nums.txt) DO	(
												dir %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Controller_C%%i\*_C%%i.txt >> misc_output.txt 2>&1
												IF NOT ERRORLEVEL 1	(
															IF EXIST %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Controller_C%%i\evtlog_GE_C%%i.txt del %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Controller_C%%i\evtlog_GE_C%%i.txt >> misc_output.txt 2>&1
															IF EXIST %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Controller_C%%i\evtlog_GSR_C%%i.txt del %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Controller_C%%i\evtlog_GSR_C%%i.txt >> misc_output.txt 2>&1
															IF EXIST %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Controller_C%%i\evtlog_GSS_C%%i.txt del %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Controller_C%%i\evtlog_GSS_C%%i.txt >> misc_output.txt 2>&1
															IF EXIST %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Controller_C%%i\evtlog_ID_C%%i.txt del %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Controller_C%%i\evtlog_ID_C%%i.txt >> misc_output.txt 2>&1
															IF EXIST %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Controller_C%%i\Return_getlatest_* del %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Controller_C%%i\Return_getlatest_* >> misc_output.txt 2>&1
															)
												@ECHO End on Controller %%i... >> misc_output.txt 2>&1
												@ECHO End on MegaRAID Controller %%i... > %TW-WS%mr_aen_sort\End_MegaRAID_Record_Sort_Controller_%%i.txt
												IF NOT [%NOWOW64%]==[YES] (.\xdir /Form=*t %TW-WS%mr_aen_sort\End_MegaRAID_Record_Sort_Controller_%%i.txt >> misc_output.txt 2>&1)
												REM IF NOT [%NOWOW64%]==[YES] (%TW-WS%timers\timer100\timer100 /s /nologo)
												)
					
					@ECHO End of the MegaRAID Event Record Sort... >> misc_output.txt 2>&1
					@ECHO End of the MegaRAID Event Record Sort... > %TW-WS%mr_aen_sort\End_MegaRAID_Record_Sort.txt
					IF NOT [%NOWOW64%]==[YES] (.\xdir /Form=*t %TW-WS%mr_aen_sort\End_MegaRAID_Record_Sort.txt >> misc_output.txt 2>&1)
					%grep% -c -e 0 -e 1 -e 2 -e 3 %TW-WS%mr_ctrl_nums.txt | %grep% 1 >> misc_output.txt 2>&1
					REM IF ERRORLEVEL 1	(
					REM 		IF NOT [%NOWOW64%]==[YES] (@ECHO Cumulative - Event Sort:)
					REM 		IF NOT [%NOWOW64%]==[YES] (%TW-WS%timers\timer5\timer5 /s /nologo)
					REM 		)
					)

REM ###########################################################################################################################
REM # storcli fwtermlog dsply Cx - fwtermlog error screening 
REM # 
REM # Words to look out for... Fault Panic BAIL_OUT Paused REC CRC Unrecoverable Sense
REM ###########################################################################################################################
SET STORCLI1_E=%time%
FOR /F "usebackq" %%i IN (%TW-WS%mr_ctrl_nums.txt) DO	(																
							IF EXIST %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt	(
															%grep% -e "Fatal firmware error: Line" %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt >> %TW-WS%fwtermlog_C%%i_Fatal.txt 2>&1
															dir %TW-WS%fwtermlog_C%%i_Fatal.txt | find /I " 0 fwtermlog_C%%i_Fatal.txt" >> misc_output.txt 2>&1
															IF NOT ERRORLEVEL 1 del %TW-WS%fwtermlog_C%%i_Fatal.txt
															REM                                            .................................................::.................................................
															IF EXIST %TW-WS%fwtermlog_C%%i_Fatal.txt @ECHO ...................Controller C%%i fwtermlog - contains Fatal firmware error: Line.................... >> %TW-FN%\Broadcom_Products\Storcli\Fatal_FW_Error_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_Fatal.txt @ECHO .......This indicates that a SERIOUS FW Issue has occured, contact Tech. Support or your FAE........ >> %TW-FN%\Broadcom_Products\Storcli\Fatal_FW_Error_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_Fatal.txt type %TW-WS%fwtermlog_C%%i_Fatal.txt >> %TW-FN%\Broadcom_Products\Storcli\Fatal_FW_Error_FWTermLog_C%%i.txt
															)
							IF EXIST %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt	(
															%grep% -e " Fault " %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt >> %TW-WS%fwtermlog_C%%i_Fault.txt 2>&1
															dir %TW-WS%fwtermlog_C%%i_Fault.txt | find /I " 0 fwtermlog_C%%i_Fault.txt" >> misc_output.txt 2>&1
															IF NOT ERRORLEVEL 1 del %TW-WS%fwtermlog_C%%i_Fault.txt
															REM                                            .................................................::.................................................
															IF EXIST %TW-WS%fwtermlog_C%%i_Fault.txt @ECHO ..............................Controller C%%i fwtermlog - contains Fault.............................. >> %TW-FN%\Broadcom_Products\Storcli\Fault_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_Fault.txt @ECHO .......This indicates that a SERIOUS FW Issue has occured, contact Tech. Support or your FAE........ >> %TW-FN%\Broadcom_Products\Storcli\Fault_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_Fault.txt type %TW-WS%fwtermlog_C%%i_Fault.txt >> %TW-FN%\Broadcom_Products\Storcli\Fault_FWTermLog_C%%i.txt
															)
							IF EXIST %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt	(
															%grep% -e "Panic" %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt >> %TW-WS%fwtermlog_C%%i_Panic.txt 2>&1
															dir %TW-WS%fwtermlog_C%%i_Panic.txt | find /I " 0 fwtermlog_C%%i_Panic.txt" >> misc_output.txt 2>&1
															IF NOT ERRORLEVEL 1 del %TW-WS%fwtermlog_C%%i_Panic.txt
															REM                                            .................................................::.................................................
															IF EXIST %TW-WS%fwtermlog_C%%i_Panic.txt @ECHO ..............................Controller C%%i fwtermlog - contains Panic.............................. >> %TW-FN%\Broadcom_Products\Storcli\Panic_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_Panic.txt @ECHO .......This indicates that a SERIOUS FW Issue has occured, contact Tech. Support or your FAE........ >> %TW-FN%\Broadcom_Products\Storcli\Panic_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_Panic.txt type %TW-WS%fwtermlog_C%%i_Panic.txt >> %TW-FN%\Broadcom_Products\Storcli\Panic_FWTermLog_C%%i.txt
															)
							IF EXIST %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt	(
															%grep% -e "BAIL_OUT" %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt >> %TW-WS%fwtermlog_C%%i_BAIL_OUT.txt 2>&1
															dir %TW-WS%fwtermlog_C%%i_BAIL_OUT.txt | find /I " 0 fwtermlog_C%%i_BAIL_OUT.txt" >> misc_output.txt 2>&1
															IF NOT ERRORLEVEL 1 del %TW-WS%fwtermlog_C%%i_BAIL_OUT.txt
															REM                                               .................................................::.................................................
															IF EXIST %TW-WS%fwtermlog_C%%i_BAIL_OUT.txt @ECHO .............................Controller C%%i fwtermlog - contains BAIL_OUT............................ >> %TW-FN%\Broadcom_Products\Storcli\BAIL_OUT_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_BAIL_OUT.txt @ECHO .......This indicates that a SERIOUS FW Issue has occured, contact Tech. Support or your FAE........ >> %TW-FN%\Broadcom_Products\Storcli\BAIL_OUT_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_BAIL_OUT.txt type %TW-WS%fwtermlog_C%%i_BAIL_OUT.txt >> %TW-FN%\Broadcom_Products\Storcli\BAIL_OUT_FWTermLog_C%%i.txt
															)
							IF EXIST %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt	(
															%grep% -e "Paused" %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt >> %TW-WS%fwtermlog_C%%i_Paused.txt 2>&1
															dir %TW-WS%fwtermlog_C%%i_Paused.txt | find /I " 0 fwtermlog_C%%i_Paused.txt" >> misc_output.txt 2>&1
															IF NOT ERRORLEVEL 1 del %TW-WS%fwtermlog_C%%i_Paused.txt
															REM                                             .................................................::.................................................
															IF EXIST %TW-WS%fwtermlog_C%%i_Paused.txt @ECHO .............................Controller C%%i fwtermlog - contains Paused.............................. >> %TW-FN%\Broadcom_Products\Storcli\Paused_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_Paused.txt @ECHO .....................................This should be investigated.................................... >> %TW-FN%\Broadcom_Products\Storcli\Paused_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_Paused.txt type %TW-WS%fwtermlog_C%%i_Paused.txt >> %TW-FN%\Broadcom_Products\Storcli\Paused_FWTermLog_C%%i.txt
															)
							IF EXIST %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt	(
															%grep% -e "MPI2_EVENT_SAS_QUIESCE_RC_STARTED" -e "MPI2_EVENT_SAS_QUIESCE_RC_COMPLETED" -e "Test event: An unexpected data IO error occurred on PD" %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt >> %TW-WS%fwtermlog_C%%i_Test_Event.txt 2>&1
															dir %TW-WS%fwtermlog_C%%i_Test_Event.txt | find /I " 0 fwtermlog_C%%i_Test_Event.txt" >> misc_output.txt 2>&1
															IF NOT ERRORLEVEL 1 del %TW-WS%fwtermlog_C%%i_Test_Event.txt
															REM                                                 .................................................::.................................................
															IF EXIST %TW-WS%fwtermlog_C%%i_Test_Event.txt @ECHO .............................Controller C%%i fwtermlog - contains Test_Event.......................... >> %TW-FN%\Broadcom_Products\Storcli\Test_Event_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_Test_Event.txt @ECHO .....................................This should be investigated.................................... >> %TW-FN%\Broadcom_Products\Storcli\Test_Event_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_Test_Event.txt type %TW-WS%fwtermlog_C%%i_Test_Event.txt >> %TW-FN%\Broadcom_Products\Storcli\Test_Event_FWTermLog_C%%i.txt
															)
							IF EXIST %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt	(
															%grep% -e "REC " %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt >> %TW-WS%fwtermlog_C%%i_REC.txt 2>&1
															dir %TW-WS%fwtermlog_C%%i_REC.txt | find /I " 0 fwtermlog_C%%i_REC.txt" >> misc_output.txt 2>&1
															IF NOT ERRORLEVEL 1 del %TW-WS%fwtermlog_C%%i_REC.txt >> misc_output.txt 2>&1
															REM                                          .................................................::.................................................
															IF EXIST %TW-WS%fwtermlog_C%%i_REC.txt @ECHO ..............................Controller C%%i fwtermlog - contains REC................................ >> %TW-FN%\Broadcom_Products\Storcli\REC_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_REC.txt @ECHO .....................................This should be investigated..................................... >> %TW-FN%\Broadcom_Products\Storcli\REC_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_REC.txt type %TW-WS%fwtermlog_C%%i_REC.txt >> %TW-FN%\Broadcom_Products\Storcli\REC_FWTermLog_C%%i.txt
															)
							IF EXIST %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt	(
															%grep% -e "Unrecoverable" %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt >> %TW-WS%fwtermlog_C%%i_Unrecoverable.txt 2>&1
															dir %TW-WS%fwtermlog_C%%i_Unrecoverable.txt | find /I " 0 fwtermlog_C%%i_Unrecoverable.txt" >> misc_output.txt 2>&1
															IF NOT ERRORLEVEL 1 del %TW-WS%fwtermlog_C%%i_Unrecoverable.txt >> misc_output.txt 2>&1
															REM                                                    .................................................::.................................................
															IF EXIST %TW-WS%fwtermlog_C%%i_Unrecoverable.txt @ECHO ...........................Controller C%%i fwtermlog - contains Unrecoverable......................... >> %TW-FN%\Broadcom_Products\Storcli\Unrecoverable_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_Unrecoverable.txt @ECHO .....................................This should be investigated..................................... >> %TW-FN%\Broadcom_Products\Storcli\Unrecoverable_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_Unrecoverable.txt type %TW-WS%fwtermlog_C%%i_Unrecoverable.txt >> %TW-FN%\Broadcom_Products\Storcli\Unrecoverable_FWTermLog_C%%i.txt
															)
							IF EXIST %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt	(
															%grep% -e "CRC" %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt >> %TW-WS%fwtermlog_C%%i_CRC.txt 2>&1
															dir %TW-WS%fwtermlog_C%%i_CRC.txt | find /I " 0 fwtermlog_C%%i_CRC.txt" >> misc_output.txt 2>&1
															IF NOT ERRORLEVEL 1 del %TW-WS%fwtermlog_C%%i_CRC.txt >> misc_output.txt 2>&1
															REM                                          .................................................::.................................................
															IF EXIST %TW-WS%fwtermlog_C%%i_CRC.txt @ECHO ...............................Controller C%%i fwtermlog - contains CRC............................... >> %TW-FN%\Broadcom_Products\Storcli\CRC_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_CRC.txt @ECHO .....................................This should be investigated..................................... >> %TW-FN%\Broadcom_Products\Storcli\CRC_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_CRC.txt type %TW-WS%fwtermlog_C%%i_CRC.txt >> %TW-FN%\Broadcom_Products\Storcli\CRC_FWTermLog_C%%i.txt
															)
							REM IF EXIST %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt	(
															REM %grep% -e "Sense" %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt >> %TW-WS%fwtermlog_C%%i_Sense.txt 2>&1
															REM dir %TW-WS%fwtermlog_C%%i_Sense.txt | find /I " 0 fwtermlog_C%%i_Sense.txt" >> misc_output.txt 2>&1
															REM IF NOT ERRORLEVEL 1 del %TW-WS%fwtermlog_C%%i_Sense.txt >> misc_output.txt 2>&1
															REM REM                                            .................................................::.................................................
															REM IF EXIST %TW-WS%fwtermlog_C%%i_Sense.txt @ECHO ...............................Controller C%%i fwtermlog - contains Sense............................. >> %TW-FN%\Broadcom_Products\Storcli\Sense_FWTermLog_C%%i.txt
															REM IF EXIST %TW-WS%fwtermlog_C%%i_Sense.txt type %TW-WS%fwtermlog_C%%i_Sense.txt >> %TW-FN%\Broadcom_Products\Storcli\Sense_FWTermLog_C%%i.txt
															)
							
							IF EXIST %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt	(
															%grep% -i -e "Battery Put to Sleep" %TW-FN%\Broadcom_Products\Storcli\fwtermlog_C%%i.txt >> %TW-WS%fwtermlog_C%%i_BatterySleep.txt 2>&1
															dir %TW-WS%fwtermlog_C%%i_BatterySleep.txt | find /I " 0 fwtermlog_C%%i_BatterySleep.txt" >> misc_output.txt 2>&1
															IF NOT ERRORLEVEL 1 del %TW-WS%fwtermlog_C%%i_BatterySleep.txt >> misc_output.txt 2>&1
															REM                                                   .................................................::.................................................
															IF EXIST %TW-WS%fwtermlog_C%%i_BatterySleep.txt @ECHO ......................Controller C%%i fwtermlog - contains Battery Put to Sleep....................... >> %TW-FN%\Broadcom_Products\Storcli\BatterySleep_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_BatterySleep.txt @ECHO ............................................Informational........................................... >> %TW-FN%\Broadcom_Products\Storcli\BatterySleep_FWTermLog_C%%i.txt
															IF EXIST %TW-WS%fwtermlog_C%%i_BatterySleep.txt type %TW-WS%fwtermlog_C%%i_BatterySleep.txt >> %TW-FN%\Broadcom_Products\Storcli\BatterySleep_FWTermLog_C%%i.txt
															)
							
							




							REM ###########################################################################################################################
							REM # MegaCli eventlog error screening
							REM # 
							REM # Words to look out for... 
							REM ###########################################################################################################################
SET STORCLI1_F=%time%
							IF EXIST %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Warning\0x00000071_Warning_113d_Unexpected_sense_X_CDBX_Sense_X_C%%i.txt	(
																							%grep% -e "0070 0000 000b 0000 0000 0000 0000 000a 0000 0000 0000 0000 0047 0003" %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Warning\0x00000071_Warning_113d_Unexpected_sense_X_CDBX_Sense_X_C%%i.txt >> %TW-WS%iuCRC_Error_Detected_C%%i.txt 2>&1
																							dir %TW-WS%iuCRC_Error_Detected_C%%i.txt | find /I " 0 iuCRC_Error_Detected_C%%i.txt" >> misc_output.txt 2>&1
																							IF NOT ERRORLEVEL 1 del %TW-WS%iuCRC_Error_Detected_C%%i.txt
																							REM      	                   	            .................................................::.................................................
																							IF EXIST %TW-WS%iuCRC_Error_Detected_C%%i.txt @ECHO .................................Drive sense data contains b/47/03.................................. > %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Controller_C%%i\Warning\iuCRC_Error_Detected_C%%i.txt
																							IF EXIST %TW-WS%iuCRC_Error_Detected_C%%i.txt type %TW-WS%iuCRC_Error_Detected_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Controller_C%%i\Warning\iuCRC_Error_Detected_C%%i.txt
																							IF EXIST %TW-WS%iuCRC_Error_Detected_C%%i.txt @ECHO .................................Drive sense data contains b/47/03.................................. > %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Warning\iuCRC_Error_Detected_C%%i.txt
																							IF EXIST %TW-WS%iuCRC_Error_Detected_C%%i.txt type %TW-WS%iuCRC_Error_Detected_C%%i.txt >> %TW-FN%\Broadcom_Products\Storcli\Event_Logs\Warning\iuCRC_Error_Detected_C%%i.txt
																							)
							)


REM   ......................................::.......................................
@ECHO ..................................Controller #................................. >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Controller =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt | %grep% -m 1 "Controller =" >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO ....................................Model #.................................... >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Model =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO ................................Serial Number #................................ >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Serial Number =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO .........................Current Controller Date/Time.......................... >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Current Controller Date/Time =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO ...................................Mfg Date.................................... >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Mfg Date =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO ..................................Rework Date.................................. >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Rework Date =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO ..................................Revision No.................................. >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Revision No =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO .............................Firmware Package Build............................ >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Firmware Package Build =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO ..................................Bios Version................................. >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Bios Version =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO ................................NVDATA Version................................. >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^NVDATA Version =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO ...............................Boot Block Version.............................. >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Boot Block Version =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO ...............................Bootloader Version.............................. >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Bootloader Version =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO ..................................Driver Name.................................. >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Driver Name =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO ................................Driver Version................................. >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Driver Version =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO ...................................Vendor Id................................... >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Vendor Id =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO ...................................Device Id................................... >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Device Id =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO .................................SubVendor Id.................................. >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^SubVendor Id =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO .................................SubDevice Id.................................. >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^SubDevice Id =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO ................................Host Interface................................. >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Host Interface =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO ...............................Device Interface................................ >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Device Interface =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO ...................................Bus Number.................................. >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Bus Number =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO ..................................Device Number................................ >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Device Number =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO .................................Function Number............................... >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Function Number =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO ...................................Image name.................................. >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
%grep% "^Image name =" %TW-FN%\Broadcom_Products\Storcli\Call_show_all.txt >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt
								
REM   ......................................::.......................................
@ECHO ...............................Stopped at Status............................... >> %TW-FN%\Broadcom_Products\Storcli\Call_show_all-Compare-All-Parms.txt

:NO_MR_Adapters

IF [%TWGETPARTIALMODE%]==[E_AEC] GOTO END_No_Pause
IF [%TWGETPARTIALMODE%]==[E_DPM] GOTO END_No_Pause
IF [%TWGETPARTIALMODE%]==[E_AEC_DPM] GOTO END_No_Pause
SET STORCLI1_G=%time%
REM ###########################################################################################################################
REM Broadcom HBA TODO ADD HBA
REM ###########################################################################################################################

:NO_Gen3_LSI_Expanders
:SKIP_TO_NEXTSCLI
:NO_Gen2_LSI_Expanders
:NO_Gen1_LSI_Expanders
:NOWOW64_SKIP_XU

IF EXIST %TW-WS%Gen4_EXP_SAS_Address_RAW.txt (SET NO_g4xu_GEN4_EXPs=NO) ELSE SET NO_g4xu_GEN4_EXPs=YES
IF EXIST %TW-WS%Gen3_EXP_SAS_Address_RAW.txt (SET NO_g3xu_GEN3_EXPs=NO) ELSE SET NO_g3xu_GEN3_EXPs=YES
IF EXIST %TW-WS%Gen2_EXP_SAS_Address_RAW.txt (SET NO_xu_GEN2_EXPs=NO) ELSE SET NO_xu_GEN2_EXPs=YES
IF EXIST %TW-WS%Gen1_EXP_SAS_Address_RAW.txt (SET NO_xu_GEN1_EXPs=NO) ELSE SET NO_xu_GEN1_EXPs=YES
IF EXIST %TW-WS%Gen4_EXP_SAS_Address_RAW.txt type %TW-WS%Gen4_EXP_SAS_Address_RAW.txt >> %TW-WS%GenX_EXP_SAS_Address.txt
IF EXIST %TW-WS%Gen3_EXP_SAS_Address_RAW.txt type %TW-WS%Gen3_EXP_SAS_Address_RAW.txt >> %TW-WS%GenX_EXP_SAS_Address.txt
IF EXIST %TW-WS%Gen2_EXP_SAS_Address_RAW.txt type %TW-WS%Gen2_EXP_SAS_Address_RAW.txt >> %TW-WS%GenX_EXP_SAS_Address.txt
IF EXIST %TW-WS%Gen1_EXP_SAS_Address_RAW.txt type %TW-WS%Gen1_EXP_SAS_Address_RAW.txt >> %TW-WS%GenX_EXP_SAS_Address.txt
IF EXIST %TW-WS%GenX_EXP_SAS_Address.txt (SET NO_Xxu_GenX_EXPs=NO) ELSE SET NO_Xxu_GenX_EXPs=YES

IF ["%NO_xu_GEN1_EXPs%"]==["YES"]	(
					IF ["%NO_xu_GEN2_EXPs%"]==["YES"]	(SET NO_xu_GEN1-2_EXPs=YES)
					)

IF ["%NO_g3xu_GEN3_EXPs%"]==["YES"]	(
					IF EXIST %TW-WS%GenX_EXP_SAS_Address.txt %grep% -c -e : %TW-WS%GenX_EXP_SAS_Address.txt | %grep% 1 >> misc_output.txt 2>&1
					IF NOT ERRORLEVEL 1 @ECHO No_Exp_Cumulative > %TW-WS%No_Exp_Cumulative.txt
					)

@ECHO End of the Broadcom SAS Expander Data Collection... >> misc_output.txt 2>&1
@ECHO End of the Broadcom SAS Expander Data Collection... > %TW-WS%End_Expander.txt

REM IF EXIST %TW-WS%No_Exp_Cumulative.txt	(
REM 						IF NOT [%NOWOW64%]==[YES] (.\xdir /Form=*t %TW-WS%End_Expander.txt >> misc_output.txt 2>&1)
REM 						IF NOT [%NOWOW64%]==[YES] (@ECHO Cumulative - Expanders:)
REM 						IF NOT [%NOWOW64%]==[YES] (%TW-WS%timers\timer8\timer8 /s /nologo)
REM 						)


:SKIPEXPANDER
REM ###########################################################################################################################
REM # Partial capture
REM ###########################################################################################################################
IF [%TWGETPARTIALMODE%]==[G_AEC] GOTO NOT_MONITOR_MODE
IF [%TWGETPARTIALMODE%]==[G_DPM] GOTO NOT_MONITOR_MODE
IF [%TWGETPARTIALMODE%]==[G_AEC_DPM] GOTO NOT_MONITOR_MODE

IF [%TWGETPARTIALMODE%]==[E_AEC] GOTO END_No_Pause
IF [%TWGETPARTIALMODE%]==[E_DPM] GOTO END_No_Pause
IF [%TWGETPARTIALMODE%]==[E_AEC_DPM] GOTO END_No_Pause

REM ###########################################################################################################################
REM # System Event Logs using Windows Events Command Line Utility
REM ###########################################################################################################################

IF NOT [%NOWOW64%]==[YES]	(
				@ECHO .
				@ECHO Starting the Event Log Collections...
				wevtutil /? >> misc_output.txt 2>&1
				IF NOT ERRORLEVEL 1	(
							IF NOT EXIST %TW-FN%\System_Logs mkdir %TW-FN%\System_Logs >> misc_output.txt 2>&1
							wevtutil.exe epl System %TW-FN%\System_Logs\system.evt /ow:true
							)
				)

REM ###########################################################################################################################
REM # MegaRAID System/Application Event Logs using eventquery.vbs 
REM ###########################################################################################################################
SET EVENTLOGS=%time%
IF EXIST %systemroot%\system32\eventquery.vbs GOTO HAVE_EVENTQUERY

REM No EVENTQUERY
GOTO USE_DUMPALL

:HAVE_EVENTQUERY

IF EXIST %systemroot%\system32\eventquery.vbs	(
						IF NOT EXIST %TW-FN%\System_Logs mkdir %TW-FN%\System_Logs >> misc_output.txt 2>&1			
						cscript %systemroot%\system32\eventquery.vbs /V /L system > %TW-FN%\System_Logs\system.log  2>&1
						cscript %systemroot%\system32\eventquery.vbs /V /L application > %TW-FN%\System_Logs\application.log  2>&1
						)

REM Removed, can add back if we see a need.
REM @ECHO Starting the Security Event Log Collection...
REM IF EXIST %systemroot%\system32\eventquery.vbs cscript %systemroot%\system32\eventquery.vbs /V /L security > %TW-FN%\security.log  2>&1

GOTO DONT_USE_DUMPEL

REM ###########################################################################################################################
REM # MegaRAID System/Application Event Logs using dumpel
REM ###########################################################################################################################
:USE_DUMPALL

dumpel /? >> misc_output.txt 2>&1
IF NOT ERRORLEVEL 1	(
			IF NOT EXIST %TW-FN%\System_Logs mkdir %TW-FN%\System_Logs >> misc_output.txt 2>&1
			dumpel -f %TW-FN%\System_Logs\system.log -l system >> misc_output.txt 2>&1
			dumpel -f %TW-FN%\System_Logs\application.log -l application >> misc_output.txt 2>&1
			)

:DONT_USE_DUMPEL

REM ###########################################################################################################################
REM # Deciphering System Log AEN's from both Dumpel & EventQuery
REM ###########################################################################################################################

IF NOT [%TWGETSKIPMEGARAID%]==[YES]	(
					IF EXIST %TW-FN%\System_Logs\system.log %grep% -i -e megasas -e megasas2 -e msas2k3 -e MR_MONITOR %TW-FN%\System_Logs\system.log > %TW-WS%system_mr.log  2>&1
					IF NOT ERRORLEVEL 1	(
								IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products
								IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli mkdir %TW-FN%\Broadcom_Products\Storcli
								move /Y %TW-WS%system_mr.log %TW-FN%\Broadcom_Products\Storcli\system_mr.log >> misc_output.txt 2>&1
								)	
					REM IF EXIST %TW-FN%\System_Logs\application.log %grep% -i -e megasas -e megasas2 -e msas2k3 -e MR_MONITOR %TW-FN%\System_Logs\application.log > %TW-FN%\Broadcom_Products\Storcli\application_mr.log  2>&1
					IF EXIST %TW-FN%\System_Logs\application.log %grep% -e MR_MONITOR %TW-FN%\System_Logs\application.log > %TW-WS%application_mr.log  2>&1
					IF NOT ERRORLEVEL 1	(
								IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products
								IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli mkdir %TW-FN%\Broadcom_Products\Storcli
								move /Y %TW-WS%application_mr.log %TW-FN%\Broadcom_Products\Storcli\application_mr.log >> misc_output.txt 2>&1
								)
					)				

IF NOT [%TWGETSKIPHBA%]==[YES]	(
				IF EXIST %TW-FN%\System_Logs\system.log %grep% -i -e symmpi -e lsi_sas -e lsi_sas2 -e lsi_gen2 -e lsi_sas3 -e MR_MONITOR %TW-FN%\System_Logs\system.log > %TW-WS%system_hba.log  2>&1
				IF NOT ERRORLEVEL 1	(
							IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products
							IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli mkdir %TW-FN%\Broadcom_Products\Storcli
							move /Y %TW-WS%system_hba.log %TW-FN%\Broadcom_Products\HBA\system_hba.log >> misc_output.txt 2>&1
							)
				)

IF EXIST %TW-FN%\System_Logs\system.log %grep% -e "\Device\Harddisk" %TW-FN%\System_Logs\system.log > %TW-WS%system_Device-Harddisk.log  2>&1
IF NOT ERRORLEVEL 1	(
			IF NOT EXIST %TW-FN%\System_Logs mkdir %TW-FN%\System_Logs
			move /Y %TW-WS%system_Device-Harddisk.log %TW-FN%\System_Logs\system_Device-Harddisk.log >> misc_output.txt 2>&1
			)


REM ###########################################################################################################################
REM # Dumping Registry Keys
REM ###########################################################################################################################
SET REGKEYS=%time%
@ECHO .
IF [%HAVE_REG%]==[YES]	(@ECHO Saving the Broadcom Registry Keys if present...)
			
			reg query HKLM\Hardware\Devicemap\SCSI /S > %TW-WS%sys-reg_hw_devicemap_scsi.txt 2>&1
			reg query HKLM\System\CurrentControlSet\Services\Disk /S > %TW-WS%sys-reg_Disk.txt 2>&1
			reg query HKLM\System\CurrentControlSet\Services\SNMP /S > %TW-WS%sys-reg_SNMP.txt 2>&1
			reg query HKLM\System\CurrentControlSet\Services\Wmi /S > %TW-WS%sys-reg_Wmi.txt 2>&1
			reg query HKLM\System\CurrentControlSet\Enum\PCI /S > %TW-WS%sys-reg_PCI.txt 2>&1
			dir %TW-WS%sys-reg_* /b > %TW-WS%initial_sys_reg-keys.txt
			FOR /F "tokens=1,2 delims=-" %%i IN (%TW-WS%initial_sys_reg-keys.txt) DO	(
													IF EXIST %TW-WS%%%i-%%j %grep% "unable to find the specified registry key" %TW-WS%%%i-%%j >> misc_output.txt 2>&1
													IF ERRORLEVEL 1	(
															IF NOT EXIST %TW-FN%\System_Reg_Keys mkdir %TW-FN%\System_Reg_Keys
															move /Y %TW-WS%%%i-%%j %TW-FN%\System_Reg_Keys\%%j >> misc_output.txt 2>&1
															)
													)
			IF NOT [%TWGETSKIPMEGARAID%]==[YES]	(
								REM Broadcom MegaRAID
								reg query HKLM\SYSTEM\CurrentControlSet\Services\megasas /S > %TW-WS%mr-reg_megasas.txt 2>&1
								reg query HKLM\SYSTEM\CurrentControlSet\Services\megasas2 /S > %TW-WS%mr-reg_megasas2.txt 2>&1
								reg query HKLM\SYSTEM\CurrentControlSet\Services\msas2k3 /S > %TW-WS%mr-reg_msas2k3.txt 2>&1
								reg query HKLM\SYSTEM\CurrentControlSet\Services\megasas35 /S > %TW-WS%mr-reg_megasas35.txt 2>&1
								reg query HKLM\SYSTEM\CurrentControlSet\Services\megasr /S > %TW-WS%mr-reg_megasr.txt 2>&1
								reg query HKLM\SYSTEM\CurrentControlSet\Services\Lsa /S > %TW-WS%mr-reg_Lsa.txt 2>&1
								reg query HKLM\SYSTEM\CurrentControlSet\Services\LSAService /S > %TW-WS%mr-reg_LSAService.txt 2>&1
								reg query "HKLM\SOFTWARE\LSI Logic Corporation" /S > %TW-WS%mr-reg_LSILogicCorp.txt 2>&1
								reg query HKLM\SOFTWARE\LSICorp /S > %TW-WS%mr-reg_LSICorp.txt 2>&1
								dir %TW-WS%mr-reg_* /b > %TW-WS%initial_mr_reg-keys.txt
								FOR /f "tokens=1,2 delims=-" %%i IN (%TW-WS%initial_mr_reg-keys.txt) DO	(
																	IF EXIST %TW-WS%%%i-%%j %grep% "unable to find the specified registry key" %TW-WS%%%i-%%j >> misc_output.txt 2>&1
																	IF ERRORLEVEL 1	(
																			IF NOT EXIST %TW-FN%\System_Reg_Keys mkdir %TW-FN%\System_Reg_Keys
																			move /Y %TW-WS%%%i-%%j %TW-FN%\System_Reg_Keys\%%j >> misc_output.txt 2>&1
																			)
																	)
								)
			IF NOT [%TWGETSKIPHBA%]==[YES]	(
							REM Commented out export, getting load/unload error but only in script.
							REM Broadcom HBA's
							REM SYMMPI.sys is for parallel SCSI & Fibre Channel Only - MiniPort
							reg query HKLM\SYSTEM\CurrentControlSet\Services\symmpi /S > %TW-WS%hba-reg_symmpi.txt 2>&1
							REM LSI_SCSI.sys is for Parallel SCSI - StorPort
							reg query HKLM\SYSTEM\CurrentControlSet\Services\lsi_scsi /S > %TW-WS%hba-reg_lsi_scsi.txt 2>&1
							REM LSI_FC.sys is for Fibre Channel - StorPort
							reg query HKLM\SYSTEM\CurrentControlSet\Services\lsi_fc /S > %TW-WS%hba-reg_lsi_fc.txt 2>&1
							REM LSI_SAS.sys is for 3Gb SAS - StorPort
							reg query HKLM\SYSTEM\CurrentControlSet\Services\lsi_sas /S > %TW-WS%hba-reg_lsi_sas.txt 2>&1
							REM LSI_GEN2.sys is for 6Gb SAS - MiniPort uses Windows ScsiPort - 32bit XP Only
							reg query HKLM\SYSTEM\CurrentControlSet\Services\lsi_gen2 /S > %TW-WS%hba-reg_lsi_gen2.txt 2>&1
							REM LSI_SAS2.sys is for 6Gb SAS - MiniPort uses Windows StorPort 
							reg query HKLM\SYSTEM\CurrentControlSet\Services\lsi_sas2 /S > %TW-WS%hba-reg_lsi_sas2.txt 2>&1
							reg query HKLM\SYSTEM\CurrentControlSet\Services\lsi_sas2i /S > %TW-WS%hba-reg_lsi_sas2i.txt 2>&1
							REM LSI_SAS3.sys is for 12Gb SAS - MiniPort uses Windows StorPort 
							reg query HKLM\SYSTEM\CurrentControlSet\Services\lsi_sas3 /S > %TW-WS%hba-reg_lsi_sas3.txt 2>&1
							reg query HKLM\SYSTEM\CurrentControlSet\Services\lsi_sas3i /S > %TW-WS%hba-reg_lsi_sas3i.txt 2>&1
							REM ItSas3.sys is for 12Gb SAS - MiniPort uses Windows StorPort 
							reg query HKLM\SYSTEM\CurrentControlSet\Services\ItSas35 /S > %TW-WS%hba-reg_ItSas35.txt 2>&1
							reg query HKLM\SYSTEM\CurrentControlSet\Services\ItSas35i /S > %TW-WS%hba-reg_ItSas35i.txt 2>&1
							REM mpi3drv.sys is for 24Gb SAS - MiniPort uses Windows StorPort 
							reg query HKLM\SYSTEM\CurrentControlSet\Services\mpi3drv /S > %TW-WS%hba-reg_mpi3drv.txt 2>&1
							dir %TW-WS%hba-reg_* /b > %TW-WS%initial_hba_reg-keys.txt
							FOR /f "tokens=1,2 delims=-" %%i IN (%TW-WS%initial_hba_reg-keys.txt) DO	(
																	IF EXIST %TW-WS%%%i-%%j %grep% "unable to find the specified registry key" %TW-WS%%%i-%%j >> misc_output.txt 2>&1
																	IF ERRORLEVEL 1	(
																			IF NOT EXIST %TW-FN%\System_Reg_Keys mkdir %TW-FN%\System_Reg_Keys
																			move /Y %TW-WS%%%i-%%j %TW-FN%\System_Reg_Keys\%%j >> misc_output.txt 2>&1
																			)
																	)
							)
			IF NOT [%NO_bnxtnvm%]==[YES]	(
								REM Broadcom Netxtreme-E
								reg query HKLM\SYSTEM\CurrentControlSet\Services\bnxtnd /S > %TW-WS%nic-reg_bnxtnd.txt 2>&1
								dir %TW-WS%nic-reg* /b > %TW-WS%initial_bnxtnd_reg-keys.txt
								FOR /f "tokens=1,2 delims=-" %%i IN (%TW-WS%initial_bnxtnd_reg-keys.txt) DO	(
																	IF EXIST %TW-WS%%%i-%%j %grep% "unable to find the specified registry key" %TW-WS%%%i-%%j >> misc_output.txt 2>&1
																	IF ERRORLEVEL 1	(
																			IF NOT EXIST %TW-FN%\System_Reg_Keys mkdir %TW-FN%\System_Reg_Keys
																			move /Y %TW-WS%%%i-%%j %TW-FN%\System_Reg_Keys\%%j >> misc_output.txt 2>&1
																			)
																	)
								)
			
					REM ###########################################################################################################################
					REM # Grab MegaRAID MSM Logs and CIM/SNMP files (32bit)
					REM ###########################################################################################################################
					
					IF EXIST %systemroot%\..\"program files"\"MegaRAID Storage Manager"\*.properties (IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"program files"\"MegaRAID Storage Manager"\cimlog.txt (IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"program files"\"MegaRAID Storage Manager"\Framework\*.log (IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"program files"\"MegaRAID Storage Manager"\*.properties (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli mkdir %TW-FN%\Broadcom_Products\Storcli >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"program files"\"MegaRAID Storage Manager"\cimlog.txt (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli mkdir %TW-FN%\Broadcom_Products\Storcli >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"program files"\"MegaRAID Storage Manager"\Framework\*.log (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli mkdir %TW-FN%\Broadcom_Products\Storcli >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"program files"\"MegaRAID Storage Manager"\*.properties (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli\MSM mkdir %TW-FN%\Broadcom_Products\Storcli\MSM >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"program files"\"MegaRAID Storage Manager"\cimlog.txt (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli\MSM mkdir %TW-FN%\Broadcom_Products\Storcli\MSM >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"program files"\"MegaRAID Storage Manager"\Framework\*.log (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli\MSM mkdir %TW-FN%\Broadcom_Products\Storcli\MSM >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"program files"\"MegaRAID Storage Manager"\*.properties copy %systemroot%\..\"program files"\"MegaRAID Storage Manager"\*.properties %TW-FN%\Broadcom_Products\Storcli\MSM >> misc_output.txt 2>&1
					IF EXIST %systemroot%\..\"program files"\"MegaRAID Storage Manager"\cimlog.txt copy %systemroot%\..\"program files"\"MegaRAID Storage Manager"\cimlog.txt %TW-FN%\Broadcom_Products\Storcli\MSM >> misc_output.txt 2>&1
					IF EXIST %systemroot%\..\"program files"\"MegaRAID Storage Manager"\Framework\*.log copy %systemroot%\..\"program files"\"MegaRAID Storage Manager"\Framework\*.log %TW-FN%\Broadcom_Products\Storcli\MSM >> misc_output.txt 2>&1
				
					IF EXIST %systemroot%\..\"program files"\"LSI Corporation"\"CIM Provider"\SAS\*.mof (IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"program files"\"LSI Corporation"\"CIM Provider"\SAS\*.mof (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli mkdir %TW-FN%\Broadcom_Products\Storcli >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"program files"\"LSI Corporation"\"CIM Provider"\SAS\*.mof (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli\CIM mkdir %TW-FN%\Broadcom_Products\Storcli\CIM >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"program files"\"LSI Corporation"\"CIM Provider"\SAS\*.mof copy %systemroot%\..\"program files"\"LSI Corporation"\"CIM Provider"\SAS\*.mof %TW-FN%\Broadcom_Products\Storcli\CIM >> misc_output.txt 2>&1

					IF EXIST %systemroot%\..\"program files"\"LSI Corporation"\SNMPAgent\SAS\*.mib (IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"program files"\"LSI Corporation"\SNMPAgent\SAS\*.mib (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli mkdir %TW-FN%\Broadcom_Products\Storcli >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"program files"\"LSI Corporation"\SNMPAgent\SAS\*.mib (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli\SNMP mkdir %TW-FN%\Broadcom_Products\Storcli\SNMP >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"program files"\"LSI Corporation"\SNMPAgent\SAS\*.mib copy %systemroot%\..\"program files"\"LSI Corporation"\SNMPAgent\SAS\*.mib %TW-FN%\Broadcom_Products\Storcli\SNMP >> misc_output.txt 2>&1
					
					
					REM ###########################################################################################################################
					REM # Grab MegaRAID MSM Logs and CIM/SNMP files (64bit)
					REM ###########################################################################################################################

					IF EXIST %systemroot%\..\"Program Files (x86)"\"MegaRAID Storage Manager"\*.properties (IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"Program Files (x86)"\"MegaRAID Storage Manager"\cimlog.txt (IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"Program Files (x86)"\"MegaRAID Storage Manager"\Framework\*.log (IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"Program Files (x86)"\"MegaRAID Storage Manager"\*.properties (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli mkdir %TW-FN%\Broadcom_Products\Storcli >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"Program Files (x86)"\"MegaRAID Storage Manager"\cimlog.txt (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli mkdir %TW-FN%\Broadcom_Products\Storcli >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"Program Files (x86)"\"MegaRAID Storage Manager"\Framework\*.log (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli mkdir %TW-FN%\Broadcom_Products\Storcli >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"Program Files (x86)"\"MegaRAID Storage Manager"\*.properties (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli\MSM mkdir %TW-FN%\Broadcom_Products\Storcli\MSM >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"Program Files (x86)"\"MegaRAID Storage Manager"\cimlog.txt (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli\MSM mkdir %TW-FN%\Broadcom_Products\Storcli\MSM >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"Program Files (x86)"\"MegaRAID Storage Manager"\Framework\*.log (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli\MSM mkdir %TW-FN%\Broadcom_Products\Storcli\MSM >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"Program Files (x86)"\"MegaRAID Storage Manager"\*.properties copy %systemroot%\..\"Program Files (x86)"\"MegaRAID Storage Manager"\*.properties %TW-FN%\Broadcom_Products\Storcli\MSM >> misc_output.txt 2>&1
					IF EXIST %systemroot%\..\"Program Files (x86)"\"MegaRAID Storage Manager"\cimlog.txt copy %systemroot%\..\"Program Files (x86)"\"MegaRAID Storage Manager"\cimlog.txt %TW-FN%\Broadcom_Products\Storcli\MSM >> misc_output.txt 2>&1
					IF EXIST %systemroot%\..\"Program Files (x86)"\"MegaRAID Storage Manager"\Framework\*.log copy %systemroot%\..\"Program Files (x86)"\"MegaRAID Storage Manager"\Framework\*.log %TW-FN%\Broadcom_Products\Storcli\MSM >> misc_output.txt 2>&1
				
					IF EXIST %systemroot%\..\"Program Files (x86)"\"LSI Corporation"\"CIM Provider"\SAS\*.mof (IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"Program Files (x86)"\"LSI Corporation"\"CIM Provider"\SAS\*.mof (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli mkdir %TW-FN%\Broadcom_Products\Storcli >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"Program Files (x86)"\"LSI Corporation"\"CIM Provider"\SAS\*.mof (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli\CIM mkdir %TW-FN%\Broadcom_Products\Storcli\CIM >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"Program Files (x86)"\"LSI Corporation"\"CIM Provider"\SAS\*.mof copy %systemroot%\..\"Program Files (x86)"\"LSI Corporation"\"CIM Provider"\SAS\*.mof %TW-FN%\Broadcom_Products\Storcli\CIM >> misc_output.txt 2>&1

					IF EXIST %systemroot%\..\"Program Files (x86)"\"LSI Corporation"\SNMPAgent\SAS\*.mib (IF NOT EXIST %TW-FN%\Broadcom_Products mkdir %TW-FN%\Broadcom_Products >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"Program Files (x86)"\"LSI Corporation"\SNMPAgent\SAS\*.mib (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli mkdir %TW-FN%\Broadcom_Products\Storcli >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"Program Files (x86)"\"LSI Corporation"\SNMPAgent\SAS\*.mib (IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli\SNMP mkdir %TW-FN%\Broadcom_Products\Storcli\SNMP >> misc_output.txt 2>&1)
					IF EXIST %systemroot%\..\"Program Files (x86)"\"LSI Corporation"\SNMPAgent\SAS\*.mib copy %systemroot%\..\"Program Files (x86)"\"LSI Corporation"\SNMPAgent\SAS\*.mib %TW-FN%\Broadcom_Products\Storcli\SNMP >> misc_output.txt 2>&1

REM ###########################################################################################################################
REM # lspci
REM ###########################################################################################################################
SET LSPCIRUN=%time%
@ECHO .
@ECHO Collecting lspci data...

mkdir %TW-FN%\lspci
%lspci% --version > %TW-FN%\lspci\lspci_version.txt 2>> misc_output.txt 
%lspci% > %TW-FN%\lspci\lspci.txt 2>> misc_output.txt 
%lspci% -t > %TW-FN%\lspci\lspci-t.txt 2>> misc_output.txt 
%lspci% -tv > %TW-FN%\lspci\lspci-tv.txt 2>> misc_output.txt 
%lspci% -v > %TW-FN%\lspci\lspci-v.txt 2>> misc_output.txt 
%lspci% -vv > %TW-FN%\lspci\lspci-vv.txt 2>> misc_output.txt 
%lspci% -vvv > %TW-FN%\lspci\lspci-vvv.txt 2>> misc_output.txt 
%lspci% -vx > %TW-FN%\lspci\lspci-vx.txt 2>> misc_output.txt 
%lspci% -x > %TW-FN%\lspci\lspci-x.txt 2>> misc_output.txt 
%lspci% -xxx > %TW-FN%\lspci\lspci-xxx.txt 2>> misc_output.txt 
%lspci% -xxxx > %TW-FN%\lspci\lspci-xxxx.txt 2>> misc_output.txt 
%lspci% -vvvxxxx > %TW-FN%\lspci\lspci-vvvxxxx.txt 2>> misc_output.txt 
%lspci% -D > %TW-FN%\lspci\lspci-D.txt 2>> misc_output.txt 
%lspci% -n > %TW-FN%\lspci\lspci-n.txt 2>> misc_output.txt 
%lspci% -nn > %TW-FN%\lspci\lspci-nn.txt 2>> misc_output.txt 
%lspci% -M > %TW-FN%\lspci\lspci-M.txt 2>> misc_output.txt 
%lspci% -PP > %TW-FN%\lspci\lspci-PP.txt 2>> misc_output.txt 


REM ###########################################################################################################################
REM # MSINFO32, driverquery and tasklist
REM ###########################################################################################################################
SET MSINFORUN=%time%
IF [%TWGETSKIPWINDOWSREPORTING%]==[YES] GOTO SKIP_WINDOWS_REPORTING
IF [%NOWOW64%]==[YES] GOTO SKIP_WINDOWS_REPORTING

@ECHO .
REM %TW-WS%timers\timer100\timer100 /q /nologo
@ECHO Collecting MSINFO32 data...
@ECHO Collecting MSINFO32 data... > %TW-WS%Start_MSINFO32.txt
.\xdir /Form=*t %TW-WS%Start_MSINFO32.txt >> misc_output.txt 2>&1

msinfo32 /report %TW-FN%\msinfo32_report.txt 2>> misc_output.txt 

REM Depricated WINMSD support
REM If ERRORLEVEL 1 WINMSD /report %TW-FN%\winmsd_report.txt 2>> misc_output.txt 


REM   .......................................||.......................................
REM @ECHO .
REM @ECHO Will wait up to 10 additional minutes in 15
REM @ECHO second increments for MSINFO32 output file
REM @ECHO to be CREATED!
REM @ECHO .

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

@ECHO One minute...

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

@ECHO Two minutes...

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

@ECHO Three minutes...

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

@ECHO Four minutes...

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

@ECHO Five minutes......

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

@ECHO Six minutes...

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

@ECHO Seven minutes...

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

@ECHO Eight minutes...

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

@ECHO Nine minutes...

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

If EXIST %TW-FN%\msinfo32_report.txt (GOTO Proceed) ELSE %sleep% 15 

@ECHO Ten minutes......

If EXIST %TW-FN%\msinfo32_report.txt	GOTO Proceed 

@ECHO MSINFO32 Report file NOT CREATED in the alloted time!
@ECHO MSINFO32 Report file NOT CREATED in the alloted time! >> misc_output.txt 2>&1

GOTO MSINFO32_FILE_CREATE_FAILED

:Proceed

REM @ECHO .
REM @ECHO Will wait up to 5 additional minutes in 15
REM @ECHO second increments for MSINFO32 output file
REM @ECHO to be CLOSED!
REM @ECHO .
REM @ECHO File Created...
@ECHO File Created... >> misc_output.txt 2>&1

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

@ECHO One minute......

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

@ECHO Two minute......

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

@ECHO Three minute......

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

@ECHO Four minute......

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE %sleep% 15

@ECHO Five minute......

dir %TW-FN% | %grep% " 0 msinfo32_report.txt" >> misc_output.txt 2>&1

IF %ERRORLEVEL%==1 (GOTO Proceed1) ELSE @ECHO MSINFO32 Report file NOT CLOSED in the alloted time!

REM   .......................................||.......................................
@ECHO .
@ECHO Due to having an open file you will see some errors
@ECHO during file compression. One posibilty for this is
@ECHO MSINFO32 trying to access Outlook files. Click "NO"
@ECHO to OUTLOOKS query about file access if this occurs
@ECHO during the 5 minute retry period and the process
@ECHO will proceed.
@ECHO .
@ECHO .
@ECHO .

@ECHO MSINFO32 Report file NOT CLOSED in the alloted time! >> misc_output.txt 2>&1




:Proceed1
REM @ECHO File Closed...
@ECHO File Closed... >> misc_output.txt 2>&1

:MSINFO32_FILE_CREATE_FAILED


REM @ECHO End of MSINFO32 Data Collection...
@ECHO End of MSINFO32 Data Collection... >> misc_output.txt 2>&1
@ECHO End of MSINFO32 Data Collection... > %TW-WS%End_MSINFO32.txt
dir /od %TW-WS%End_MSINFO32.txt >> misc_output.txt 2>&1
REM %TW-WS%timers\timer100\timer100 /s /nologo
SET DRIVERQUERYRUN=%time%
@ECHO .
@ECHO Collecting driverquery data...
@ECHO Collecting driverquery /V >> misc_output.txt 2>&1
driverquery /V  >> %TW-FN%\System_Logs\driverquery_V.txt 2>&1
@ECHO Collecting driverquery /SI >> misc_output.txt 2>&1
driverquery /SI  >> %TW-FN%\System_Logs\driverquery_SI.txt 2>&1
@ECHO .
@ECHO Collecting tasklist data...
@ECHO Collecting tasklist /V >> misc_output.txt 2>&1
SET TASKLISTRUN=%time%
tasklist /V  >> %TW-FN%\System_Logs\tasklist.txt 2>&1


:SKIP_WINDOWS_REPORTING
SET CDARUN=%time%
IF NOT ["%TWGETSKIPCDA%"]==["YES"]	(
					REM ###########################################################################################################################
					REM Controller Disk Association
					REM ###########################################################################################################################

					IF NOT EXIST %TW-WS%cda mkdir %TW-WS%cda
					IF NOT EXIST %TW-FN%\Controller_Disk_Association MKDIR %TW-FN%\Controller_Disk_Association >> misc_output.txt 2>&1										

					@ECHO .
					REM IF NOT [%NOWOW64%]==[YES] (%TW-WS%timers\timer100\timer100 /q /nologo)
					@ECHO Compiling Controller/Disk Associations to the Windows PhysicalDisk PD #'s...
					IF [%NOWOW64%]==[YES] (@ECHO %time%)
					@ECHO Compiling Controller/Disk Associations to the Windows PhysicalDisk PD #'s... >> misc_output.txt 2>&1
					@ECHO Compiling Controller/Disk Associations to the Windows PhysicalDisk PD #'s... > %TW-WS%cda\Start_Compile_Disk_associations.txt
					IF NOT [%NOWOW64%]==[YES] (.\xdir /Form=*t %TW-WS%cda\Start_Compile_Disk_associations.txt >> misc_output.txt 2>&1)

				
					REM ###########################################################################################################################
					REM DiskPart - detail disk
					
					@ECHO list disk > %TW-WS%cda\listdisk.txt
					
					diskpart /s %TW-WS%cda\listdisk.txt > %TW-WS%cda\list_disk.txt
					%grep% -A 10000 -e "--------" %TW-WS%cda\list_disk.txt | %grep% Disk > %TW-WS%cda\diskpart_pds.txt
					FOR /F "tokens=2 delims= " %%i in (%TW-WS%cda\diskpart_pds.txt) DO	(
													@ECHO select disk %%i > %TW-WS%cda\detaildisk_%%i.txt
													@ECHO detail disk >> %TW-WS%cda\detaildisk_%%i.txt
													@ECHO exit >> %TW-WS%cda\detaildisk_%%i.txt
													)
					FOR /F "tokens=2 delims= " %%i in (%TW-WS%cda\diskpart_pds.txt) DO	(
													dir /b  %TW-WS%cda\detaildisk_%%i.txt >> %TW-WS%cda\diskpart_scripts.txt
													)
					FOR /F "tokens=1,2,3 delims=_." %%i in (%TW-WS%cda\diskpart_scripts.txt) DO	(
														REM   ......................................::.......................................
														@ECHO ...........................diskpart detail disk PD%%j............................ > %TW-WS%cda\dp-detail_disk_%%j.txt
														diskpart /s %TW-WS%cda\%%i_%%j.%%k >> %TW-WS%cda\dp-detail_disk_%%j.txt 2>&1
														)
					FOR /F "tokens=2 delims= " %%i in (%TW-WS%cda\diskpart_pds.txt) DO	(
													dir /b  %TW-WS%cda\dp-detail_disk_%%i.txt >> %TW-WS%cda\dp-detail_disk_all.txt
													)
					REM ###########################################################################################################################
					REM DiskPart - Location Path
					
					FOR /F "tokens=1,2,3,4 delims=_." %%i in (%TW-WS%cda\dp-detail_disk_all.txt) DO	(
															%grep% "Location Path :" %TW-WS%cda\%%i_%%j_%%k.%%l >> %TW-WS%cda\location-path_%%k.txt
															)
					REM ###########################################################################################################################
					REM sg_vpd - Page 0x83
											
					
					%sg_scan% -b -s -v > %TW-WS%cda\sg_scan-b-s-v.txt
					%sg_scan% -b -v > %TW-WS%cda\sg_scan-b-v.txt
					%sg_scan% -s -v | %gawk% $1~/SCSI/ > %TW-WS%cda\sg_scan-s-v.txt
					%sg_scan% | %gawk% "{print $1, $NF}" | %gawk% $1~/PD/ > %TW-WS%cda\pd_unid.txt
					FOR /F "tokens=2 delims= " %%i in (%TW-WS%cda\diskpart_pds.txt) DO	(
													REM   ......................................::.......................................
													@ECHO ..............................sg_vpd -p 0x83 PD%%i............................... > %TW-WS%cda\sg_vpd-0x83_%%i.txt
													%sg_vpd% -p 0x83 PD%%i >> %TW-WS%cda\sg_vpd-0x83_%%i.txt 2>&1
													dir /b %TW-WS%cda\sg_vpd-0x83_%%i.txt >> %TW-WS%cda\sg_vpd-0x83_all.txt 2>>misc_output.txt	
													) 
					
					
					REM ###########################################################################################################################
					REM storcli /cx/vx with NAA ID
					
					REM %TW-WS%cda\diskpart_pds.txt 	= diskpart PD #'s second token
					REM %TW-WS%cda\sg_scan-b-v.txt		= List of all PDs with additional info, i.e. PD19            <RAID >  LSI       MR9381-4i4e       4.23  004ba3d55b92dd5d1e50efa709b00506
					REM %TW-WS%cda\location-path_%%k.txt	= Location path in PD # designated 
					REM %TW-WS%cda\cv_pd_%%p.txt 		= MR /cx/vx # in PD # designated file
					
					IF NOT [%TWGETSKIPMEGARAID%]==[YES]	(
										IF NOT ["%NO_MR_Adps%"]==["YES"]	(
															%MR_Cli% /call/vall show all | %grep% -e "/c" -e "SCSI NAA Id =" > %TW-WS%cda\call_vall_cv_naa.txt
															IF NOT ERRORLEVEL 1	(	
																		%MR_Cli% /call/vall show all | %grep% -e "/c"  > %TW-WS%cda\call_vall_cv.txt
																			
																		FOR /F "tokens=1,2 delims=/:" %%i in (%TW-WS%cda\call_vall_cv.txt) DO	(
																											%grep% -A 1 "/%%i/%%j" %TW-WS%cda\call_vall_cv_naa.txt >> "%TW-WS%cda\cv_naa_%%i_%%j.txt"
																											)
																		FOR /F "tokens=1,2 delims=/:" %%i in (%TW-WS%cda\call_vall_cv.txt) DO	(
																											%grep% "SCSI NAA Id =" "%TW-WS%cda\cv_naa_%%i_%%j.txt" >> "%TW-WS%cda\naa_%%i_%%j.txt"
																											@ECHO naa_%%i_%%j.txt >> %TW-WS%cda\naa_all.txt
																											)
																		IF EXIST %TW-WS%cda\naa_all.txt	(FOR /F "tokens=1,2" %%i in (%TW-WS%cda\naa_all.txt) DO	(move /Y "%TW-WS%cda\%%i %%j" "%TW-WS%cda\%%i%%j" >> misc_output.txt 2>&1))
													
																	
																			
																		FOR /F "tokens=1,2 delims=/: " %%i in (%TW-WS%cda\call_vall_cv.txt) DO	(
																											FOR /F "tokens=4 delims== " %%k in (%TW-WS%cda\naa_%%i_%%j.txt) DO	(
																																			FOR /F "tokens=2 delims= " %%l in (%TW-WS%cda\diskpart_pds.txt) DO	(
																																											%grep% %%k %TW-WS%cda\sg_vpd-0x83_%%l.txt >> misc_output.txt 2>&1
																																											IF NOT ERRORLEVEL 1	( 
																																														@ECHO /%%i/%%j >> %TW-WS%cda\cv_pd_%%l.txt
																																														REM   ......................................::.......................................
																																														@ECHO ..........................storcli /%%i/%%j show all............................ > %TW-WS%cda\cvsa_pd_%%l.txt
																																														%MR_Cli% /%%i/%%j show all >> %TW-WS%cda\cvsa_pd_%%l.txt
																																														)
																																											)
																																				)
																											)
																		)
															)
										)
													
					IF EXIST %TW-WS%cda\call_vall_cv.txt	(
										dir %TW-WS%cda\call_vall_cv.txt | %grep% " 0 call_vall_cv.txt" >> misc_output.txt 2>&1
										IF NOT ERRORLEVEL 1 move /Y %TW-WS%cda\call_vall_cv.txt %TW-WS%cda\0Byte_call_vall_cv.txt >> misc_output.txt 2>&1	
										)
		
										

					
					IF EXIST %TW-FN%\System_Reg_Keys\reg_hw_devicemap_scsi.txt	(
													%grep% "Logical Unit Id" %TW-FN%\System_Reg_Keys\reg_hw_devicemap_scsi.txt > %TW-WS%cda\reg_scsi_lun_id.txt 
													FOR /F "tokens=1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17 delims=\ " %%i in (%TW-WS%cda\reg_scsi_lun_id.txt) DO (%grep% -F -A 5 "%%i\%%j\%%k\%%l\%%m %%n %%o\%%p %%q %%r\%%s %%t %%u\%%v %%w %%x %%y" %TW-FN%\System_Reg_Keys\reg_hw_devicemap_scsi.txt | %grep% -e "Logical Unit Id" -e "InquiryData" -e "SerialNumber" -e "Identifier" -e "DeviceType" -e "DeviceIdentifierPage" > %TW-WS%cda\reg-scsi-lun-id_%%o_%%r_%%u_%%y.txt)
													dir /b %TW-WS%cda\reg-scsi-lun-id_* > %TW-WS%cda\reg-scsi-lun-id-all.txt
													FOR /F "tokens=2 delims= " %%i in (%TW-WS%cda\diskpart_pds.txt) DO	(
																						%grep% "PD%%i " %TW-WS%cda\pd_unid.txt > %TW-WS%cda\pd_unid_%%i.txt
																						)
													FOR /F "tokens=2 delims= " %%i in (%TW-WS%cda\diskpart_pds.txt) DO	(
																						FOR /F "tokens=2 delims= " %%j in (%TW-WS%cda\pd_unid_%%i.txt) DO	(
																															FOR /F "tokens=1,2,3,4,5,6 delims=_." %%k in (%TW-WS%cda\reg-scsi-lun-id-all.txt) DO	(
																																										%grep% %%j %TW-WS%cda\%%k_%%l_%%m_%%n_%%o.%%p >> misc_output.txt 2>&1
																																										IF NOT ERRORLEVEL 1	(
																																													copy %TW-WS%cda\%%k_%%l_%%m_%%n_%%o.%%p %TW-WS%cda\%%k-PD_%%i.txt >> misc_output.txt 2>&1
																																													%grep% "Logical Unit Id" %TW-WS%cda\%%k-PD_%%i.txt > %TW-WS%cda\presum-%%k-PD_%%i.txt 
																																													)												
																																										)
																															)
																						)
													FOR /F "tokens=2 delims= " %%i in (%TW-WS%cda\diskpart_pds.txt) DO	(IF EXIST %TW-WS%cda\presum-reg-scsi-lun-id-PD_%%i.txt @ECHO %%i >> %TW-WS%cda\reg-scsi-lun-id-pds.txt)
													IF EXIST %TW-WS%cda\reg-scsi-lun-id-pds.txt	( 
																			FOR /F "tokens=1" %%i in (%TW-WS%cda\reg-scsi-lun-id-pds.txt) DO	(
																												FOR /F "tokens=5,6,7,8 delims=\" %%j in (%TW-WS%cda\presum-reg-scsi-lun-id-PD_%%i.txt) DO (@ECHO \%%j\%%k\%%l\%%m > %TW-WS%cda\sum-reg-scsi-lun-id-PD_%%i.txt)
																												)
																			)
													)
					
																		
					FOR /F "tokens=2 delims= " %%i in (%TW-WS%cda\diskpart_pds.txt) DO	(
														REM   ......................................::.......................................
														@ECHO ............................................................................... >> %TW-FN%\Controller_Disk_Association\CDA_Summary.txt
														%grep% "PD%%i   " %TW-WS%cda\sg_scan-b-v.txt >> %TW-FN%\Controller_Disk_Association\CDA_Summary.txt
														IF EXIST %TW-WS%cda\location-path_%%i.txt type %TW-WS%cda\location-path_%%i.txt	>> %TW-FN%\Controller_Disk_Association\CDA_Summary.txt
														IF EXIST %TW-WS%cda\location-path_%%i.txt type %TW-WS%cda\location-path_%%i.txt	>> %TW-WS%cda\location-path_all.txt
														IF EXIST %TW-WS%cda\sum-reg-scsi-lun-id-PD_%%i.txt type %TW-WS%cda\sum-reg-scsi-lun-id-PD_%%i.txt >> %TW-FN%\Controller_Disk_Association\CDA_Summary.txt
														IF EXIST %TW-WS%cda\cv_pd_%%i.txt	(
																			type %TW-WS%cda\cv_pd_%%i.txt >> %TW-FN%\Controller_Disk_Association\CDA_Summary.txt
																			@ECHO %%i >> %TW-WS%cda\mr_pds.txt
																			)
														IF EXIST %TW-WS%cda\cu_pd_%%i.txt	(
																			type %TW-WS%cda\cu_pd_%%i.txt >> %TW-FN%\Controller_Disk_Association\CDA_Summary.txt
																			@ECHO %%i >> %TW-WS%cda\3w_pds.txt
																			)												
														)
					FOR /F "tokens=2 delims= " %%i in (%TW-WS%cda\diskpart_pds.txt) DO	(
														%grep% "PD%%i   " %TW-WS%cda\sg_scan-b-v.txt >> %TW-FN%\Controller_Disk_Association\Physical_Disk_%%i.txt
														IF EXIST %TW-WS%cda\dp-detail_disk_%%i.txt type %TW-WS%cda\dp-detail_disk_%%i.txt >> %TW-FN%\Controller_Disk_Association\Physical_Disk_%%i.txt
														IF EXIST %TW-WS%cda\sg_vpd-0x83_%%i.txt type %TW-WS%cda\sg_vpd-0x83_%%i.txt >> %TW-FN%\Controller_Disk_Association\Physical_Disk_%%i.txt
														IF EXIST %TW-WS%cda\reg-scsi-lun-id-PD_%%i.txt	( 
																				REM   ......................................::.......................................
																				@ECHO .................................Registry Key.................................. >> %TW-FN%\Controller_Disk_Association\Physical_Disk_%%i.txt
																				type %TW-WS%cda\reg-scsi-lun-id-PD_%%i.txt >> %TW-FN%\Controller_Disk_Association\Physical_Disk_%%i.txt
																				)
														IF EXIST %TW-WS%cda\cvsa_pd_%%i.txt type %TW-WS%cda\cvsa_pd_%%i.txt >> %TW-FN%\Controller_Disk_Association\Physical_Disk_%%i.txt 
														IF EXIST %TW-WS%cda\cusa_pd_%%i.txt type %TW-WS%cda\cusa_pd_%%i.txt >> %TW-FN%\Controller_Disk_Association\Physical_Disk_%%i.txt
														)
					IF NOT [%TWGETSKIPMEGARAID%]==[YES]	(
										IF EXIST %TW-WS%cda\call_vall_cv.txt	(
															FOR /F "tokens=1" %%i in (%TW-WS%cda\mr_pds.txt) DO	(
																						REM   ......................................::.......................................
																						@ECHO ............................................................................... >> %TW-FN%\Controller_Disk_Association\CDA_Summary_MegaRAID.txt
																						%grep% "PD%%i   " %TW-WS%cda\sg_scan-b-v.txt >> %TW-FN%\Controller_Disk_Association\CDA_Summary_MegaRAID.txt
																						IF EXIST %TW-WS%cda\location-path_%%i.txt type %TW-WS%cda\location-path_%%i.txt	>> %TW-FN%\Controller_Disk_Association\CDA_Summary_MegaRAID.txt
																						IF EXIST %TW-WS%cda\sum-reg-scsi-lun-id-PD_%%i.txt type %TW-WS%cda\sum-reg-scsi-lun-id-PD_%%i.txt >> %TW-FN%\Controller_Disk_Association\CDA_Summary_MegaRAID.txt
																						type %TW-WS%cda\cv_pd_%%i.txt >> %TW-FN%\Controller_Disk_Association\CDA_Summary_MegaRAID.txt
																						IF EXIST %TW-FN%\Controller_Disk_Association\Physical_Disk_%%i.txt move /Y %TW-FN%\Controller_Disk_Association\Physical_Disk_%%i.txt %TW-FN%\Controller_Disk_Association\Physical_Disk_%%i_MegaRAID.txt >> misc_output.txt 2>&1
																						)
															)
										)
					IF EXIST %TW-WS%cda\sg_scan-b-s-v.txt move /Y %TW-WS%cda\sg_scan-b-s-v.txt %TW-FN%\Controller_Disk_Association\sg_scan-b-s-v.txt >> misc_output.txt 2>&1										
					
					
					@ECHO Completed... >> misc_output.txt 2>&1
					@ECHO Completed Compiling Controller/Disk Associations to the Windows PhysicalDisk PD #'s... > %TW-WS%cda\End_Compile_Disk_associations.txt
					IF NOT [%NOWOW64%]==[YES] (.\xdir /Form=*t %TW-WS%cda\End_Compile_Disk_associations.txt >> misc_output.txt 2>&1)
					REM IF NOT [%NOWOW64%]==[YES] (%TW-WS%timers\timer100\timer100 /s /nologo)
					)

REM ###########################################################################################################################
REM # Save storcli.log / storsas.log Files
REM ###########################################################################################################################
SET SAVESTORCLILOG=%time%
IF EXIST storcli.log copy storcli.log %TW-FN%\Broadcom_Products\Storcli\Snapdump >> misc_output.txt 2>&1
IF EXIST storelibdebugit.txt copy storelibdebugit.txt %TW-FN%\Broadcom_Products\Storcli\Snapdump >> misc_output.txt 2>&1

IF EXIST storcli2.log copy storcli2.log %TW-FN%\Broadcom_Products\Storcli\Avenger\Snapdump >> misc_output.txt 2>&1
IF EXIST storcli2.log.1 copy storcli2.log.1 %TW-FN%\Broadcom_Products\Storcli\Avenger\Snapdump >> misc_output.txt 2>&1
IF EXIST storsas.log copy storsas.log %TW-FN%\Broadcom_Products\Storcli\Avenger\Snapdump >> misc_output.txt 2>&1

			
mkdir native_test >> misc_output.txt 2>&1
cd native_test

REM   ......................................::.......................................
@ECHO ############################################################################### > ..\%TW-WS%Utility_Versions.txt 2>&1
@ECHO ############################################################################### >> ..\%TW-WS%Utility_Versions.txt 2>&1
@ECHO ############################################################################### >> ..\%TW-WS%Utility_Versions.txt 2>&1
@ECHO Installed Utils in Path >> ..\%TW-WS%Utility_Versions.txt 2>&1
@ECHO ############################################################################### >> ..\%TW-WS%Utility_Versions.txt 2>&1
@ECHO ############################################################################### >> ..\%TW-WS%Utility_Versions.txt 2>&1
@ECHO ############################################################################### >> ..\%TW-WS%Utility_Versions.txt 2>&1
%MR_Cli% version >> ..\%TW-WS%Utility_Versions.txt 2>&1
@ECHO ############################################################################### >> ..\%TW-WS%Utility_Versions.txt 2>&1
%MR_Cli2% version >> ..\%TW-WS%Utility_Versions.txt 2>&1
REM   ......................................::.......................................

cd ..
rmdir /S /Q native_test >> misc_output.txt 2>&1

REM   ......................................::.......................................
@ECHO ############################################################################### >> %TW-WS%Utility_Versions.txt 2>&1
@ECHO ############################################################################### >> %TW-WS%Utility_Versions.txt 2>&1
@ECHO ############################################################################### >> %TW-WS%Utility_Versions.txt 2>&1
@ECHO Script supplied Utils >> %TW-WS%Utility_Versions.txt 2>&1
@ECHO ############################################################################### >> %TW-WS%Utility_Versions.txt 2>&1
@ECHO ############################################################################### >> %TW-WS%Utility_Versions.txt 2>&1
@ECHO ############################################################################### >> %TW-WS%Utility_Versions.txt 2>&1
%MR_Cli% version >> %TW-WS%Utility_Versions.txt 2>&1
@ECHO ############################################################################### >> %TW-WS%Utility_Versions.txt 2>&1
%MR_Cli2% version >> %TW-WS%Utility_Versions.txt 2>&1
REM   ......................................::.......................................

IF ["%NO_scl_EXP-IOC%"]==["YES"] move /Y scli.exe Utils >> misc_output.txt 2>&1

IF ["%NO_MR_Adps%"]==["YES"] move /Y %MR_Cli% Utils >> misc_output.txt 2>&1
IF ["%NO_g3xu_GEN3_EXPs%"]==["YES"] move /Y bootstrapCobra.bin Utils >> misc_output.txt 2>&1

IF EXIST %TW-FN%\Broadcom_Products\Storcli	(
					IF NOT EXIST %TW-FN%\Broadcom_Products\Storcli\Notes mkdir %TW-FN%\Broadcom_Products\Storcli\Notes
					move /Y MegaRAID_Terminology.txt %TW-FN%\Broadcom_Products\Storcli\Notes >> misc_output.txt 2>&1
					)	

IF [%NOWOW64%]==[YES] IF EXIST timer.exe del timer.exe >> misc_output.txt 2>&1
IF [%NOWOW64%]==[YES] IF EXIST xdir.exe del xdir.exe >> misc_output.txt 2>&1

REM ###########################################################################################################################
REM # Script Diag
REM ###########################################################################################################################
SET SCRIPTDIAGLOG=%time%
REM   ......................................::.......................................
@ECHO .....................Name of user executing BCMGet.bat...................... >> %TW-WS%script_diag.txt
@ECHO %USERNAME% >> %TW-WS%script_diag.txt
IF NOT [%NOWOW64%]==[YES] (@ECHO ..................................whoami.................................. >> %TW-WS%script_diag.txt)
IF NOT [%NOWOW64%]==[YES] (whoami >> %TW-WS%script_diag.txt)
REM   ......................................::.......................................
@ECHO ...............Directory contents where BCMGet.bat was executed............. >> %TW-WS%script_diag.txt
dir >> %TW-WS%script_diag.txt
REM   ......................................::.......................................
@ECHO ......................................set...................................... >> %TW-WS%script_diag.txt
set >> %TW-WS%script_diag.txt
@ECHO ......................................ver...................................... >> %TW-WS%script_diag.txt
ver >> %TW-WS%script_diag.txt
@ECHO ...........................Command Line and Options............................ >> %TW-WS%script_diag.txt
@ECHO %0 %* >> %TW-WS%script_diag.txt

REM ###########################################################################################################################
REM # Script Start/Stop times
REM ###########################################################################################################################
SET TWGETWINSTOP=%time%
@ECHO "Start of script" > %TW-WS%Script_Start_Stop_Time.txt
@ECHO %TWGETWINSTART% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "SCL296XXRAID" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %SCL296XXRAID% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "SCL296XXPERFIT" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %SCL296XXPERFIT% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "SCL296XXFeatureIT" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %SCL296XXFeatureIT% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "SCL296XXEHBA" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %SCL296XXEHBA% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "SCL295XXRAID" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %SCL295XXRAID% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "SCL295XXHBA" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %SCL295XXHBA% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "SCL2MARGAY" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %SCL2MARGAY% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "SCL2CUB" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %SCL2CUB% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "SCL2COBRA" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %SCL2COBRA% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "BNXTNVMRUN" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %BNXTNVMRUN% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "NICCLIRUN" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %NICCLIRUN% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "STORCLI2" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %STORCLI2% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "STORCLI1_A" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %STORCLI1_A% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "STORCLI1_B" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %STORCLI1_B% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "STORCLI1_C" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %STORCLI1_C% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "STORCLI1_D" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %STORCLI1_D% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "STORCLI1_E" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %STORCLI1_E% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "STORCLI1_F" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %STORCLI1_F% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "STORCLI1_G" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %STORCLI1_G% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "EVENTLOGS" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %EVENTLOGS% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "REGKEYS" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %REGKEYS% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "LSPCIRUN" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %LSPCIRUN% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "MSINFORUN" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %MSINFORUN% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "DRIVERQUERYRUN" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %DRIVERQUERYRUN% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "TASKLISTRUN" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %TASKLISTRUN% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "CDARUN" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %CDARUN% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "SAVESTORCLILOG" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %SAVESTORCLILOG% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "SCRIPTDIAGLOG" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %SCRIPTDIAGLOG% >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO "TWGETWINSTOP" >> %TW-WS%Script_Start_Stop_Time.txt
@ECHO %TWGETWINSTOP% >> %TW-WS%Script_Start_Stop_Time.txt


REM ###########################################################################################################################
REM # Compressing the file output and cleaning temporary workspace 
REM ###########################################################################################################################

REM HBA
IF EXIST Valid_hba_test.txt move /Y Valid_hba_test.txt %TW-WS% >> misc_output.txt 2>&1
REM MegaCli MegaRAID
IF EXIST adpcount.txt move /Y adpcount.txt %TW-WS% >> misc_output.txt 2>&1
REM storcli MegaRAID
IF EXIST pre_mr_ctrl_nums.txt move /Y pre_mr_ctrl_nums.txt %TW-WS% >> misc_output.txt 2>&1
IF EXIST pre_mr2_ctrl_nums.txt move /Y pre_mr2_ctrl_nums.txt %TW-WS% >> misc_output.txt 2>&1

IF EXIST misc_output.txt move /Y misc_output.txt %TW-WS% > nul 2>&1

IF [%TWGETSKIPCOMPRESSION%]==[YES]	( 
					@ECHO End of script...
					IF [%NOWOW64%]==[YES] (@ECHO %time%)
					@ECHO End of script... > %TW-WS%End_of_script.txt
					@ECHO .
					IF NOT [%NOWOW64%]==[YES] (@ECHO Elapsed Time for entire script:)
					IF NOT [%NOWOW64%]==[YES] (timer /s /nologo)
					@ECHO .
					@ECHO "BCMGet -H" provides a help screen.
					@ECHO . 
					@ECHO The data collection is in the following subdirectory;
					@ECHO .
					@ECHO %TW-FN%
					@ECHO .
					)

IF NOT [%TWGETSKIPCOMPRESSION%]==[YES]	( 
					@ECHO End of script, please wait while compressing output file...
					IF [%NOWOW64%]==[YES] (@ECHO %time%)
					@ECHO End of script, please wait while compressing output file... > %TW-WS%End_of_script.txt
					REM IF NOT [%NOWOW64%]==[YES] (Utils\timer_comp\timer_comp /q /nologo)
					7z -mx=9 a %TW-FN%.7z %TW-FN% >> misc_output.txt 2>&1
					%grep% "Everything is Ok" misc_output.txt > nul 2>&1
					IF NOT ERRORLEVEL 1 (del misc_output.txt > nul 2>&1)
					IF EXIST misc_output.txt 	(
									@ECHO .
									@ECHO .
									@ECHO .
									@ECHO .
									@ECHO .
									@ECHO Issue with 7z file compression, see misc_output.txt...
									@ECHO .
									@ECHO .
									@ECHO .
									@ECHO .
									@ECHO .
									)
					REM IF NOT [%NOWOW64%]==[YES] (Utils\timer_comp\timer_comp /s /nologo)
					REM   .......................................||.......................................
REM					IF NOT [%NOWOW64%]==[YES] (@ECHO .)
REM					IF NOT [%NOWOW64%]==[YES] (@ECHO Elapsed Time for entire script including file compression:)
REM					IF NOT [%NOWOW64%]==[YES] (timer /s /nologo)
					IF NOT EXIST misc_output.txt 	(
									@ECHO .
									@ECHO The file name is:
									@ECHO .
									@ECHO %TW-FN%.7z
									@ECHO .
									@ECHO Send JUST this file to your support rep, do NOT rename. 
									@ECHO .
									@ECHO "BCMGet -H" provides a help screen.
									@ECHO . 
									)	
					IF NOT [%TWGETDIRECTORYKEEP%]==[YES] 	(rmdir /S /Q %TW-FN%)
					IF [%TWGETDIRECTORYKEEP%]==[YES]	(
										@ECHO The following subdir was left for your use;
										@ECHO .
										@ECHO %TW-FN%
										@ECHO .
										)
					)


REM ###########################################################################################################################
REM # Clean old or temp files if they exist 
REM ###########################################################################################################################

IF [%TWGETBATCHMODE%]==[BATCH] GOTO END_No_Pause
IF [%TWGETBATCHMODE%]==[QUIET] GOTO END_No_Pause

:END
IF EXIST cleanup_all.txt	(FOR /F "usebackq" %%i IN (cleanup_all.txt) DO	(
										IF EXIST %%i (del %%i > nul 2>&1)
										) 
				IF NOT [%NOWOW64%]==[YES]	(
								@ECHO End of script... > End_of_script.txt
								@ECHO Script end time
								.\xdir /Form=*t End_of_script.txt
								@ECHO .	
								del End_of_script.txt > nul 2>&1
								del xdir.exe > nul 2>&1
								del timer.exe > nul 2>&1
								del timer.txt > nul 2>&1
								rmdir /S /Q Utils\timer_comp > nul 2>&1
								)
				IF [%EXTRACTUTILS%]==[YES] del misc_output.txt > nul 2>&1
				IF [%NOWOW64%]==[YES] (@ECHO %time%)
				)
del cleanup_all.txt > nul 2>&1 
del 7z.exe > nul 2>&1
del 7z.dll > nul 2>&1
IF EXIST cygwin64 rmdir /S /Q cygwin64 > nul 2>&1
IF EXIST doc rmdir /S /Q doc > nul 2>&1
IF EXIST pciutils-3.2.1_64 rmdir /S /Q pciutils-3.2.1_64 > nul 2>&1
IF EXIST sg3_utils-1.42_64 rmdir /S /Q sg3_utils-1.42_64 > nul 2>&1
IF EXIST Utils rmdir /S /Q Utils > nul 2>&1
IF EXIST sdrv rmdir /S /Q sdrv > nul 2>&1
IF EXIST win rmdir /S /Q win > nul 2>&1
PAUSE
GOTO END1

:END_No_Pause
IF EXIST cleanup_all.txt	(FOR /F "usebackq" %%i IN (cleanup_all.txt) DO	(
										IF EXIST %%i (del %%i > nul 2>&1)
										) 
				IF NOT [%NOWOW64%]==[YES]	(
								@ECHO End of script... > End_of_script.txt
								@ECHO Script end time
								.\xdir /Form=*t End_of_script.txt
								@ECHO .
								del End_of_script.txt > nul 2>&1
								del xdir.exe > nul 2>&1
								del timer.exe > nul 2>&1
								del timer.txt > nul 2>&1
								rmdir /S /Q Utils\timer_comp  > nul 2>&1
								)
				IF [%EXTRACTUTILS%]==[YES] del misc_output.txt > nul 2>&1
				IF [%NOWOW64%]==[YES] (@ECHO %time%)
				)
del cleanup_all.txt > nul 2>&1 
del 7z.exe > nul 2>&1
del 7z.dll > nul 2>&1

:SKIP_TO_END
:END1

